<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */

/**
 * Class CloudflareController
**/

class CloudflareController extends pm_Controller_Action{

    private $app;
    
    public function __call($name, $arguments){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index?call', [ 'exit' => true ]);
                return;
    }

/**
 * init
**/
    public function init(){
        parent::init();

		//error_reporting(E_ALL);

		if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
			$this->_redirect('index/index');
			return;
		}

		if(Modules_FlexFirewallManager_Settings::ResellerAuth()){
	        	if(Modules_FlexFirewallManager_Settings::GetSetting("status_Reseller")!="1"){
				if(!Modules_FlexFirewallManager_Settings::isEnablePermission()){
	        	   		throw new pm_Exception(pm_Locale::lmsg('statusNO'));
				}
		        }
		}
		if(Modules_FlexFirewallManager_Settings::ClientAuth()){

			if(!empty($this->getRequest()->getParam('site_id'))){
				$_SESSION[pm_Context::getModuleInfo()->name]['site_id']=$this->getRequest()->getParam('site_id');

				if(empty($this->getRequest()->getParam('alias_id'))){
					unset($_SESSION[pm_Context::getModuleInfo()->name]['alias_id']);
				}else{
					$_SESSION[pm_Context::getModuleInfo()->name]['alias_id']=$this->getRequest()->getParam('alias_id');
				}

			}

			if(!empty($this->getRequest()->getParam('context'))){
				foreach (pm_Domain::getDomainsByClient(pm_Session::getClient(),true) as $domain) {
            				if ($domain->hasPermission('firewall_ext_enable')){
						$_SESSION[pm_Context::getModuleInfo()->name]['site_id']=$domain->getId();
						unset($_SESSION[pm_Context::getModuleInfo()->name]['alias_id']);
	                			break;
            				}
        			}
			}

			if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['site_id']) &&  Modules_FlexFirewallManager_Settings::GetSetting("status_Client")!="1"){
				if(!Modules_FlexFirewallManager_Settings::isEnablePermission()){
	        		    	throw new pm_Exception(pm_Locale::lmsg('statusNO'));
				}
			}
		}

        	/** @noinspection PhpUndefinedFieldInspection */
	        $this->view->pageTitle = pm_Locale::lmsg('pageTitle');

		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'flex-firewall-manager.css?'.Date('dmhYis'));

		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-library.js?'.Date('dmhYis'));
		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-firewall-manager.js?'.Date('dmhYis'));


		$errorcom="";
         	try {
			$errorcom="CreateCom";
			$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
			$errorcom="CloudflareUserSetting";
			$this->app->CloudflareUserSetting=Modules_FlexFirewallManager_Settings::UserCom();
			$errorcom="";
	        }catch(exception $e){
			echo $errorcom . $e->getCode() . " : " . $e->getMessage()."<br>";
			die();
			$this->_redirect('index');
           	}
		

		if(isset($_SESSION[pm_Context::getModuleInfo()->name]['domain'])){
			if(Modules_FlexFirewallManager_Settings::GetLength($_SESSION[pm_Context::getModuleInfo()->name]['domain'])>1){$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];}
		}

    }



/**
 * Index Page. List Domains
**/
    public function indexAction(){


	$data = [];
	$dataCF = [];
	$regin=0;

	try {
		$appjson = json_decode($this->app->CloudFlareDomains());
	}catch(com_exception $e){
		if($e->getCode()==2147614729){
			Modules_FlexFirewallManager_Settings::SaveSetting("Job", "PleskUser");
                	$this->_redirect('index', [ 'exit' => true ]);
                	return;
		}
	}

	if($appjson->result){

		foreach($appjson->domains as $domain){
		 	$dataCF[] = [
                		'name' => $domain->DomainName,
                		'type' => "cloudflare",
                		'obj' => $domain
  	            	];
	    	}  


		$PleskDomains=Modules_FlexFirewallManager_Settings::GetAllDomains(true);


		foreach($PleskDomains as $DomainItem){

			$checkdom = Modules_FlexFirewallManager_Settings::CheckDomExist($dataCF,$DomainItem["name"]);
	
			if($checkdom==null){

				$DomainNS=Modules_FlexFirewallManager_Settings::GetPleskDomainNS($DomainItem["name"]);

				if($DomainItem["type"]=="notvalid"){

					$PleskNS = "";
					foreach($DomainNS as $ns){
						$PleskNS=$PleskNS."<img src=\"". pm_Context::getBaseUrl() ."img/icon/off-state.png\" style=\"width: 16px;margin-top: -2px;\"> " .$ns."<br>";
					}

					$data[] = [
        			        'domain' => $DomainItem["name"],
        	        		'status' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" style=\"width: 16px;margin-top: -2px;\" title=\"".pm_Locale::lmsg('Error.RootDomain')."\"> " . pm_Locale::lmsg('Error.Forbidden'),
		                	'plan' => pm_Locale::lmsg('FoundKO'),
					'ns' => $PleskNS,
					'dev' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off-state.png\"  style=\"width: 16px;margin-top: -2px;\">",
					'do' => "<a class=\"btn\" rel=\"".$DomainItem["name"]."\" title=\"".pm_Locale::lmsg('Error.RootDomain')."\" disabled href=\"javascript:\"><img src=\"". pm_Context::getBaseUrl() ."img/icon/protected.png\" style=\"width: 16px;margin-top: -2px;\">".pm_Locale::lmsg('Create')."</a>",
					];

				}else{
					$DomainIcon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/domain.png\" style=\"width: 16px;margin-top: -2px;\" title=\"".pm_Locale::lmsg('Domain')."\"> ";
					if($DomainItem["type"]=="alias"){$DomainIcon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/alias.png\" style=\"width: 16px;margin-top: -2px;\" title=\"Alias\"> ";}
					$PleskNS = "";
					foreach($DomainNS as $ns){
						$PleskNS=$PleskNS."<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" style=\"width: 16px;margin-top: -2px;\"> " .$ns."<br>";
					}

					$data[] = [
        			        'domain' => $DomainIcon . $DomainItem["name"],
        	        		'status' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off-state.png\" style=\"width: 16px;margin-top: -2px;\" title=\"".pm_Locale::lmsg('FoundKO')."\"> " . pm_Locale::lmsg('FoundKO'),
		                	'plan' => pm_Locale::lmsg('FoundKO'),
					'ns' => $PleskNS,
					'dev' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off-state.png\"  style=\"width: 16px;margin-top: -2px;\">",
					'do' => "<a class=\"btn\" rel=\"".$DomainItem["name"]."\" href=\"javascript:PleskExt.FlexFirewallManager.Cloudflare.create('".$DomainItem["name"]."')\"><img src=\"". pm_Context::getBaseUrl() ."img/icon/protected.png\" style=\"width: 16px;margin-top: -2px;\">".pm_Locale::lmsg('Create')."</a>",
					];
				}
	
			}else{
	
				$regin=$regin+1;

				Modules_FlexFirewallManager_Settings::PleskDomainAccountCF($checkdom->DomainName,Modules_FlexFirewallManager_Settings::UserCom());
	
				$status="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> " .pm_Locale::lmsg('on');
				$logindomain='<a href="' . $this->_helper->url('rules', 'cloudflare', null, ['domain' => $checkdom->DomainName]) . '" class="s-btn sb-login"><span>'.$checkdom->DomainName.'</span></a>';
        			if (!$checkdom->DomainStatus){
					$status="<img src=\"". pm_Context::getBaseUrl() ."img/icon/change-time.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"disabled\" title=\"".str_replace("%1",$checkdom->DomainRegistar,pm_Locale::lmsg('CloudFlare.DNSErrorDesc'))."\"><a id=\"whois".str_replace(".","",$checkdom->DomainName)."\" href=\"javascript:PleskExt.FlexFirewallManager.Cloudflare.whois('".$checkdom->DomainRegistar."')\">" . pm_Locale::lmsg('CloudFlare.DNSError') ."</a>";
					$logindomain=$checkdom->DomainName;
				} 
	


				$DomainNS=Modules_FlexFirewallManager_Settings::GetPleskDomainNS($checkdom->DomainName);
				$CFNS = "";
	
				if($DomainNS==null){
					foreach(explode(",",$checkdom->DomainNS) as $ns){
						$CFNS=$CFNS."<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> " .$ns."<br>";
					}
				}else{
					foreach(explode(",",$checkdom->DomainNS) as $ns){
						if($checkdom->DomainStatus){
							$CFNS=$CFNS."<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> " .$ns."<br>";
						}else{
							$CFNS=$CFNS."<img src=\"". pm_Context::getBaseUrl() ."img/icon/change-time.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"disabled\" title=\"".str_replace("%1",$checkdom->DomainRegistar,pm_Locale::lmsg('CloudFlare.DNSErrorDesc'))."\"> " .$ns."<br>";
						}
					}
				}
	
	
				$dev="<li><a href=\"".$this->_helper->url('setting', 'cloudflare', null, ['domain' => $checkdom->DomainName,'s' => 'development_mode','v' => 'on'])."\">".pm_Locale::lmsg('CloudFlare.Dev')."</a></li>";
				if($checkdom->Dev){$dev="";}
	
				$delete="<li data-img=\"clean-app-cache.png\"><a href=\"javascript:PleskExt.FlexFirewallManager.deleteAction('cloudflare/delete/domain/".$checkdom->DomainName."',null)\">".pm_Locale::lmsg('Cancel')."</a></li>";
				$dns="<li data-img=\"dns.png\"><a href=\"".$this->_helper->url('dns', 'cloudflare', null, ['domain' => $checkdom->DomainName])."\">DNS</a></li>";
				$cache="<li data-img=\"clean-app-cache.png\"><a href=\"".$this->_helper->url('setting', 'cloudflare', null, ['domain' => $checkdom->DomainName,'s' => 'cache','v' => 'clean'])."\">".pm_Locale::lmsg('CloudFlare.Cache')."</a></li>";
				$attack="<li data-img=\"warning.png\"><a href=\"".$this->_helper->url('setting', 'cloudflare', null, ['domain' => $checkdom->DomainName,'s' => 'security_level','v' => 'under_attack'])."\">".pm_Locale::lmsg('CloudFlare.SL.Attack')."</a></li>";
				$normal="<li data-img=\"on.png\"><a href=\"".$this->_helper->url('setting', 'cloudflare', null, ['domain' => $checkdom->DomainName,'s' => 'security_level','v' => 'medium'])."\">".pm_Locale::lmsg('CloudFlare.SL.Normal')."</a></li>";
				if($checkdom->Dev){$normal="<li data-img=\"on.png\"><a href=\"".$this->_helper->url('setting', 'cloudflare', null, ['domain' => $checkdom->DomainName,'s' => 'security_level','v' => 'normal'])."\">".pm_Locale::lmsg('CloudFlare.SL.Normal')."</a></li>";}

				$icondev=$checkdom->Dev ? "<br><span class=\"pul-label pul-label--sm pul-label--warning\"><span class=\"pul-label__content\">".pm_Locale::lmsg('CloudFlare.Dev')."</span></span>" : "";
				if(!$checkdom->DomainStatus){$icondev="";}

				$autodns="<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"disable\" title=\"".pm_Locale::lmsg('off')."\"> " . pm_Locale::lmsg('off');
				if($DomainItem["autodns"] == "1"){ $autodns="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> " . pm_Locale::lmsg('on');}
				if($DomainItem["type"]=="alias"){
					if($DomainItem["autodns"] == "1"){ 
						$autodns="<img src=\"". pm_Context::getBaseUrl() ."img/icon/alias.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"enabled\" title=\"Alias ".pm_Locale::lmsg('on')."\"> " . pm_Locale::lmsg('on');
					}else{
						$autodns="<img src=\"". pm_Context::getBaseUrl() ."img/icon/off-state.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"disable\" title=\"Alias\">";
					}
				}

				if ($checkdom->DomainStatus){
					if($checkdom->Dev){$status=$status.$icondev;}
				}


				$data[] = [
        		        'domain' => $logindomain,
                		'status' => $status,
	                	'plan' => $checkdom->DomainPlan,
				'ns' => $CFNS,
				'dns' => $autodns,
				'do' => (!$checkdom->DomainStatus) ? "<ul class=\"pul-button-group\" data-title=\"".pm_Locale::lmsg('PathConfig')."\" data-action=\"window.location='".$this->_helper->url('settings', 'cloudflare', null, ['domain' => $checkdom->DomainName])."';\" style=\"display:none\">".$dns.$delete."</ul>" : "<ul class=\"pul-button-group\" data-title=\"".pm_Locale::lmsg('PathConfig')."\" data-action=\"window.location='".$this->_helper->url('settings', 'cloudflare', null, ['domain' => $checkdom->DomainName])."';\" style=\"display:none\">".$dns.$cache.$dev.$attack.$normal."</ul>",
				];
	
			}
		}	
	} //result

	if($regin==0){
		if($this->app->CloudflareUserSetting==''){
			if(pm_Session::getClient()->hasPermission('firewall_ext_api')){
				$this->_status->addWarning(pm_Locale::lmsg('CloudFlare.LoginEmpty') . " <i>(".Modules_FlexFirewallManager_Settings::UserCom().")</i>",true);
			}else{
				$this->_status->addWarning(pm_Locale::lmsg('CloudFlare.LoginEmpty'),true);
			}
		}		
	}

 	$options = [
            'defaultSortField' => 'status',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 50,
        ];

	$list = new pm_View_List_Simple($this->view, $this->_request,$options);
        $list->setData($data);

	$list->setColumns([
        	    'domain' => [
	                'title' => pm_Locale::lmsg('Domain'),
        	        'noEscape' => true,
                	'sortable' => true,
	                'searchable' => false,
        	    ],
        	    'status' => [
	                'title' => pm_Locale::lmsg('status'),
        	        'noEscape' => true,
                	'sortable' => true,
	                'searchable' => false,
        	    ],
        	    'plan' => [
	                'title' => pm_Locale::lmsg('CloudFlare.Plan'),
        	        'noEscape' => true,
                	'sortable' => true,
	                'searchable' => false,
        	    ],
        	    'ns' => [
	                'title' => "Plesk NS",
        	        'noEscape' => true,
                	'sortable' => false,
	                'searchable' => false,
        	    ],
        	    'dns' => [
	                'title' =>  pm_Locale::lmsg('CloudFlare.AutoSync'),
        	        'noEscape' => true,
                	'sortable' => false,
	                'searchable' => false,
        	    ],
        	    'do' => [
	                'title' => pm_Locale::lmsg('actionsColumn'),
        	        'noEscape' => true,
                	'sortable' => false,
	                'searchable' => false,
        	    ],
        ]);



	$tools[] = [
	     'icon' => pm_Context::getBaseUrl() ."img/icon/login.png",
             'title' => pm_Locale::lmsg('PathConfig'),
             'description' => pm_Session::getClient()->hasPermission('firewall_ext_api') || Modules_FlexFirewallManager_Settings::AdminAuth() || Modules_FlexFirewallManager_Settings::ResellerAuth() ? Modules_FlexFirewallManager_Settings::UserCom() : "Cloudflare",
             'controller' => 'cloudflare',
             'link' => 'config',
	];


	$this->view->tools = $tools;
	$this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
	if(Modules_FlexFirewallManager_Settings::AdminAuth()){
		$this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
	}else{
	        $this->view->subtabs = [];
	}

	$this->view->list = $list;
        $list->setDataUrl(['action' => 'list-data-domain']);


	return $list;
    }

    public function listDataDomainAction(){
        $list = $this->indexAction();
        $this->_helper->json($list->fetchData());
    }


/**
 * Create setting account
**/
    public function configAction(){

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}


        $form = new Modules_FlexFirewallManager_CF_Config();


        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
		$ValProcess=$form->process();
                if($ValProcess==1){
	                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
		} elseif ($ValProcess==2) {
			$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
		}else{
	                $this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR')));
		}

            } catch (pm_Exception $e) {
                $this->_status->addError($e->getMessage());
            }
            $this->_helper->json(array('redirect' => 'index'));
        }

        $this->view->form = $form;
        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
    }


/**
 * Manage settings account
**/
    public function settingsAction(){

	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}


        $form = new Modules_FlexFirewallManager_CF_Settings();

	$formSL = $form->getSubForm("SubFormSL");
	$formSSL = $form->getSubForm("SubFormSSL");
	$formHSTS = $form->getSubForm("SubFormHSTS");

	$form->removeSubForm("SubFormSL");
	$form->removeSubForm("SubFormSSL");
	$form->removeSubForm("SubFormHSTS");

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
		$ValProcess=$form->process();
                if($ValProcess==1){
	                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
		} elseif ($ValProcess==2) {
			$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
		}else{
	                $this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR')));
		}

            } catch (pm_Exception $e) {
                $this->_status->addError($e->getMessage());
            }
            $this->_redirect(pm_Context::getBaseUrl() . 'index.php/cloudflare/index');
	    return;
        }

        $this->view->form = $form;
        $this->view->formSL = $formSL;
        $this->view->formSSL = $formSSL;
        $this->view->formHSTS = $formHSTS;
        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
    }

/**
 * Save one setting account
**/
    public function settingAction(){

	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

	if( $this->_getParam('s')=="cache" && $this->_getParam('v')=="clean" ){

		$appjson = json_decode($this->app->CloudFlareCache());

		if($appjson->result){
			$this->_status->addInfo(str_replace("%1","",pm_Locale::lmsg('statusOK')));
		}else{
			if(strpos($appjson->desc, "Pro Version")==false){
				$this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR')));
			}else{
				$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
			}
		}
		$this->_redirect('cloudflare/index');
		return;
	}


	$appjson = json_decode($this->app->CloudFlareDomainSetting($this->_getParam('s').",".$this->_getParam('v')));

	if($appjson->result){
		 $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
	}else{
		if(strpos($appjson->desc, "Pro Version")==false){
			$this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR')));
		}else{
			$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
		}
	}

	$this->_redirect('cloudflare/index');

    }

/**
 * Get Rules
**/

    public function rulesAction(){

	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}
 	$list = $this->_getRules();

	$tools = [];

	$tools[] = [
	       'title' => pm_Locale::lmsg('Enable'),
                'class' => 'sb-activate',
                'execGroupOperation' => $this->_helper->url('enable'),
            ];

	$tools[] = [
                'title' => pm_Locale::lmsg('Disable'),
                'class' => 'sb-disable',
                'execGroupOperation' => $this->_helper->url('disable'),
            ];

	$tools[] = [
                'title' => pm_Locale::lmsg('Delete'),
                'class' => 'sb-delete',
                'link' => 'javascript:PleskExt.FlexFirewallManager.deleteAction("cloudflare/remove/domain/'.$_SESSION[pm_Context::getModuleInfo()->name]['domain'].'")',
            ];


 	$list->setTools($tools);

        $this->view->list = $list;


        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }



   private function _getRules(){

	$data = [];

	try{
		$appjson = json_decode($this->app->GetRulesNames("CLOUDFLARE"));
	}catch(com_exception $e){
		if($e->getCode()==2147614729){
			Modules_FlexFirewallManager_Settings::SaveSetting("Job", "PleskUser");
                	$this->_redirect('index', [ 'exit' => true ]);
                	return;
		}		
	}

	if($appjson->result){
		foreach($appjson->rules as $rule){


			$disabledrule="";
			$typerule="Admin";
			$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/admin.png' style='margin:0px;padding:0px;border:none' title='".$rule->RuleName."'/> ";
			if( strpos($rule->RuleName, "Web")){$typerule="Web";$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/domain.png' style='margin:0px;padding:0px;border:none' title='".pm_Locale::lmsg('Domain')."' /> ";}
			if( strpos($rule->RuleName, "ASN")){$typerule="ASN";$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/ip-shared.png' style='margin:0px;padding:0px;border:none' title='ASN' /> ";}
			if( strpos($rule->RuleName, "Country")){$typerule="COUNTRY";$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/session.png' style='margin:0px;padding:0px;border:none' title='".pm_Locale::lmsg('TabCountryTitle')."' /> ";}

			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" alt=\"disabled\" title=\"".pm_Locale::lmsg('off')."\">";
			if($rule->RuleEnabled){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\">";}

			$link="<a href='javascript:' title='".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rule->RuleName)."' onclick='PleskExt.FlexFirewallManager.loadRule(\"cloudflare/rule/domain/".$_SESSION[pm_Context::getModuleInfo()->name]['domain']."\",\"".$rule->RuleName."\",".$rule->nip.")'>" . $typeimg . str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rule->RuleName) ."</a>";
			if($typerule=="COUNTRY"){$link="<a href='".$this->_helper->url('blacklistcountry', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']])."' title='".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rule->RuleName)."'>" . $typeimg . str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rule->RuleName) ."</a>";}

			if(!$rule->RuleEnabled || $typerule=="Admin"){$link=$typeimg . str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rule->RuleName);$disabledrule=" disabled";}
			if(Modules_FlexFirewallManager_Settings::isLicenced()){$disabledrule="";}


			$nip=$rule->nip;
			$iconIP="";
			if($typerule=="Admin"){
				$nip="-";
			}else{
				if($rule->rulemaxip){$iconIP=" <img src='". pm_Context::getBaseUrl() ."img/icon/info.png' style='margin:0px;padding:0px;border:none' title='".pm_Locale::lmsg('Rule.FULL')."'/> ";}
			}

			if($rule->RuleEnabled && $iconIP!=""){$icon=$iconIP;}

			$ports=($typerule=="Admin" ? "-" : "80,81,443");
			if($typerule=="COUNTRY"){$nip="-";$ports=pm_Locale::lmsg('Rule.ANY');}
			if($typerule=="ASN"){$nip="-";$ports=pm_Locale::lmsg('Rule.ANY');}

			if(Modules_FlexFirewallManager_Settings::AdminAuth()){

				 $data[] = [
        	        	'column-0' => '<input type="checkbox" class="checkbox" '.$disabledrule.' rel="'.$typerule.'" name="listCheckbox[]" value="'.$rule->RuleName.'"> ' . $icon,
                		'rule' => $link,
        	        	'type' => pm_Locale::lmsg('Rule.IN'),
	                	'action' => $typerule=="Admin" ? "-" : pm_Locale::lmsg('Rule.'.strtoupper($rule->RuleAction)),
        	        	'protocol' => pm_Locale::lmsg('Rule.ANY'),
                		'ports' => $ports,
                		'nip' => $nip
		            	];
			}

			if(Modules_FlexFirewallManager_Settings::ResellerAuth()){
				 $data[] = [
        	        	'column-0' => '<input type="checkbox" class="checkbox" '.$disabledrule.' rel="'.$typerule.'" name="listCheckbox[]" value="'.$rule->RuleName.'"> ' . $icon,
                		'rule' => $link,
        	        	'type' => pm_Locale::lmsg('Rule.IN'),
	                	'action' => $typerule=="Admin" ? "-" : pm_Locale::lmsg('Rule.'.strtoupper($rule->RuleAction)),
        	        	'protocol' => pm_Locale::lmsg('Rule.ANY'),
                		'ports' => $ports,
                		'nip' => $nip
		            	];
			}

			if(Modules_FlexFirewallManager_Settings::ClientAuth()){

				 $data[] = [
        	        	'column-0' => '<input type="checkbox" class="checkbox" '.$disabledrule.' rel="'.$typerule.'" name="listCheckbox[]" value="'.$rule->RuleName.'"> ' . $icon,
                		'rule' => $link,
	                	'action' => $typerule=="Admin" ? "-" : pm_Locale::lmsg('Rule.'.strtoupper($rule->RuleAction)),
        	        	'protocol' => pm_Locale::lmsg('Rule.ANY'),
                		'ports' => $ports,
                		'nip' => $nip
		            	];
			}



		}

		if(2 + count($data)>$appjson->maxrule){
			if(count($data)==$appjson->maxrule){
				$this->_status->addWarning(str_replace("%2",count($data),str_replace("%1",$appjson->maxrule,pm_Locale::lmsg('CloudFlare.PlanLimitRule')))." ".pm_Locale::lmsg('CloudFlare.PlanUpgrade'));
			}else{
				$this->_status->addWarning(str_replace("%2",count($data),str_replace("%1",$appjson->maxrule,pm_Locale::lmsg('CloudFlare.PlanLimitRule'))));
			}
		}

	}


 	$options = [
            'defaultSortField' => 'rule',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 50,
        ];

	$list = new pm_View_List_Simple($this->view, $this->_request,$options);
        $list->setData($data);



        	$list->setColumns([
	            'column-0' => [
        	        'title' => '',
                	'noEscape' => true,
	                'sortable' => false,
        	        'searchable' => false,
	            ],
        	    'rule' => [
                	'title' => pm_Locale::lmsg('Rule.Name'),
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => true,
	            ],
        	    'type' => [
                	'title' => pm_Locale::lmsg('Rule.Type'),
	                'noEscape' => true,
        	        'sortable' => true,
	            ],	
	 	   'action' => [
        	        'title' => pm_Locale::lmsg('Rule.Action'),
                	'noEscape' => true,
                	'sortable' => true,
	            ],
		 'protocol' => [
                	'title' => pm_Locale::lmsg('Rule.Protocol'),
	                'noEscape' => true,
        	        'sortable' => true,
	            ],
		 'ports' => [
	                'title' => pm_Locale::lmsg('Rule.Port'),
        	        'noEscape' => true,
                	'sortable' => true,
	            ],
 		'nip' => [
                	'title' => pm_Locale::lmsg('Rule.NIP'),
	                'noEscape' => true,
        	        'sortable' => true,
	            ],
        	]);




	$tools[] = [
		'icon' => pm_Context::getBaseUrl() ."img/icon/firewall.png",
		'title' => pm_Locale::lmsg('ToBlock'),
                'description' => 'Cloudflare',
		'link' => $this->_helper->url('add', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']]),
	];


	$appjson = json_decode($this->app->GetRulesNames());
	if($appjson->result){
		foreach($appjson->rules as $rules){
			if(str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rules->rulename)==$_SESSION[pm_Context::getModuleInfo()->name]['domain']){
				$tools[] = [
				'icon' => pm_Context::getBaseUrl() ."img/icon/recheck.png",
				'title' => pm_Locale::lmsg('Transfer'),
		                'description' => 'Cloudflare',
				'link' => $this->_helper->url('transfer', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']]),
				];
				break;
			}
		}
	}


	$tools[] = [
		'icon' => pm_Context::getBaseUrl() ."img/icon/session.png",
		'title' => pm_Locale::lmsg('TabCountryTitle'),
                'description' => 'Cloudflare',
		'link' => $this->_helper->url('blacklistcountry', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']]),
	];

	$this->view->tools = $tools;
        $list->setDataUrl(['action' => 'list-data-rules']);

	return $list;

   }

    public function listDataRulesAction(){
        $list = $this->_getRules();
        $this->_helper->json($list->fetchData());
    }

/**
 * Firewall Rule Page
**/

  public function ruleAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

	if($_SERVER['QUERY_STRING']==""){
		$this->_redirect('cloudflare/index');
	}

	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}


	if(strpos($_GET["rule"], "Web")==false && strpos($_GET["rule"], "ASN")==false){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('cloudflare/rules/domain/'.$_SESSION[pm_Context::getModuleInfo()->name]['domain'], [ 'exit' => true ]);
                return;
	}

 	$list = $this->_getIPs(urldecode($_GET["rule"]));
        $this->view->list = $list;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));



	$tools[] = [
		'icon' => pm_Context::getBaseUrl() ."img/icon/firewall.png",
		'title' => pm_Locale::lmsg('ToBlock'),
                'description' => 'Cloudflare',
		'link' => $this->_helper->url('add', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']])."?rule=".rawurlencode($_GET["rule"]),
	];
	

	$this->view->tools = $tools;

    }

   private function _getIPs($rule){

	$_SESSION[pm_Context::getModuleInfo()->name]['rule']=$rule;

	$data = [];
	$ASN = [];

	try{
		$appjson = json_decode($this->app->GetIPListFromRule(Modules_FlexFirewallManager_Settings::Ext . " - ASN","CLOUDFLARE"));
		if($appjson->result){

			foreach($appjson->list as $listip){
				$ASN[]=$listip->asn;
			}
		}
	}catch(com_exception $e){
		pm_Log::err("[" . $this->Ext . "] com_exception _getIPs " . $e->getCode() . " : " . $e->getMessage());
	}catch(exception $e){
		pm_Log::err("[" . $this->Ext . "] exception _getIPs " . $e->getCode() . " : " . $e->getMessage());
	}


	$appjson = json_decode($this->app->GetIPListFromRule($rule,"CLOUDFLARE"));

	if($appjson->result){

		foreach($appjson->list as $listip){

		$reputation="";
		$ip=str_replace("/128","",str_replace("/255.255.255.255","",$listip->ip));
		if(strpos($ip, '/')>0 || strpos($ip, '-')>0 || strpos($ip, '*')>0){
			// no cargar reputacion
		}else{
			if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip])){
				$reputation="<img src='". pm_Context::getBaseUrl() ."img/icon/indicator.gif' loading='lazy' border='0' class='reputation' alt='".$ip."'/>";
			}else{
				if($_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]!="NORMAL"){
					$reputation="<img src='". pm_Context::getBaseUrl() ."img/icon/warning.png' border='0' alt='".$ip."' rel='".$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]."'/> ".$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip];
				}
			}
		}

		$flag="<img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($listip->code). ".svg' loading='lazy' title='" .Modules_FlexFirewallManager_Settings::Country($listip->code). "' style='height:12px;margin:0px;padding:0px;border:none' /> ";
		if($listip->code==''){$flag='';}


		$asnlink=' <a href="javascript:" rel="'.$listip->asn.'" onclick="PleskExt.FlexFirewallManager.Cloudflare.BlockASN(\''.$listip->asn.'\',\''.$_SESSION[pm_Context::getModuleInfo()->name]['domain'].'\')" title="'.pm_Locale::lmsg('Rule.BLOCK').'"><img rel="'.$listip->asn.'" src="'. pm_Context::getBaseUrl() .'img/icon/firewall.png" loading="lazy"></a>';
		if(in_array($listip->asn, $ASN)){$asnlink=' <a href="?rule='.rawurlencode(Modules_FlexFirewallManager_Settings::Ext . " - ASN") .'" rel="'.$listip->asn.'" title="'.pm_Locale::lmsg('PathRulesF').'"><img rel="'.$listip->asn.'" src="'. pm_Context::getBaseUrl() .'img/icon/lock.png"></a>';}
		if(!Modules_FlexFirewallManager_Settings::AdminAuth()){$asnlink='';}
		if($listip->asn==''){$asnlink='';}
		if( strpos($rule , "ASN")>0){$asnlink='';}

		 $data[] = [
                	'column-0' => '<input type="checkbox" class="checkbox" name="listCheckbox[]" value="'.str_replace("/128","",str_replace("/255.255.255.255","",$listip->ip)).'"> ',
                	'column-1' => str_replace("/128","",str_replace("/255.255.255.255","",$listip->ip)),
                	'column-2' => $listip->code,
                	'column-3' => $flag . Modules_FlexFirewallManager_Settings::Country($listip->code),
                	'column-4' => $listip->isp,
                	'column-5' => $asnlink.$listip->asn,
                	'column-6' => $reputation,
	            ];
	        
	    	}        
	}

 	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('IP'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('IP_CCountry'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-3' => [
                'title' => pm_Locale::lmsg('IP_Country'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-4' => [
                'title' => pm_Locale::lmsg('IP_ISP'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-5' => [
                'title' => "ASN",
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-6' => [
                'title' => pm_Locale::lmsg('IP_Reputation'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
        ]);


	$tools = [];

	$tools[] = [
                'title' => pm_Locale::lmsg('Delete'),
                'class' => 'sb-delete',
                'description' => 'Cloudflare',
                'link' => 'javascript:PleskExt.FlexFirewallManager.deleteAction("cloudflare/remove-ip/domain/'.$_SESSION[pm_Context::getModuleInfo()->name]['domain'].'","'.$rule.'")',
       ];

       $list->setTools($tools);



        $list->setDataUrl(['action' => 'list-data-rule']);

        return $list;

    }

    public function listDataRuleAction(){
        $list = $this->_getIPs($_SESSION[pm_Context::getModuleInfo()->name]['rule']);
        $this->_helper->json($list->fetchData());
    }



    public function removeIpAction(){


	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}else{
		if(isset($_POST["domain"]))
			$this->app->CloudflareDomain = $_POST["domain"];
	}

	if($_SESSION[pm_Context::getModuleInfo()->name]['domain']==""){
		if(!$appjson->status){ 
      			$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'),true);
               		$this->_redirect('index', [ 'exit' => true ]);
			return;
		}
	}



        $messages = [];
        foreach ((array)$this->_getParam('ids') as $id) {

		$appjson = json_decode($this->app->UnlockIP($id,"CLOUDFLARE",$_GET["rule"]));

		if($appjson->result){
	       if(isset($_POST["do"]) && ($_POST["do"]=="search" || $_POST["do"]=="searchlist")){
		        $messages[] = ['status' => 'success', 'content' => str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".$id."</b>",pm_Locale::lmsg('ToSearch_IPDelete')))];
		    }else{
      			$this->_status->addMessage('info', str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".$id."</b>",pm_Locale::lmsg('IPDeleteOK'))),true);
		    }

		}else{
    		   if(isset($_POST["do"]) && ($_POST["do"]=="search" || $_POST["do"]=="searchlist")){
		      	 $messages[] = ['status' => 'error', 'content' => str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".$id."</b>",pm_Locale::lmsg('IPDeleteKO')))];
		    }else{
      			$this->_status->addMessage('error', str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".$id."</b>",pm_Locale::lmsg('IPDeleteKO'))),true);
		    }

		}
        }

        if(isset($_POST["do"]) && $_POST["do"]=="search"){
  	        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
	}else{
	         $this->_redirect('cloudflare/rule?rule='.$_GET["rule"]);
	}
       

    }


    public function enableAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('cloudflare/index', [ 'exit' => true ]);
                return;
	}



        $messages = [];
        foreach ((array)$this->_getParam('ids') as $id) {
		$appjson = json_decode($this->app->ChangeRuleStatus($id,true,"CLOUDFLARE"));


		if($appjson->result){
	            $messages[] = ['status' => 'info', 'content' => str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OnOK'))];
		}else{
	            $messages[] = ['status' => 'error', 'content' => str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OnKO'))];
		}
        }

        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
    }

   public function disableAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('cloudflare/index', [ 'exit' => true ]);
                return;
	}


        $messages = [];
        foreach ((array)$this->_getParam('ids') as $id) {
		$appjson = json_decode($this->app->ChangeRuleStatus($id,false,"CLOUDFLARE"));
		if($appjson->result){
	            $messages[] = ['status' => 'info', 'content' => str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OffOK'))];
		}else{
	            $messages[] = ['status' => 'error', 'content' => str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OffKO'))];
		}
        }

        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);

    }

    public function removeAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('cloudflare/index', [ 'exit' => true ]);
                return;
	}


	$domain=$this->_getParam('domain');

	if($domain>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}else{
		if(isset($_POST["domain"])){
			$this->app->CloudflareDomain = $_POST["domain"];
			$domain = $_POST["domain"];
		}
	}

	if($_SESSION[pm_Context::getModuleInfo()->name]['domain']==""){
		if(!$appjson->status){ 
      			$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'),true);
               		$this->_redirect('index', [ 'exit' => true ]);
			return;
		}
	}


        foreach ((array)$this->_getParam('ids') as $id) {
		$appjson = json_decode($this->app->DeleteRuleName($id,"CLOUDFLARE"));
		if($appjson->result){
		    $this->_status->addMessage('info', str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.DeleteOK')),true);
		}else{
		    $this->_status->addMessage('error', str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.DeleteKO')),true);
		}
        }

	$this->_redirect('cloudflare/rules/domain/'. $domain);


    }

/**
 * Add IP to Firewall
**/
    public function addAction(){

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}

	$rule="";

        $form = new Modules_FlexFirewallManager_CF_Add();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {

		$ValProcess=explode(";",$form->process());

		if(isset($_SESSION[pm_Context::getModuleInfo()->name]['rule'])){
			$rule=$_SESSION[pm_Context::getModuleInfo()->name]['rule'];
			unset($_SESSION[pm_Context::getModuleInfo()->name]['rule']);
		}

                if($ValProcess[0]=="IP"){
	                if($ValProcess[1]=="1"){
		                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
			} elseif ($ValProcess[1]=="2") {
				$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
			}else{
		                $this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR'))." (".$ValProcess[2].")");
			}
		}

                if($ValProcess[0]=="ASN"){
	                if($ValProcess[1]=="1"){
		                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
			} elseif ($ValProcess[1]=="2") {
				$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
			}else{
		                $this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR'))." (".$ValProcess[2].")");
			}
		}

            } catch (pm_Exception $e) {
                $this->_status->addError($e->getMessage());
            }
		if($ValProcess[0]=="IP"){
		    if(Modules_FlexFirewallManager_Settings::GetLength($rule)>0){
			$this->_helper->json(array('redirect' => $this->_helper->url('rule', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']])."?rule=".$rule));
		    }else{
			$this->_helper->json(array('redirect' => $this->_helper->url('rules', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']])));
		    }
		}

		 if($ValProcess[0]=="ASN"){
			$this->_helper->json(array('result' => $ValProcess[1],'desc' => pm_View_Status::getAllMessages(true)[0]['content']));
		}
            
        }

        $this->view->form = $form;
        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
    }


/**
 * List Dns Domain
**/

  public function dnssecAction(){
	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}

	$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
	$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];

	if(isset($_POST['change'])){
		$appjson = json_decode($this->app->CloudFlareUpdateDnssec($_POST['change']));
	}else{
		$appjson = json_decode($this->app->CloudFlareGetDnssec());
	}

	if($appjson->result){

		if(isset($_POST['change'])){
			if($_POST['change']=="1"){
				$dsitems = explode(" ",$appjson->ds);
				if(count($dsitems)>1){
					pm_ApiCli::call("dns",array("--add",$_SESSION[pm_Context::getModuleInfo()->name]['domain'],"-ds","".$dsitems[4]." ".$dsitems[5]." ".$dsitems[6]." ".$dsitems[7].""));
				}
			}

			if($_POST['change']=="0"){
				pm_ApiCli::call("dns",array("--del",$_SESSION[pm_Context::getModuleInfo()->name]['domain'],"-ds","".$dsitems[4]." ".$dsitems[5]." ".$dsitems[6]." ".$dsitems[7].""));
			}
		}

		$output[]=array('status' => 'info','msg' => $appjson->dnssec);
	}else{
		$output[]=array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')) . " (".$appjson->desc.")");
	}

	echo json_encode($output);
	exit;

  }


  public function deleteAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

	$this->app->CloudflareUserSetting=Modules_FlexFirewallManager_Settings::UserCom();
	if($this->app->CloudflareUserSetting==''){
		$output[]=array('status' => 'danger','msg' => pm_Locale::lmsg('CloudFlare.LoginEmpty'));
	}else{

		$appjson = json_decode($this->app->CloudFlareDelete($this->_getParam('domain')));

		if($appjson->result){
			$this->_status->addMessage('info',pm_Locale::lmsg('pageSaveOK'));
		}else{
			$this->_status->addMessage('error',str_replace("%1","",pm_Locale::lmsg('statusERROR')). "(".$appjson->desc.")");
		}
	}

		 	
	$this->_redirect('cloudflare/index', [ 'exit' => true ]);


  }
  public function dnsAction(){


	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}


	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}


 	$list = $this->_getDNS($_SESSION[pm_Context::getModuleInfo()->name]['domain']);
        $this->view->list = $list;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));


	$tools[] = [
		'icon' => pm_Context::getBaseUrl() ."img/icon/refresh.png",
                'title' => pm_Locale::lmsg('CloudFlare.DNSSyncNow'),
                'description' => 'Cloudflare',
             	'controller' => 'cloudflare',
             	'link' => "javascript:PleskExt.FlexFirewallManager.WaitMessage('<img src=\"". pm_Context::getBaseUrl() . "img/icon/indicator.gif\" loading=\"lazy\" title=\"\" border=\"0\"/> ". pm_Locale::lmsg('CloudFlare.DNSSyncNow') . "');window.location='". $this->_helper->url('syncdns', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']]) ."'",
       ];

	$tools[] = [
		'icon' => pm_Context::getBaseUrl() ."img/icon/dnssec.png",
                'title' => "DNSSEC",
                'description' => pm_Locale::lmsg('PathConfig'),
             	'controller' => 'cloudflare',
             	'link' => "javascript:PleskExt.FlexFirewallManager.Cloudflare.settingdnssec();",
       ];
	

	$form = new pm_Form_Simple();

	        $form->addElement('hidden', 'dnssec', [
	            'value' => $_SESSION[pm_Context::getModuleInfo()->name]['dnssec'],
	        ]);

        $this->view->form = $form;
	$this->view->tools = $tools;

    }


   public function syncdnsAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('cloudflare/index', [ 'exit' => true ]);
                return;
	}

	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}

	$txtdns = [];
	try{

		$regdns=Modules_FlexFirewallManager_Settings::GetPleskDomainDnsRecords($_SESSION[pm_Context::getModuleInfo()->name]['domain']);

		foreach($regdns as $dns){

			if($dns->getType()=="A" || $dns->getType()=="AAAA" || $dns->getType()=="TXT"){
				$txtdns[]=array($dns->getType(),substr($dns->getHost(), 0, -1),$dns->getValue(),"");
			}else{
				$txtdns[]=array($dns->getType(),substr($dns->getHost(), 0, -1),substr($dns->getValue(), 0, -1),$dns->getOption("option"));
			}
		}

	}catch(exception $e){
	}

	if(count($txtdns)>0){
		if(Modules_FlexFirewallManager_Cloudflare::syncDns($_SESSION[pm_Context::getModuleInfo()->name]['domain'],Modules_FlexFirewallManager_Settings::UserCom(),$txtdns)){
		 	$this->_status->addMessage('info',pm_Locale::lmsg('pageSaveOK'));
		}else{
		 	$this->_status->addMessage('error',str_replace("%1","",pm_Locale::lmsg('statusERROR')));
		}
	}else{
	 	$this->_status->addMessage('error',str_replace("%1","",pm_Locale::lmsg('statusERROR')));
	}

	$this->_redirect('cloudflare/dns/domain/'.$_SESSION[pm_Context::getModuleInfo()->name]['domain']);


   }

   public function syncountryAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('cloudflare/index', [ 'exit' => true ]);
                return;
	}


	$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
	$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];

	$appjson = json_decode($this->app->GetCountry());

	if($appjson->result){

		foreach($appjson->list as $country){
			
			$status=$country->status;
			if( $status == "L" ){$status="A";}
			$this->app->UpdateCountryLimit($country->code,$status,"CLOUDFLARE");
	        
	    	}

		$appjson = json_decode($this->app->UpdateCountryLimit("","","CLOUDFLARE"));

		if($appjson->result){
			$this->_status->addMessage('info',pm_Locale::lmsg('pageSaveOK'));
		}else{
			$this->_status->addMessage('error',str_replace("%1","",pm_Locale::lmsg('statusERROR')));
		}

	}else{
		$this->_status->addMessage('error',str_replace("%1","",pm_Locale::lmsg('statusERROR')));
	}

	$this->_redirect('cloudflare/blacklistcountry/domain/'.$_SESSION[pm_Context::getModuleInfo()->name]['domain']);

   }

   private function _getDNS($domainname){

	$this->app->CloudflareDomain = $domainname;

	$dataCF = [];

	$_SESSION[pm_Context::getModuleInfo()->name]['dnssec']="";

	$appjson = json_decode($this->app->CloudflareGetDNS());

	if($appjson->result){

		$_SESSION[pm_Context::getModuleInfo()->name]['dnssec']=$appjson->dnssec;

		if($_SESSION[pm_Context::getModuleInfo()->name]['dnssec']=="pending"){
			$this->_status->addWarning(pm_Locale::lmsg('CloudFlare.DNSSECpending'));
		}
		if($_SESSION[pm_Context::getModuleInfo()->name]['dnssec']=="active"){
			$this->_status->addInfo(pm_Locale::lmsg('CloudFlare.DNSSECactive'));
		}

		foreach($appjson->dns as $listdns){

		 $dataCF[] = [
                	'id' => $listdns->id,
                	'type' => $listdns->type,
                	'name' => $listdns->name,
                	'value' => $listdns->value,
                	'opciones' => ($listdns->type == "MX") ? $listdns->priority : "",
                	'proxy' => $listdns->proxy,
                	'cloudflare' => $listdns->cloudflare
	            ];
	        
	    	}
	}



	$data = [];
	$foundnotsync=false;
	try{


		$regdns=Modules_FlexFirewallManager_Settings::GetPleskDomainDnsRecords($domainname);

		foreach($regdns as $dns){

			if ( in_array($dns->getType(),["PTR", "HTTPS", "LOC", "CERT", "DNSKEY", "NAPTR", "SMIMEA", "SSHFP", "SVCB", "TLSA", "URI"]) ){continue;}

			$checkreg = Modules_FlexFirewallManager_Settings::CheckDnsExist($dataCF,[
			'type' => $dns->getType(),
                	'name' => substr($dns->getHost(), 0, -1),
                	'value' => $dns->getType()=="A" || $dns->getType()=="AAAA" || $dns->getType()=="TXT" ? $dns->getValue() : substr($dns->getValue(), 0, -1),
                	'opciones' => $dns->getOption("option")
	           	]);



			if(($dns->getType()=="NS") && (strpos($dns->getValue(),"cloudflare.com")!=false)){$checkreg=null;}
			if($dns->getType()=="DS"){$checkreg=null;}

			if($checkreg==null){

					if(($dns->getType()=="NS") && (strpos($dns->getValue(),"cloudflare.com")!=false)){
					 	$data[] = [
        	        			'sync' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off-state.png\"  title=\"".pm_Locale::lmsg('CloudFlare.DNSCloudDisabled')."\" style=\"width: 16px;margin-top: -2px;\">",
        	        			'type' => $dns->getType() == "MX" ? $dns->getType() ." (".$dns->getOption("option").")" : $dns->getType(),
	                			'name' => substr($dns->getHost(), 0, -1),
		                		'value' => $dns->getType()=="A" || $dns->getType()=="AAAA" || $dns->getType()=="TXT" ? $dns->getValue() : substr($dns->getValue(), 0, -1),
        		        		'option' => "",
		                		'inproxy' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off-state.png\"  title=\"".pm_Locale::lmsg('CloudFlare.DNSCloudDisabled')."\" style=\"width: 16px;margin-top: -2px;\">"
	        			 	];
					}elseif($dns->getType()=="DS"){
					 	$data[] = [
        	        			'sync' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/dnssec.png\"  title=\"DNSSEC\" style=\"width: 16px;margin-top: -2px;\">",
        	        			'type' => "DS",
	                			'name' => substr($dns->getHost(), 0, -1),
		                		'value' => $dns->getValue(),
        		        		'option' => "",
		                		'inproxy' => $_SESSION[pm_Context::getModuleInfo()->name]['dnssec']=="pending" ? "<img src=\"". pm_Context::getBaseUrl() ."img/icon/change-time.png\"  title=\"".pm_Locale::lmsg('CloudFlare.DNSCloudDisabled')."\" style=\"width: 16px;margin-top: -2px;\">" : "<img src=\"". pm_Context::getBaseUrl() ."img/icon/protected.png\"  title=\"".pm_Locale::lmsg('CloudFlare.DNSCloudDesc')."\" style=\"width: 16px;margin-top: -2px;\">"
	        			 	];
					}else{

						$foundnotsync=true;

						 $data[] = [
        	        			'sync' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" style=\"width: 16px;margin-top: -2px;\" title=\"".pm_Locale::lmsg('No')."\"> " . pm_Locale::lmsg('No'),
        	        			'type' => $dns->getType() == "MX" ? $dns->getType() ." (".$dns->getOption("option").")" : $dns->getType(),
	                			'name' => substr($dns->getHost(), 0, -1),
		                		'value' => $dns->getType()=="A" || $dns->getType()=="AAAA" || $dns->getType()=="TXT" ? $dns->getValue() : substr($dns->getValue(), 0, -1),
        		        		'option' => "",
		                		'inproxy' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" style=\"width: 16px;margin-top: -2px;\">"
	        			 	];
					}
			}else{


					 $data[] = [
						'sync' => "<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" style=\"width: 16px;margin-top: -2px;\" title=\"".pm_Locale::lmsg('Yes')."\"> " . pm_Locale::lmsg('Yes'),
        	        			'type' => $dns->getType() == "MX" ? $dns->getType() ." (".$dns->getOption("option").")" : $dns->getType(),
	                			'name' => substr($dns->getHost(), 0, -1),
		                		'value' => $dns->getType()=="A" || $dns->getType()=="AAAA" || $dns->getType()=="TXT" ? $dns->getValue() : substr($dns->getValue(), 0, -1),
        		        		'option' => "",
		        	        	'inproxy' => $dns->getType()=="A" || $dns->getType()=="AAAA" || $dns->getType()=="CNAME" ? "<input type=\"hidden\" data-action=\"PleskExt.FlexFirewallManager.Cloudflare.updateproxy\" data-icon-title=\"".pm_Locale::lmsg('CloudFlare.DNSCloudDesc')."\" data-icon=\"". pm_Context::getBaseUrl() ."img/icon/protected.png\" class=\"switch\" value=\"".($checkreg['cloudflare'] ? 1 : 0) ."\" id=\"".$checkreg['id']."\">" : "<img src=\"". pm_Context::getBaseUrl() ."img/icon/off-state.png\" title=\"".pm_Locale::lmsg('CloudFlare.DNSCloudDisabled')."\" style=\"width: 16px;margin-top: -2px;\">"
	        			 ];


			}



		}


	}catch(exception $e){
	}


	if($foundnotsync){
		$this->_status->addMessage('warning',pm_Locale::lmsg('CloudFlare.DNSSyncAlert'));
	}

 	$options = [
            'defaultSortField' => 'type',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'sync' => [
                'title' => pm_Locale::lmsg('CloudFlare.DNSSync'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'type' => [
                'title' => pm_Locale::lmsg('CloudFlare.DNSType'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'name' => [
                'title' => pm_Locale::lmsg('CloudFlare.DNSHost'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'value' => [
                'title' => pm_Locale::lmsg('CloudFlare.DNSValue'),
                'noEscape' => true,
                'sortable' => true,
                'css' => "dnsvalue",
                'searchable' => true,
            ],
            'inproxy' => [
                'title' => pm_Locale::lmsg('CloudFlare.DNSCloud'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
        ]);


        $list->setDataUrl(['action' => 'list-data-dns']);

        return $list;

    }

    public function listDataDnsAction(){
        $list = $this->_getDNS($_SESSION[pm_Context::getModuleInfo()->name]['domain']);
        $this->_helper->json($list->fetchData());
    }


    public function proxyAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_helper->json(array('status' => 'warning','msg' => pm_Locale::lmsg('statusPRO')));
                return;
	}

	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}

	$id="";
	if(isset($_POST["id"])){$id=$_POST["id"];}
	$py="";
	if(isset($_POST["py"])){$py=$_POST["py"];}
	$p="";
	if(isset($_POST["p"])){$p=$_POST["p"];}
	$w="";
	if(isset($_POST["w"])){$w=$_POST["w"];}
	$t="";
	if(isset($_POST["t"])){$t=$_POST["t"];}


	$opciones=$id . " " . $py . " " . $p . " " . $w . " " . $t;

	$txtdns[]=array($_POST["t"],$_POST["h"],$_POST["v"],$opciones);



	if(Modules_FlexFirewallManager_Cloudflare::ProxyDns($_SESSION[pm_Context::getModuleInfo()->name]['domain'],Modules_FlexFirewallManager_Settings::UserCom(),$txtdns,$_POST["proxy"])){
		$this->_helper->json(array('status' => 'success','msg' => pm_Locale::lmsg('pageSaveOK')));
	
	}else{
		$this->_helper->json(array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR'))));
	}


   }

    public function createAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_helper->json(array('status' => 'warning','msg' => pm_Locale::lmsg('statusPRO')));
                return;
	}

	$this->app->CloudflareUserSetting=Modules_FlexFirewallManager_Settings::UserCom();
	if($this->app->CloudflareUserSetting==''){
		$this->_helper->json(array('status' => 'danger','msg' => pm_Locale::lmsg('CloudFlare.LoginEmpty')));
	}else{

		$appjson = json_decode($this->app->CloudFlareCreate($this->_getParam('domain')));

		if($appjson->result){
			$this->_helper->json(array('status' => 'success','msg' => pm_Locale::lmsg('pageSaveOK')));
		}else{
			if($appjson->err=="400"){
				$this->_helper->json(array('status' => 'danger','msg' => pm_Locale::lmsg('Domain') . " : ". pm_Locale::lmsg('Error.RootDomain')));

			}else{
				$this->_helper->json(array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')). "(".$appjson->desc.")"));
			}
		}
	}


   }

    public function autosyncAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
		$this->_helper->json(array('status' => 'warning','msg' => pm_Locale::lmsg('statusPRO')));
                return;
	}

	if(Modules_FlexFirewallManager_Settings::GetLength($this->_getParam('domain'))>0){
		$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
		$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];
	}


	if($_POST["autosync"]==''){
		$this->_helper->json(array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')),'err' => 'post'));
	}else{


		if(Modules_FlexFirewallManager_Settings::PleskDomainAutoSyncCF($_SESSION[pm_Context::getModuleInfo()->name]['domain'],$_POST["autosync"])=="1"){
			$this->_helper->json(array('status' => 'success','msg' => pm_Locale::lmsg('pageSaveOK')));
		}else{
			$this->_helper->json(array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR'))));
		}
	}

   }


/**
 * Cline Windows Firewall to CloudFlare
**/
    public function transferAction(){

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

	$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');

        $form = new Modules_FlexFirewallManager_CF_Transfer();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {

		$ValProcess=$form->process();

	    	if($ValProcess=="1"){
		         $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
		} elseif ($ValProcess=="2") {
			$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
		}else{
		        $this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR')));
		}


            } catch (pm_Exception $e) {
                $this->_status->addError($e->getMessage());
            }

	    $this->_helper->json(array('redirect' => $this->_helper->url('rules', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']])));


            
        }

        $this->view->form = $form;
        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
    }




/**
 * BlackList Country Page
**/

   public function blacklistcountryAction(){

	$_SESSION[pm_Context::getModuleInfo()->name]['domain']=$this->_getParam('domain');
	$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('cloudflare/index', [ 'exit' => true ]);
                return;
	}

 	$list = $this->_getBlackCountry();
        $this->view->list = $list;



	$tools[] = [
		'icon' => pm_Context::getBaseUrl() ."img/icon/refresh.png",
                'title' => pm_Locale::lmsg('CloudFlare.DNSSyncNow'),
                'description' => 'Cloudflare',
             	'controller' => 'cloudflare',
             	'link' => $this->_helper->url('syncountry', 'cloudflare', null, ['domain' => $_SESSION[pm_Context::getModuleInfo()->name]['domain']]),
       ];
	
	$this->view->tools = $tools;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));




    }

  private function _getBlackCountry(){

	$data = [];


    	$appjson = json_decode($this->app->GetCountry("CLOUDFLARE"));


	if($appjson->result){

		foreach($appjson->list as $country){

			$status=pm_Locale::lmsg('Rule.ALLOW');
			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> ";
			if( $country->status == "B" ){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/lock.png\" alt=\"lock\"> ";$status= pm_Locale::lmsg('ToBlock');}


		 $data[] = [
                	'column-0' => '<input type="checkbox" class="checkbox" name="listCheckbox[]" value="'.$country->code.'"> ' . $icon,
                	'column-1' => $status,
                	'column-2' => Modules_FlexFirewallManager_Settings::Country($country->code),
                	'column-3' => $country->code." <img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($country->code). ".svg' loading='lazy' title='" .Modules_FlexFirewallManager_Settings::Country($country->code). "' style='height:12px;margin:0px;padding:0px;border:none' />",
	            ];
	        
	    	}        
	}


 	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_UP,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('status'),
                'noEscape' => true,
                'sortable' => true,
                 'searchable' => false,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('IP_Country'),
                'noEscape' => true,
                'sortable' => false,
                 'searchable' => true,
            ],
            'column-3' => [
                'title' => pm_Locale::lmsg('IP_CCountry'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => true,
            ],
        ]);


       $list->setTools([
            [
                'title' => pm_Locale::lmsg('Rule.BLOCK'),
                'class' => 'sb-lock',
                'execGroupOperation' => $this->_helper->url('blockcountry'),
            ],
 		[
                'title' => pm_Locale::lmsg('Rule.ALLOW'),
                'class' => 'sb-unlock',
                'execGroupOperation' => $this->_helper->url('allowcountry'),
            ],
        ]);



        $list->setDataUrl(['action' => 'list-data-blc']);

        return $list;

    }

    public function listDataBlcAction(){
        $list = $this->_getBlackCountry();
        $this->_helper->json($list->fetchData());
    }

  public function allowcountryAction(){


        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id,"A","CLOUDFLARE");
        }

    	$appjson = json_decode($this->app->UpdateCountryLimit("","","CLOUDFLARE"));

	if($appjson->result){

		$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        	$this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);

	}else{

		$messages[] = ['status' => 'error', 'content' => str_replace("%1","",pm_Locale::lmsg('statusERROR'))];
        	$this->_helper->json(['status' => 'danger', 'statusMessages' => $messages]);
	}

	$this->_redirect('blacklistcountry');

    }


   public function blockcountryAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id,"B","CLOUDFLARE");
        }

    	$appjson = json_decode($this->app->UpdateCountryLimit("","","CLOUDFLARE"));

	if($appjson->result){

		$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        	$this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);

	}else{

		$messages[] = ['status' => 'error', 'content' => str_replace("%1","",pm_Locale::lmsg('statusERROR'))];
        	$this->_helper->json(['status' => 'danger', 'statusMessages' => $messages]);
	}

	$this->_redirect('blacklistcountry');

    }

   public function availabledomainsAction(){

	$dataCF = [];

	try {
		$appjson = json_decode($this->app->CloudFlareDomains());
	}catch(com_exception $e){
               	return $this->_helper->json($dataCF);

	}

	if($appjson->result){

		$PleskDomains=Modules_FlexFirewallManager_Settings::GetAllDomains(true);

		foreach($appjson->domains as $domain){

			$found = false;
	                foreach ($PleskDomains as $dom) {
				if(strtolower($dom["name"])==$domain->DomainName){
					$found = true;
					break;
				}			
        	        }
			if($found){
			 	$dataCF[] = $domain->DomainName;
			}
	    	}  

	} //result

	return $this->_helper->json($dataCF);

    }

}

