<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk 
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */

/**
 * Class FirewallController
**/

class FirewallController extends pm_Controller_Action{

    private $app;
    
    public function __call($name, $arguments){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index?call', [ 'exit' => true ]);
                return;
    }

/**
 * init
**/
    public function init(){
        parent::init();

		//error_reporting(E_ALL);

		if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
			$this->_redirect('index/index');
			return;
		}

		if(Modules_FlexFirewallManager_Settings::ResellerAuth()){
	        	if(Modules_FlexFirewallManager_Settings::GetSetting("status_Reseller")!="1"){
				if(!Modules_FlexFirewallManager_Settings::isEnablePermission()){
	        	   		throw new pm_Exception(pm_Locale::lmsg('statusNO'));
				}
		        }
		}
		if(Modules_FlexFirewallManager_Settings::ClientAuth()){

			if(!empty($this->getRequest()->getParam('site_id'))){
				$_SESSION[pm_Context::getModuleInfo()->name]['site_id']=$this->getRequest()->getParam('site_id');

				if(empty($this->getRequest()->getParam('alias_id'))){
					unset($_SESSION[pm_Context::getModuleInfo()->name]['alias_id']);
				}else{
					$_SESSION[pm_Context::getModuleInfo()->name]['alias_id']=$this->getRequest()->getParam('alias_id');
				}

			}

			if(!empty($this->getRequest()->getParam('context'))){
				foreach (pm_Domain::getDomainsByClient(pm_Session::getClient(),true) as $domain) {
            				if ($domain->hasPermission('firewall_ext_enable')){
						$_SESSION[pm_Context::getModuleInfo()->name]['site_id']=$domain->getId();
						unset($_SESSION[pm_Context::getModuleInfo()->name]['alias_id']);
	                			break;
            				}
        			}
			}

			if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['site_id']) &&  Modules_FlexFirewallManager_Settings::GetSetting("status_Client")!="1"){
				if(!Modules_FlexFirewallManager_Settings::isEnablePermission()){
	        		    	throw new pm_Exception(pm_Locale::lmsg('statusNO'));
				}
			}
		}


        	/** @noinspection PhpUndefinedFieldInspection */
	        $this->view->pageTitle = pm_Locale::lmsg('pageTitle');

		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'flex-firewall-manager.css?'.Date('dmhYis'));

		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-library.js?'.Date('dmhYis'));
		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-firewall-manager.js?'.Date('dmhYis'));

		$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
    }


/**
 * Add IP to Firewall
**/
    public function addAction(){

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}


        $form = new Modules_FlexFirewallManager_FW_Add();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {

		$ValProcess=explode(";",$form->process());

		if(isset($_SESSION[pm_Context::getModuleInfo()->name]['rule'])){
			$rule=$_SESSION[pm_Context::getModuleInfo()->name]['rule'];
			unset($_SESSION[pm_Context::getModuleInfo()->name]['rule']);
		}

                if($ValProcess[0]=="IP"){
	                if($ValProcess[1]=="1"){
		                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
			} elseif ($ValProcess[1]=="2") {
				$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
			}else{
		                $this->_status->addError(str_replace("%1","<b>".pm_Locale::lmsg('ToBlock')."</b>",pm_Locale::lmsg('statusERROR'))." (".$ValProcess[2].")",true);
			}
		}

                if($ValProcess[0]=="ASN"){
	                if($ValProcess[1]=="1"){
		                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
			} elseif ($ValProcess[1]=="2") {
				$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
			}else{
		                $this->_status->addError(str_replace("%1","<b>ASN</b>",pm_Locale::lmsg('statusERROR'))." (".$ValProcess[2].")",true);
			}
		}

            } catch (pm_Exception $e) {
                $this->_status->addError($e->getMessage());
            }
		if($ValProcess[0]=="IP"){
		    if(Modules_FlexFirewallManager_Settings::GetLength($rule)>0){
			$this->_helper->json(array('redirect' => 'rule?rule='.$rule));
		    }else{
			$this->_helper->json(array('redirect' => 'index'));
		    }
		}

		 if($ValProcess[0]=="ASN"){
			$this->_helper->json(array('result' => $ValProcess[1],'desc' => pm_View_Status::getAllMessages(true)[0]['content']));
		}
            
        }

        $this->view->form = $form;
        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
    }


/**
 * Firewall Rules Page
**/
   public function indexAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";
	unset($_SESSION[pm_Context::getModuleInfo()->name]['rule']);

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

	if(Modules_FlexFirewallManager_Settings::AdminAuth()){

		if($this->_getParam('create')=="test"){
			$this->createrule("test");
			return;
		}

		if($this->_getParam('create')=="admin"){
			$this->createrule("admin");
			return;
		}

	}

 	$list = $this->_getRules();

        $this->view->list = $list;

	$tools = $this->_getTools(true,$list);
        $this->view->tools = $tools;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
	if(Modules_FlexFirewallManager_Settings::AdminAuth()){
	        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
	}else{
	        $this->view->subtabs = [];
	}
    }




public function _getTools($main,$list) {


	$data = [];

	if(isset($_GET["rule"])){$_SESSION[pm_Context::getModuleInfo()->name]['rule']=$_GET["rule"];}



	if (!Modules_FlexFirewallManager_Settings::AdminAuth() && (pm_Session::getClient()->hasPermission('firewall_ext_add') || Modules_FlexFirewallManager_Settings::GetSetting('status_ClientAdd')=="1")){

		if(Modules_FlexFirewallManager_Settings::ClientAuth()){

			if(Modules_FlexFirewallManager_Settings::GetSetting("status_ClientAdd")=="1" || pm_Domain::getByDomainId($_SESSION[pm_Context::getModuleInfo()->name]['site_id'])->hasPermission('firewall_ext_add')){
				$data[] = [
	        	        'icon' => pm_Context::getBaseUrl() ."img/icon/firewall.png",
        	        	'title' => pm_Locale::lmsg('ToBlock'),
	        	        'description' => 'Firewall',
	                	'link' => "add",
	        	    ];
			}
		}else{

	        	$data[] = [
        	        'icon' => pm_Context::getBaseUrl() ."img/icon/firewall.png",
                	'title' => pm_Locale::lmsg('ToBlock'),
	                'description' => 'Firewall',
	                'link' => "add",
        	    ];
		}
	}

	if(Modules_FlexFirewallManager_Settings::AdminAuth()){

	        $data[] = [
        	        'icon' => pm_Context::getBaseUrl() ."img/icon/firewall.png",
                	'title' => pm_Locale::lmsg('ToBlock'),
	                'description' => 'Firewall',
	                'link' => isset($_GET["rule"]) ? "add?rule=".urldecode($_GET["rule"]) : "add",
        	    ];


		if($main){

			$data[] = [
				'icon' => pm_Context::getBaseUrl() ."img/icon/session.png",
				'title' => pm_Locale::lmsg('TabCountryTitle'),
        		        'description' => 'Firewall',
				'link' => "blacklistcountry",
			];

			$testrule=false;		
			$adminrule=false;


			foreach($list->fetchData()["data"] as $rule){
				if($rule["rulename"]==Modules_FlexFirewallManager_Settings::Ext." - TEST"){$testrule=true;}
				if($rule["rulename"]==Modules_FlexFirewallManager_Settings::Ext . " - ADMIN"){$adminrule=true;}
				if($testrule && $adminrule){break;}
			}

			$setup_date=explode("-", Modules_FlexFirewallManager_Settings::GetSetting('setup_date'));

			if( count($setup_date)>1 && Date('Y-m-d') < Date('Y-m-d',strtotime(Date("Y-m-d", mktime(0, 0, 0, $setup_date[1], $setup_date[2], $setup_date[0])) . " +20 days")) ){
				if(!$testrule){
			            $data[] = [
        			        'icon' => pm_Context::getBaseUrl() ."img/icon/add.png",
                			'title' => pm_Locale::lmsg('Rule.Sample'),
	                		'description' => 'Firewall',
		                	'link' => "index/create/test",
	        		    ];
				}
			}

			if(!$adminrule){
		            $data[] = [
        		        'icon' => pm_Context::getBaseUrl() ."img/icon/add.png",
                		'title' => pm_Locale::lmsg('Rule.Admin'),
	                	'description' => 'Firewall',
		                'link' => "index/create/admin",
        		    ];
			}

		if(pm_Config::get('ExportImportRule')){
        	    $data[] = [
                	'icon' => pm_Context::getBaseUrl() ."img/icon/recheck.png",
	                'title' => pm_Locale::lmsg('Import'),
	                'description' => 'Firewall',
        	        'link' => 'javascript:StartImport()',
	            ];
		}
		}

	}else{
	}

	if(count($data)==0){$data=null;}

	 return $data;
    }


    /**
     * BlackList Country Page
     */
   public function blacklistcountryAction(){


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

 	$list = $this->_getBlackCountry();
        $this->view->list = $list;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));


    }

  private function _getBlackCountry(){

	$data = [];


    	$appjson = json_decode($this->app->GetCountry());

	if($appjson->result){

		foreach($appjson->list as $country){

			$status=pm_Locale::lmsg('Rule.ALLOW');
			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> ";
			if( $country->status == "L" ){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/security-scan.png\" alt=\"lock\"> ";$status= pm_Locale::lmsg('Rule.LIMIT');}
			if( $country->status == "B" ){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/lock.png\" alt=\"lock\"> ";$status= pm_Locale::lmsg('ToBlock');}

		 $data[] = [
                	'column-0' => '<input type="checkbox" class="checkbox" name="listCheckbox[]" value="'.$country->code.'"> ' . $icon,
                	'column-1' => $status,
                	'column-2' => Modules_FlexFirewallManager_Settings::FormatDateOutput($country->add,pm_Locale::lmsg('formatDate')),
                	'column-3' => Modules_FlexFirewallManager_Settings::Country($country->code),
                	'column-4' => $country->code." <img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($country->code). ".svg' loading='lazy' title='" .Modules_FlexFirewallManager_Settings::Country($country->code). "' style='height:12px;margin:0px;padding:0px;border:none' />",
	            ];
	        
	    	}        
	}


 	$options = [
            'defaultSortField' => 'column-2',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_UP,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('status'),
                'noEscape' => true,
                'sortable' => true,
                 'searchable' => false,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('DateAdd'),
                'noEscape' => true,
                'sortable' => true,
                 'searchable' => true,
            ],
            'column-3' => [
                'title' => pm_Locale::lmsg('IP_Country'),
                'noEscape' => true,
                'sortable' => false,
                 'searchable' => true,
            ],
            'column-4' => [
                'title' => pm_Locale::lmsg('IP_CCountry'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => true,
            ],
        ]);


       $list->setTools([
            [
                'title' => pm_Locale::lmsg('Rule.LIMIT'),
                'class' => 'sb-disable',
                'execGroupOperation' => $this->_helper->url('limitcountry'),
            ],
            [
                'title' => pm_Locale::lmsg('Rule.BLOCK'),
                'class' => 'sb-lock',
                'execGroupOperation' => $this->_helper->url('blockcountry'),
            ],
 		[
                'title' => pm_Locale::lmsg('Rule.ALLOW'),
                'class' => 'sb-unlock',
                'execGroupOperation' => $this->_helper->url('allowcountry'),
            ],
        ]);



        $list->setDataUrl(['action' => 'list-data-blc']);

        return $list;

    }


   public function allowcountryAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id);
        }


	$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
	$this->_redirect('blacklistcountry');

    }


   public function blockcountryAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){

		$appjson = json_decode($this->app->GetCountryLimit("B"));
		if($appjson->result){
			if(count($appjson->list)>2){
 				$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
	        	        $this->_redirect('blacklistcountry', [ 'exit' => true ]);
		                return;
			}

		}
	}


        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id,"B");
        }

	Modules_FlexFirewallManager_Settings::SaveSetting('Job', 'UpdateBlockCountry');


	$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
	$this->_redirect('blacklistcountry');

    }


   public function limitcountryAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){

		$appjson = json_decode($this->app->GetCountryLimit("L"));
		if($appjson->result){

			if(count($appjson->list)>2){
 				$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
	        	        $this->_redirect('blacklistcountry', [ 'exit' => true ]);
		                return;
			}

		}

	}

        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id,"L");
        }

	Modules_FlexFirewallManager_Settings::SaveSetting('Job', 'UpdateBlockCountry');

	$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
	$this->_redirect('blacklistcountry');

    }


    public function listDataBlcAction(){
	        $list = $this->_getBlackCountry();
        	$this->_helper->json($list->fetchData());
    }



/**
 * Firewall Rule Page
**/

  public function ruleAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";
	unset($_SESSION[pm_Context::getModuleInfo()->name]['rule']);

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

	if($_SERVER['QUERY_STRING']==""){
		$this->_redirect('firewall/index');
	}


	$allowrule=true;
	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
		$allowrule=Modules_FlexFirewallManager_Settings::AllowRule($_GET["rule"]);
	}

	if(!$allowrule){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('firewall/index', [ 'exit' => true ]);
                return;
	}

 	$list = $this->_getIPs(urldecode($_GET["rule"]));
        $this->view->list = $list;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

	$tools = $this->_getTools(false,$list);
        $this->view->tools = $tools;

    }


/**
 * List IP into Firewall Rule
**/
   private function _getIPs($rule){

	$_SESSION[pm_Context::getModuleInfo()->name]['rule']=$rule;

	$data = [];

	$appjson = json_decode($this->app->GetIPListFromRule($rule));

	if($appjson->result){

		foreach($appjson->list as $listip){

		$reputation="";
		$ip=str_replace("/128","",str_replace("/255.255.255.255","",$listip->ip));
		if(strpos($ip, '-')>0){
			$arrange=explode("-",$ip);
			if($arrange[0]==$arrange[1]){$ip=$arrange[0];}
		}


		if(strpos($ip, '/')>0 || strpos($ip, '-')>0 || strpos($ip, '*')>0){
			// no cargar reputacion
		}else{
			if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip])){
				$reputation="<img src='". pm_Context::getBaseUrl() ."img/icon/indicator.gif' loading='lazy' border='0' class='reputation' alt='".$ip."'/>";
			}else{
				if($_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]!="NORMAL"){
					$reputation="<img src='". pm_Context::getBaseUrl() ."img/icon/warning.png' loading='lazy' border='0' alt='".$ip."' rel='".$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]."'/> ".$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip];
				}
			}
		}

		$flag="<img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($listip->code). ".svg' loading='lazy' title='" .Modules_FlexFirewallManager_Settings::Country($listip->code). "' style='height:12px;margin:0px;padding:0px;border:none' /> ";
		if($listip->code==''){$flag='';}


		$asnlink=' <a href="javascript:" rel="'.$listip->asn.'" onclick="BlockASN(\''.$listip->asn.'\',\'WINDOWS\')" title="'.pm_Locale::lmsg('Rule.BLOCK').'"><img rel="'.$listip->asn.'" src="'. pm_Context::getBaseUrl() .'img/icon/firewall.png" loading="lazy"></a>';
		if(  strpos("0,".Modules_FlexFirewallManager_Settings::GetSetting('ASNBlackList').",0" , ",".$listip->asn.",") >0){$asnlink=' <a href="javascript:" onclick="PleskExt.FlexFirewallManager.loadRule(\'firewall/rule\',\'' . rawurlencode(Modules_FlexFirewallManager_Settings::Ext . " - ".$listip->asn) . '\',\'999\')" rel="'.$listip->asn.'" title="'.pm_Locale::lmsg('PathRulesF').'"><img rel="'.$listip->asn.'" src="'. pm_Context::getBaseUrl() .'img/icon/lock.png"></a>';}
		if(!Modules_FlexFirewallManager_Settings::AdminAuth()){$asnlink='';}
		if($listip->asn=='' || $listip->asn=='AS0'){$asnlink='';}
		if( strpos($rule , $listip->asn) >0){$asnlink='';}

		 $data[] = [
                	'column-0' => '<input type="checkbox" class="checkbox" name="listCheckbox[]" value="'.$listip->ip.'"> ',
                	'column-1' => $ip,
                	'column-2' => $listip->code,
                	'column-3' => $flag . Modules_FlexFirewallManager_Settings::Country($listip->code),
                	'column-4' => $listip->isp,
                	'column-5' => $asnlink.$listip->asn,
                	'column-6' => $reputation,
	            ];
	        
	    	}        
	}

 	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('IP'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('IP_CCountry'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-3' => [
                'title' => pm_Locale::lmsg('IP_Country'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-4' => [
                'title' => pm_Locale::lmsg('IP_ISP'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-5' => [
                'title' => "ASN",
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-6' => [
                'title' => pm_Locale::lmsg('IP_Reputation'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
        ]);


       $ToolsButtons = [];
       $ToolsButtons[] = [
                'title' => pm_Locale::lmsg('Delete'),
                'class' => 'sb-delete',
                'link' => 'javascript:PleskExt.FlexFirewallManager.deleteAction("firewall/remove-ip","'.$rule.'")',
       ];


	


	$appjsonVersion = json_decode(Modules_FlexFirewallManager_Settings::GetVersionCom($this->app));

	if($appjsonVersion->MailServer=="MailEnable"){
	
		if(strpos($rule,"SMTP")!==false){
	
		       		$ToolsButtons[] = [
        		        'title' => pm_Locale::lmsg('MailEnable.MoveIp'),
				'description' => 'MailEnable',
		                'class' => 'sb-move',
        		        'link' => 'javascript:PleskExt.FlexFirewallManager.moveAction("firewall/move-ip-mailenable","SMTP")',
            			];
		}

		if(strpos($rule,"POP")!==false){
		
       				$ToolsButtons[] = [
                		'title' => pm_Locale::lmsg('MailEnable.MoveIp'),
				'description' => 'MailEnable',
        		        'class' => 'sb-move',
                		'link' => 'javascript:PleskExt.FlexFirewallManager.moveAction("firewall/move-ip-mailenable","POP")',
	            		];
		}
	}



	$list->setTools($ToolsButtons);



        $list->setDataUrl(['action' => 'list-data-rule']);

        return $list;

    }

   private function _getRules(){

	$data = [];

	try{
	    	$appjson = json_decode($this->app->GetRulesNames());
	}catch(com_exception $e){
		if($e->getCode()==2147614729){
			Modules_FlexFirewallManager_Settings::SaveSetting("Job", "PleskUser");
                	$this->_redirect('index', [ 'exit' => true ]);
                	return;
		}		
	}
	
	$allowaction='checkbox';
	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){$allowaction='hidden';}

	if($appjson->result){

		foreach($appjson->rules as $rules){

			$typerule="Firewall";
			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" alt=\"disabled\" title=\"".pm_Locale::lmsg('off')."\">";
			if($rules->status){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\">";}

			$allowrule=true;

			if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
				$allowrule=Modules_FlexFirewallManager_Settings::AllowRule($rules->rulename);
			}

			if($allowrule){

			$cc=explode(" - ",$rules->rulename);
			$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/security.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."'/> ";
			$ccimg="";
			if(count($cc)==2){
				if(Modules_FlexFirewallManager_Settings::GetLength($cc[1])==2){
					$typerule=pm_Locale::lmsg('Country');
					$ccimg=" <img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($cc[1]). ".svg' loading='lazy' style='margin:0px;padding:0px;border:none' title='".Modules_FlexFirewallManager_Settings::Country($cc[1])."' />";
				}else{
					if(strpos($cc[1], ".")!=false){
						$typerule=pm_Locale::lmsg('Domain');
						$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/domain.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".pm_Locale::lmsg('Domain')." ".$rules->rulenamext."' /> ";
					}else{
						if(strpos($cc[1], "WEB")>0){
							$typerule=pm_Locale::lmsg('Domain');
							$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/domain.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".pm_Locale::lmsg('Domain')."' /> ";
						}
						if( strpos($cc[1], "DB")!=false || strpos($cc[1], "SQL")!=false ){
							$typerule="DB";
							$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/databases.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."'/> ";
						}
						if( substr($cc[1],0,4)=="IMAP" || substr($cc[1],0,4)=="SMTP" || substr($cc[1],0,3)=="POP" ){
							$typerule="MAIL";
							$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/mail.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."'/> ";
						}
						if(substr($cc[1],0,3)=="FTP"){
							$typerule="FTP";
							$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/ftp-access.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."'/> ";
						}
						if( strpos($cc[1], "Login")!=false || substr($cc[1],0,3)=="RDP" || strpos($cc[1], "Security")!=false ){
							$typeimg=" <img src='". pm_Context::getBaseUrl() ."img/icon/login.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."'/> ";
						}
						if(substr($cc[1],0,3)=="BOT"){
							$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/robot.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."'/> ";
						}
						if(substr($cc[1],0,3)=="DNS"){
							$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/dns.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."'/> ";
						}
						if(substr($cc[1],0,5)=="ADMIN"){
							$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/admin.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."'/> ";
						}
						if( substr($cc[1],0,2)=="AS" ){
							$typerule="ASN";
							$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/ip-shared.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".$rules->rulenamext."' /> ";
							if(substr($rules->rulenamext,-5)==" - ".substr($rules->rulenamext,-2)){
								$ccimg=" <img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($rules->country). ".svg' loading='lazy' style='margin:0px;padding:0px;border:none' title='".Modules_FlexFirewallManager_Settings::Country($rules->country)."' />";
							}
						}
					}
				}
			}

			if($rules->status){
				if($rules->numbersips >= $rules->rulemaxip){$icon="<img src='". pm_Context::getBaseUrl() ."img/icon/info.png' loading='lazy' style='margin:0px;padding:0px;border:none' title='".pm_Locale::lmsg('Rule.FULL')."'/> ";}
			}


			$webDomStatus = Modules_FlexFirewallManager_Settings::GetSetting("LockWEB_Domain",0);
			$colum5 = $typerule==pm_Locale::lmsg('Domain') ? "WEB , FTP , DNS" : str_replace("*",pm_Locale::lmsg('Rule.ANY'),$rules->ruleport);
			if($webDomStatus=="1" && $typerule==pm_Locale::lmsg('Domain') && $rules->status==false){
				$colum5 = $typerule==pm_Locale::lmsg('Domain') ? "WEB" : str_replace("*",pm_Locale::lmsg('Rule.ANY'),$rules->ruleport); 
				if(Modules_FlexFirewallManager_Settings::GetSetting("EnableModule",0)=="1"){
					$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\">";
				}else{
					$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/warning.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('MODULE.Error')."\">";
				}
			}


			if(Modules_FlexFirewallManager_Settings::AdminAuth()){

				 $data[] = [
	                	'rulename' => $rules->rulename,
	                	'iconImg' => $typeimg,
	                	'type' => $typerule,
	                	'NIP' => $rules->numbersips,
        	        	'column-0' => '<input type="checkbox" class="checkbox" rel="'.$typerule.'" name="listCheckbox[]" value="'.$rules->rulename.'"> ' . $icon,
                		'column-1' => '<a href="javascript:" title="'.$rules->rulename.'" onclick="PleskExt.FlexFirewallManager.loadRule(\'firewall/rule\',\''.$rules->rulename.'\',\''.$rules->numbersips.'\')">' . $typeimg . $rules->rulenamext .'</a>'. $ccimg,
        	        	'column-2' => pm_Locale::lmsg('Rule.'. $rules->ruletype),
	                	'column-3' => pm_Locale::lmsg('Rule.'. $rules->action),
        	        	'column-4' => pm_Locale::lmsg('Rule.' . $rules->ruleprotocol),
                		'column-5' => $colum5,
                		'column-6' => $rules->numbersips,
		            	];
			}

			if(Modules_FlexFirewallManager_Settings::ResellerAuth()){
				 $data[] = [
	                	'rulename' => $rules->rulename,
	                	'iconImg' => $typeimg,
	                	'type' => $typerule,
	                	'NIP' => $rules->numbersips,
        	        	'column-0' => '<input type="'.$allowaction.'" class="checkbox" rel="'.$typerule.'" name="listCheckbox[]" value="'.$rules->rulename.'"> ' . $icon,
                		'column-1' => '<a href="javascript:" onclick="PleskExt.FlexFirewallManager.loadRule(\'firewall/rule\',\''.$rules->rulename.'\',\''.$rules->numbersips.'\')">' . $typeimg . $rules->rulenamext .'</a>'. $ccimg,
        	        	'column-2' => pm_Locale::lmsg('Rule.'. $rules->ruletype),
	                	'column-3' => pm_Locale::lmsg('Rule.'. $rules->action),
        	        	'column-4' => pm_Locale::lmsg('Rule.' . $rules->ruleprotocol),
                		'column-5' => $colum5,
                		'column-6' => $rules->numbersips,
		            	];
			}

			if(Modules_FlexFirewallManager_Settings::ClientAuth()){

				 $data[] = [
	                	'rulename' => $rules->rulename,
	                	'iconImg' => $typeimg,
	                	'type' => $typerule,
	                	'NIP' => $rules->numbersips,
        	        	'column-0' => '<input type="'.$allowaction.'" class="checkbox" rel="'.$typerule.'" name="listCheckbox[]" value="'.$rules->rulename.'"> ' . $icon,
                		'column-1' => '<a href="javascript:" onclick="PleskExt.FlexFirewallManager.loadRule(\'firewall/rule\',\''.$rules->rulename.'\',\''.$rules->numbersips.'\')">' . $typeimg . $rules->rulenamext .'</a>'. $ccimg,
                		'column-5' => $colum5,
                		'column-6' => $rules->numbersips,
		            	];
			}


		    }
	        
	    	}        
	}


	if(count($data)==0 && Modules_FlexFirewallManager_Settings::ClientAuth()){
		$typeimg="<img src='". pm_Context::getBaseUrl() ."img/icon/domain.png' style='margin:0px;padding:0px;border:none' title='".pm_Locale::lmsg('Domain')."' /> ";

		if(isset($_SESSION[pm_Context::getModuleInfo()->name]['alias_id'])){

			 $data[] = [
             		'rulename' => $rules->rulename,
        		'column-0' => '<input type="hidden" class="checkbox" disabled rel="'.$typerule.'""> ' . $icon,
	       		'column-1' => $typeimg .  pm_DomainAlias::getByDomainAliasId($_SESSION[pm_Context::getModuleInfo()->name]['alias_id'])->getDisplayName(),
      			'column-5' => "WEB , FTP , DNS",
        	        'column-6' => 0,
	           	];
		}else{
			 $data[] = [
        	     	'rulename' => $rules->rulename,
        		'column-0' => '<input type="hidden" class="checkbox" disabled rel="'.$typerule.'""> ' . $icon,
	       		'column-1' => $typeimg .  pm_Domain::getByDomainId($_SESSION[pm_Context::getModuleInfo()->name]['site_id'])->getDisplayName(),
      			'column-5' => "WEB , FTP , DNS",
                	'column-6' => 0,
	           	];
		}
	
	}


 	$options = [
            'defaultSortField' => 'column-4',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 50,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);

	if(Modules_FlexFirewallManager_Settings::ClientAuth()){

	  $list->setColumns([
        	    'column-0' => [
	                'title' => '',
        	        'noEscape' => true,
                	'sortable' => false,
	                'searchable' => false,
        	    ],
	            'column-1' => [
        	        'title' => pm_Locale::lmsg('Rule.Name'),
                	'noEscape' => true,
	                'sortable' => false,
        	        'searchable' => true,
	            ],
		 'column-5' => [
                	'title' => pm_Locale::lmsg('Rule.Port'),
	                'noEscape' => true,
        	        'sortable' => false,
	            ],
 		'column-6' => [
                	'title' => pm_Locale::lmsg('Rule.NIP'),
	                'noEscape' => true,
        	        'sortable' => true,
	            ],
        	]);

	}else{
	
        	$list->setColumns([
	            'column-0' => [
        	        'title' => '',
                	'noEscape' => true,
	                'sortable' => false,
        	        'searchable' => false,
	            ],
        	    'column-1' => [
                	'title' => pm_Locale::lmsg('Rule.Name'),
	                'noEscape' => true,
        	        'sortable' => true,
                	'searchable' => true,
	            ],
        	    'column-2' => [
                	'title' => pm_Locale::lmsg('Rule.Type'),
	                'noEscape' => true,
        	        'sortable' => true,
	            ],	
	 	   'column-3' => [
        	        'title' => pm_Locale::lmsg('Rule.Action'),
                	'noEscape' => true,
                	'sortable' => true,
	            ],
		 'column-4' => [
                	'title' => pm_Locale::lmsg('Rule.Protocol'),
	                'noEscape' => true,
        	        'sortable' => true,
	            ],
		 'column-5' => [
	                'title' => pm_Locale::lmsg('Rule.Port'),
        	        'noEscape' => true,
                	'sortable' => true,
	            ],
 		'column-6' => [
                	'title' => pm_Locale::lmsg('Rule.NIP'),
	                'noEscape' => true,
        	        'sortable' => true,
	            ],
        	]);

	}

	if($allowaction!="checkbox"){
		$list->setTools([]);
	}else{

		$setTools = [];

       		$setTools[] = [
	         'title' => pm_Locale::lmsg('Enable'),
                'class' => 'sb-activate',
                'execGroupOperation' => $this->_helper->url('enable'),
            ];

       		$setTools[] = [
                'title' => pm_Locale::lmsg('Disable'),
                'class' => 'sb-disable',
                'execGroupOperation' => $this->_helper->url('disable'),
            ];

       		$setTools[] = [
                'title' => pm_Locale::lmsg('Delete'),
                'class' => 'sb-delete',
                'link' => 'javascript:PleskExt.FlexFirewallManager.deleteAction("firewall/remove")',
            ];


	if(pm_Config::get('ExportImportRule')){

       		$setTools[] = [
	       'title' => pm_Locale::lmsg('Export'),
                'class' => 'sb-backup' ,
                'execGroupOperation' => $this->_helper->url('export'),
            ];

	}


	$appjsonVersion = json_decode(Modules_FlexFirewallManager_Settings::GetVersionCom($this->app));

	if($appjsonVersion->MailServer=="MailEnable"){

		       	$setTools[] = [
                'title' => pm_Locale::lmsg('Transfer'),
                'description' => 'MailEnable',
                'class' => 'sb-move sb-hide',
                'execGroupOperation' => [
                    "url" => $this->_helper->url('tranferMailenable'),
                    "skipConfirmation" => false,
                    "locale" => [
                        "confirmOnGroupOperation" => pm_Locale::lmsg('MailEnable.MoveRuleConfirm'),
                    ],
                    "subtype" => "toggle",
                ],
            ];
	}



	       $list->setTools($setTools);
	}


        $list->setDataUrl(['action' => 'list-data-rules']);

        return $list;

    }





    public function listDataRuleAction(){
	        $list = $this->_getIPs(urldecode($_SESSION[pm_Context::getModuleInfo()->name]['rule']));
        	$this->_helper->json($list->fetchData());
    }
    public function listDataRulesAction(){
	        $list = $this->_getRules();
        	$this->_helper->json($list->fetchData());
    }

 

    public function enableAction(){


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
		$appjson = json_decode($this->app->FirewallStatus);

		if($appjson->result){
			if(!$appjson->status){ 
            			$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
				$this->_redirect('index', [ 'exit' => true ]);
				return;
			}
		}
	}

        $messages = [];
        foreach ((array)$this->_getParam('ids') as $id) {
		$appjson = json_decode($this->app->ChangeRuleStatus($id,true));
		if($appjson->result){
	            $messages[] = ['status' => 'info', 'content' => str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OnOK'))];
		}else{
	            $messages[] = ['status' => 'error', 'content' => str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OnKO'))];
		}
        }

        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
    }

   public function disableAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
		$appjson = json_decode($this->app->FirewallStatus);

		if($appjson->result){
			if(!$appjson->status){ 
            			$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
                		$this->_redirect('index', [ 'exit' => true ]);
				return;
			}
		}
	}

        $messages = [];

        foreach ((array)$this->_getParam('ids') as $id) {
		$appjson = json_decode($this->app->ChangeRuleStatus($id,false));
		if($appjson->result){
	            $messages[] = ['status' => 'info', 'content' => str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OffOK'))];
		}else{
	            $messages[] = ['status' => 'error', 'content' => str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OffKO'))];
		}
        }

        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);

    }

    public function removeIpAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
		$appjson = json_decode($this->app->FirewallStatus);
	
		if($appjson->result){
			if(!$appjson->status){ 
				if(isset($_POST["do"]) && $_POST["do"]=="search"){
			                $messages[] = ['status' => 'error', 'content' => pm_Locale::lmsg('statusKO')];
			  	        $this->_helper->json(['status' => 'error', 'statusMessages' => $messages]);
				}else{
	            			$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
        	        		$this->_redirect('index', [ 'exit' => true ]);
				}
				return;
			}
		}
	}

        $messages = [];

        foreach ((array)$this->_getParam('ids') as $id) {

		$appjson = json_decode($this->app->UnlockIP($id,"WINDOWS",$_GET["rule"]));

		if($appjson->result){
	            if(isset($_POST["do"]) && $_POST["do"]=="search"){
		            $messages[] = ['status' => 'success', 'content' => str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".str_replace("/128","",str_replace("/255.255.255.255","",$id))."</b>",pm_Locale::lmsg('ToSearch_IPDelete')))];
		   } elseif (isset($_POST["do"]) && $_POST["do"]=="searchlist"){
		            $messages[] = ['status' => 'success', 'content' => str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".str_replace("/128","",str_replace("/255.255.255.255","",$id))."</b>",pm_Locale::lmsg('IPDeleteOK')))];
		    }else{
			    $this->_status->addMessage('info', str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".str_replace("/128","",str_replace("/255.255.255.255","",$id))."</b>",pm_Locale::lmsg('IPDeleteOK'))),true);
		    }
		}else{
		    if(isset($_POST["do"]) && ($_POST["do"]=="search" || $_POST["do"]=="searchlist")){
		            $messages[] = ['status' => 'error', 'content' => str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".str_replace("/128","",str_replace("/255.255.255.255","",$id))."</b>",pm_Locale::lmsg('IPDeleteKO')))];
		    }else{
			    $this->_status->addMessage('error', str_replace("%2",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),str_replace("%1","<b>".str_replace("/128","",str_replace("/255.255.255.255","",$id))."</b>",pm_Locale::lmsg('IPDeleteKO'))),true);
		    }

		}
        }

    if(isset($_POST["do"]) && ($_POST["do"]=="search" || $_POST["do"]=="searchlist")){
  	        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
	}else{
	        $this->_redirect('firewall/rule?rule='.$_GET["rule"]);
	}


    }


    public function tranfermailenableAction(){


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
		$appjson = json_decode($this->app->FirewallStatus);
	
		if($appjson->result){
			if(!$appjson->status){ 
            			$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
        	        	$this->_redirect('index', [ 'exit' => true ]);
				return;
			}
		}
	}

	$rule = $this->_getParam('ids')[0];

	$appjson = json_decode($this->app->TransferFWtoMailEnable($rule,str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rule)));

	if($appjson->result){
		$this->_status->addMessage('info', str_replace("%1","",pm_Locale::lmsg('statusOK')));
	}else{
		$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
	}

	$this->_redirect('index', [ 'exit' => true ]);


    }

    public function moveIpMailenableAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
		$appjson = json_decode($this->app->FirewallStatus);
	
		if($appjson->result){
			if(!$appjson->status){ 
				if(isset($_POST["do"]) && $_POST["do"]=="search"){
			                $messages[] = ['status' => 'error', 'content' => pm_Locale::lmsg('statusKO')];
			  	        $this->_helper->json(['status' => 'error', 'statusMessages' => $messages]);
				}else{
	            			$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
        	        		$this->_redirect('index', [ 'exit' => true ]);
				}
				return;
			}
		}
	}

        $listAdd = [];

        foreach ((array)$this->_getParam('ids') as $id) {

		$appjson = json_decode($this->app->BlockIp($id,"MAILENABLE",$_GET["rule"]));

		if($appjson->result){
			$listAdd[] = $id;

		}
        }

        foreach ((array)$listAdd as $id) {
		$this->app->UnlockIP($id,"WINDOWS",Modules_FlexFirewallManager_Settings::Ext . " - " . $_GET["rule"]);
	}


        $this->_redirect('firewall/rule?rule=' . Modules_FlexFirewallManager_Settings::Ext . " - " . $_GET["rule"]);

    }


    public function removeAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
		$appjson = json_decode($this->app->FirewallStatus);

		if($appjson->result){
			if(!$appjson->status){ 
            			$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
                		$this->_redirect('index', [ 'exit' => true ]);
				return;
			}
		}
	}

        $messages = [];
        foreach ((array)$this->_getParam('ids') as $id) {
		$appjson = json_decode($this->app->DeleteRuleName($id));
		if($appjson->result){
			if(strpos($id, " - AS")!=false){
				$asn=explode(" - ",$id);
				$asnlist=str_replace(",".$asn[1].",", ",", ",".Modules_FlexFirewallManager_Settings::GetSetting('ASNBlackList').",");
				$asnlist=substr($asnlist, 1,-1);
				$asnlist=str_replace(",," , "," , $asnlist);
				$asnlist=str_replace(" " , "" , $asnlist);
				Modules_FlexFirewallManager_Settings::SaveSetting('ASNBlackList', $asnlist);
			}
			
		    $this->_status->addMessage('info', str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.DeleteOK')),true);
		}else{

		    $this->_status->addMessage('error', str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.DeleteKO')),true);
		}
        }

	$this->_redirect('firewall/index');

    }




    public function DownLoadExport(){


    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\export-rule.bin";

		return $fileManager->fileGetContents($filePath);
    }

    public function exportAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}


	$appjson = json_decode($this->app->FirewallStatus);

	if($appjson->result){
		if(!$appjson->status){ 
            		$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
	                $this->_redirect('index', [ 'exit' => true ]);
			return;
		}
	}

        $messages = [];
        foreach ((array)$this->_getParam('ids') as $id) {
		$fileData=$this->app->ExportFirewallRule($id);


    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\export-rule.bin";

        	if($fileManager->fileExists($filePath)){
            		$fileManager->removeFile($filePath);
        	}

		$fileManager->filePutContents($filePath, $fileData);     

        }


	$messages[] = ['status' => 'info', 'content' =>  str_replace("%2","</a>",str_replace("%1","<a href=\"javascript:ToDownload('public/?export')\">",pm_Locale::lmsg('ExportFile')))];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);


    }


    public function createrule($opt){

	$appjson = json_decode($this->app->FirewallStatus);

	if($appjson->result){
		if(!$appjson->status){ 
            		$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
	                $this->_redirect('index', [ 'exit' => true ]);
			return;
		}
	}

	if($opt=="test"){$appjson = json_decode($this->app->CreateTestRule);}
	if($opt=="admin"){$appjson = json_decode($this->app->CreateAdminRule);}


	if($appjson->result){
            	$this->_status->addMessage('info', pm_Locale::lmsg('Rule.OnOK'));
	}else{
            	$this->_status->addMessage('error', pm_Locale::lmsg('Rule.OnKO'));
	}

	$this->_redirect('firewall/index', [ 'exit' => true ]);

    }

   public function availablerulesAction(){

		$dataCF = [];

	        $list = $this->_getRules();

		foreach($list->fetchData()["data"] as $rule){
			$dataCF[] = [ 'name' => str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rule["rulename"]) , 'iconImg' => str_replace("margin:0px;","margin:0px;max-height: 16px;",$rule["iconImg"]) , 'type' => $rule["type"] , 'nIP' => $rule["NIP"]];
		}

        	return $this->_helper->json($dataCF);

    }

}

