<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk 
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk 
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */

/**
 * Class IndexController
**/

class IndexController extends pm_Controller_Action{

    private $app;
    

    public function __call($name, $arguments){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index?call', [ 'exit' => true ]);
                return;
    }

    /**
     * INIT
     */
    public function init(){
        parent::init();

		//error_reporting(E_ALL);

		/*Check Permission*/

		if($this->getRequest()->getParam('action')!= "index" && Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
			if(Modules_FlexFirewallManager_Settings::AdminAuth()){
				$this->_redirect('index/index');
				return;
			}else{
				throw new pm_Exception(pm_Locale::lmsg('statusNO'));
			}
		}

		if(Modules_FlexFirewallManager_Settings::ResellerAuth()){
	        	if(Modules_FlexFirewallManager_Settings::GetSetting("status_Reseller")!="1"){
				if(!Modules_FlexFirewallManager_Settings::isEnablePermission()){
	        	   		throw new pm_Exception(pm_Locale::lmsg('statusNO'));
				}
		        }
		}
		if(Modules_FlexFirewallManager_Settings::ClientAuth()){

			if(!empty($this->getRequest()->getParam('site_id'))){
				$_SESSION[pm_Context::getModuleInfo()->name]['site_id']=$this->getRequest()->getParam('site_id');

				if(empty($this->getRequest()->getParam('alias_id'))){
					unset($_SESSION[pm_Context::getModuleInfo()->name]['alias_id']);
				}else{
					$_SESSION[pm_Context::getModuleInfo()->name]['alias_id']=$this->getRequest()->getParam('alias_id');
				}

			}

			if(!empty($this->getRequest()->getParam('context'))){
				foreach (pm_Domain::getDomainsByClient(pm_Session::getClient(),true) as $domain) {
            				if ($domain->hasPermission('firewall_ext_enable')){
						$_SESSION[pm_Context::getModuleInfo()->name]['site_id']=$domain->getId();
						unset($_SESSION[pm_Context::getModuleInfo()->name]['alias_id']);
	                			break;
            				}
        			}
			}

			if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['site_id']) &&  Modules_FlexFirewallManager_Settings::GetSetting("status_Client")!="1"){
				if(!Modules_FlexFirewallManager_Settings::isEnablePermission()){
	        		    	throw new pm_Exception(pm_Locale::lmsg('statusNO'));
				}
			}
		}


        	/** Load Title, Link , Script */
	        $this->view->pageTitle = pm_Locale::lmsg('pageTitle');

		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'flex-firewall-manager.css?'.Date('dmhYis'));

		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-library.js?'.Date('dmhYis'));
		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-firewall-manager.js?'.Date('dmhYis'));

		/** Create Link to FirewallBrain */
		$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

		if($_SERVER['QUERY_STRING']=="restore"){
			$this->_status->addMessage('info', str_replace("%1","<b>".pm_Locale::lmsg('Migrate.Restore')."</b>",pm_Locale::lmsg('statusOK')),true);
		}

    }





    /**
     * Setup Page
     * @Detect if FirewallBrain cannot load and redirect to main page
     */
	public function setupAction(){

		if(!Modules_FlexFirewallManager_Settings::isJob()){

			if($this->app==null){
				$this->_redirect('index');
			}
		}
	
	}


    /**
     * Job Page
     * @Show html message (template) and page reload 5 times before show exception
     *
     * @param $monitors
     * @param $timespan
     *
     * @return array
     */
	public function jobAction(){
	}



    /**
     * Index Page - IndexStatus
     * @Show green bar status to admin account (StatusGreenBar)
     */
    public function IndexStatus(){


	$output="";

	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init" || Modules_FlexFirewallManager_Settings::GetSetting("Job")=="PleskUser"){
		return $output;
		return;
	}

	if(Modules_FlexFirewallManager_Settings::AdminAuth()){

		if($this->app!=null){
			try{
				$appjson = json_decode(Modules_FlexFirewallManager_Settings::GetVersionCom($this->app));
			}
			catch(com_exception $e){
				$output=$output. "<p><b>" . pm_Locale::lmsg('COMVersion') . "</b> : " . pm_Locale::lmsg('COMVersionKO')  ."</p>";
				return;
			}catch(exception $e){
				return $output;
				return;
			}
			$msglicense="";
			if(pm_Config::get('ShowLicense')){$output="<div class='table-license'>";}else{$output="<div class='table'>";}
			$output=$output."<div><b>" . pm_Locale::lmsg('User') . "</b> : " . Modules_FlexFirewallManager_Settings::UserCom()."</div>";
			$output=$output."<div><b>" . pm_Locale::lmsg('COMEMS'). "</b> : " . $appjson->MailServer . "</div>";
		        if (Modules_FlexFirewallManager_Settings::IsLicenced()){$msglicense=pm_Locale::lmsg('AppProFull').$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo'];}else{$msglicense=pm_Locale::lmsg('AppProBasic') . " - <a href='index.php/index/upgrade'>".pm_Locale::lmsg('Upgrade')."</a>";} 
			if(pm_Config::get('ShowLicense')){ $output=$output."<div><b>" . pm_Locale::lmsg('AppPro'). "</b> : " . $msglicense. "</div>"; }
			$output=$output. "</div>";
		}else{ 
			$output=$output. "<p><b>" . pm_Locale::lmsg('COMVersion') . "</b> : " . pm_Locale::lmsg('COMVersionKO')  ."</p>";
		}
	}

return $output;

}


    /**
     * Debug Page. Show Main Settings
     * @Show debug information for admin account
     */
    public function debugAction(){
		if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
			throw new pm_Exception('Permission denied');
		}

	$form = new Modules_FlexFirewallManager_Form_Debug();

        $this->view->form = $form;
   }



    /**
     * Index Page. Show Main Settings
     */
    public function indexAction(){

	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){

		$this->_status->addMessage('info', pm_Locale::lmsg('InitInfo'));

		if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
			throw new pm_Exception('Permission denied');
		}
	}else{

		if($this->app==null){
			$this->_redirect('index/setup');
		}
	
		if(Modules_FlexFirewallManager_Settings::isJob()){
			$this->_redirect('index/job');
		}

		if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
			$this->_redirect('index/firewall');
		}
	}

	if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['InitInfo'])){$this->_status->addMessage('info', pm_Locale::lmsg('InitInfo'));$_SESSION[pm_Context::getModuleInfo()->name]['InitInfo']=1;}

	/*Show StatusGreenBar*/
	$this->view->Status=self::IndexStatus();

	/*Get RDP AutoBlock*/
	$this->view->RDP=Modules_FlexFirewallManager_Settings::GetSetting("status_RDP");

        $form = new Modules_FlexFirewallManager_Form_Settings();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
		if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
			$result=$form->process();
			if($result!="OK"){
				$this->_status->addError($result);
			}
                	$this->_helper->json(array('redirect' => pm_Context::getBaseUrl()));

		}else{
			$this->_helper->json($form->process());
		}

            } catch (pm_Exception $e) {
		$this->_helper->json(array('status' => 'danger','msg' => $e->getMessage()));
            }

        }

        $this->view->form = $form;
        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getSettingTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
    }


    /**
     * Firewall Page. Show Firewall Settings
     */
    public function firewallAction(){

	if($_SERVER['QUERY_STRING']=="abuse"){
		$this->_helper->json(array('msg' => Modules_FlexFirewallManager_AbuseIP::CheckLogin($_POST['key'])));
		return;
	}

	if($_SERVER['QUERY_STRING']=="rdp"){

		$result = "error";

		if($_POST['op']=="deny"){
			if(Modules_FlexFirewallManager_Settings::isLicenced()){
				$result = pm_ApiCli::callSbin('FlexFirewallSetup.exe',array("/denyAC",$_POST['ac']));
			}else{
				$result = "license";
			}
		}else{
			$result = pm_ApiCli::callSbin('FlexFirewallSetup.exe',array("/allowAC",$_POST['ac']));
		}
		sleep(2);
		$this->_helper->json(array('msg' => "done",'log' => $result));
		return;
	}
	

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

        $form = new Modules_FlexFirewallManager_Form_Firewall();

	$formSMTP = $form->getSubForm("SubFormSMTP");
	$formIMAP = $form->getSubForm("SubFormIMAP");
	$formPOP = $form->getSubForm("SubFormPOP");
	$formFTP = $form->getSubForm("SubFormFTP");
	$formSecurity = $form->getSubForm("SubFormSecurity");
	$formDB = $form->getSubForm("SubFormDB");
	$formRDP = $form->getSubForm("SubFormRDP");
	$formAbuse = $form->getSubForm("SubFormAbuse");

	$form->removeSubForm("SubFormSMTP");
	$form->removeSubForm("SubFormIMAP");
	$form->removeSubForm("SubFormPOP");
	$form->removeSubForm("SubFormFTP");
	$form->removeSubForm("SubFormSecurity");
	$form->removeSubForm("SubFormDB");
	$form->removeSubForm("SubFormRDP");
	$form->removeSubForm("SubFormAbuse");

	if(Modules_FlexFirewallManager_Settings::GetSetting("EnableAbuseIP","1")!="1"){$formAbuse = null;}



        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
                
		if($form->process()){
			if(!Modules_FlexFirewallManager_Settings::isLicenced()){
				//$this->_status->addWarning(pm_Locale::lmsg('pageSaveBasic'));
				$messages[] = ['status' => 'warning', 'msg' => pm_Locale::lmsg('pageSaveBasic')];
			}
			$messages[] = ['status' => 'success', 'msg' => pm_Locale::lmsg('pageSaveOK')];
			$this->_helper->json($messages);
		}else{
			$messages[] = ['status' => 'error', 'msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR'))];
			$this->_helper->json($messages);
		}

            } catch (pm_Exception $e) {
		$messages[] = ['status' => 'error', 'msg' => $e->getMessage()];
		$this->_helper->json($messages);
            }
	    //$this->_helper->json(array('redirect' => 'firewall'));
        }

        $this->view->form = $form;
	$this->view->formSMTP = $formSMTP;
	$this->view->formIMAP = $formIMAP;
	$this->view->formPOP = $formPOP;
	$this->view->formFTP = $formFTP;
	$this->view->formSecurity = $formSecurity;
	$this->view->formDB = $formDB;
	$this->view->formRDP = $formRDP;
	$this->view->formAbuse = $formAbuse;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

	if(!Modules_FlexFirewallManager_Settings::ClientAuth()){
		$this->view->Status=self::IndexStatus();
	        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getSettingTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
	}
    }



    /**
     * Web Page. Show Web Settings IIS
     */
    public function webAction(){


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

        $form = new Modules_FlexFirewallManager_Form_Web();

	$formWEB = $form->getSubForm("SubFormWEB");
	$form->removeSubForm("SubFormWEB");

	$formRULE = $form->getSubForm("SubFormRULE");
	$form->removeSubForm("SubFormRULE");

	$formMOD = $form->getSubForm("SubFormMOD");
	$form->removeSubForm("SubFormMOD");

	$formDom = $form->getSubForm("SubFormDom");
	$form->removeSubForm("SubFormDom");

	$formSSL = $form->getSubForm("SubFormSSL");
	$form->removeSubForm("SubFormSSL");

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
                
		if($form->process()){
			if(!Modules_FlexFirewallManager_Settings::isLicenced()){
				$messages[] = ['status' => 'warning', 'msg' => pm_Locale::lmsg('pageSaveBasic')];
			}
			$messages[] = ['status' => 'success', 'msg' => pm_Locale::lmsg('pageSaveOK')];
			$this->_helper->json($messages);

		}else{
			$messages[] = ['status' => 'error', 'msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR'))];
			$this->_helper->json($messages);
		}

            } catch (pm_Exception $e) {
		$messages[] = ['status' => 'error', 'msg' => $e->getMessage()];
		$this->_helper->json($messages);

            }

	    //$this->_helper->json(array('redirect' => 'web'));
        }

        $this->view->form = $form;
	$this->view->formWEB = $formWEB;
	$this->view->formRULE = $formRULE;
	$this->view->formMOD = $formMOD;
	$this->view->formDom = $formDom;
	$this->view->formSSL = $formSSL;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

	if(!Modules_FlexFirewallManager_Settings::ClientAuth()){
		$this->view->Status=self::IndexStatus();
	        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getSettingTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
	}
    }


    /**
     * Add IP to White List
     */
    public function addwlAction(){


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}


        $form = new Modules_FlexFirewallManager_Form_AddWL();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
		$ValProcess=$form->process();
                if($ValProcess=="1"){
	                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
		} elseif ($ValProcess=="2") {
			$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
		}else{
	                $this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR')) . " (".$ValProcess.")");
		}

            } catch (pm_Exception $e) {
                $this->_status->addError($e->getMessage());
            }
            $this->_helper->json(array('redirect' => 'whitelist'));
        }

        $this->view->form = $form;
        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
    }







    /**
     * Search Page. Find the IP in any Firewall Rules
     */
    public function searchAction(){

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}


        $form = new Modules_FlexFirewallManager_Form_Search();

	$listview=(isset($_SESSION[pm_Context::getModuleInfo()->name]['searchlist']) ? $_SESSION[pm_Context::getModuleInfo()->name]['searchlist'] : null);
	$script=(isset($_SESSION[pm_Context::getModuleInfo()->name]['searchscript']) ? $_SESSION[pm_Context::getModuleInfo()->name]['searchscript'] : "");
	$_SESSION[pm_Context::getModuleInfo()->name]['searchscript']="";
	$_SESSION[pm_Context::getModuleInfo()->name]['searchlist']="";


        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
                
		$appjson = json_decode($form->process());

		if($appjson->result){

				$todelete=true;
				$countList = count($appjson->list);

		                $this->_status->addInfo(pm_Locale::lmsg('ToSearch_IPOK'));
	
				if($countList==1){
	
					$apptype=$appjson->list[0]->app;
	
					if(strtoupper($apptype)=="WINDOWS"){
						if(!Modules_FlexFirewallManager_Settings::AllowRule($appjson->list[0]->rule)){$todelete=false;}
					}
	
					if(strtoupper($apptype)=="SYSTEM"){
						if(Modules_FlexFirewallManager_Settings::AdminAuth()){$apptype="Windows";}else{$todelete=false;}
					}
					$blockCountry=!(strpos($appjson->list[0]->rule,"Service")===false);
					$subject=pm_Locale::lmsg('TabSearchTitle') . " : " . $this->_getParam('ipadress');
					$content="<div id='searchbody'>";
					$content=$content."<b>" . pm_Locale::lmsg('status') . "</b> : " . pm_Locale::lmsg('ToSearch_IPOK');
					$content=$content."<br><b>APP:</b> " . $apptype;
					if($apptype=="Cloudflare"){$content=$content."<br><b>" . pm_Locale::lmsg('Domain') . "</b> : " . $appjson->list[0]->domain;}
					if(Modules_FlexFirewallManager_Settings::GetLength($appjson->countrycode)>0 && strtoupper($apptype)!="SYSTEM"){$content=$content."<br><b>" . pm_Locale::lmsg('IP_CCountry') . "</b> : " . $appjson->countrycode . " <img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($appjson->countrycode). ".svg' loading='lazy' style='height:12px;margin:0px;padding:0px;border:1px solid;margin-top:-3px' />";}
					if(Modules_FlexFirewallManager_Settings::GetLength($appjson->countrycode)>0 && strtoupper($apptype)!="SYSTEM"){$content=$content."<br><b>" . pm_Locale::lmsg('IP_Country') . "</b> : " . Modules_FlexFirewallManager_Settings::Country($appjson->countrycode);}

					if(!$todelete && Modules_FlexFirewallManager_Settings::AdminAuth()){$todelete=true;}
	
					if($todelete){

						if($blockCountry){
							$content=$content."<br><b>" . pm_Locale::lmsg('Rule.Name') . "</b> : " . pm_Locale::lmsg('Blocked') . " {" . Modules_FlexFirewallManager_Settings::Country($appjson->countrycode)."}";
							$content=$content."<br>";
						}else{
							$content=$content."<br><b>" . pm_Locale::lmsg('Rule.Name') . "</b> : " . str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$appjson->list[0]->rule);
							$content=$content."<br><b>Mask</b> : " . $appjson->list[0]->mask;
						}
							$content=$content."<br><p align=\\\"center\\\"><a class=\\\"pul-button pul-button--primary sb-scan\\\" href=\\\"javascript:\\\" onclick=\\\"deleteip(this,'".$apptype."','".$appjson->list[0]->mask."','".$appjson->list[0]->rule."','".$appjson->list[0]->domain."')\\\">".pm_Locale::lmsg('Delete')."</a></p>";
					}else{	
						if($blockCountry){
							$content=$content."<br><b>" . pm_Locale::lmsg('Rule.Name') . "</b> : " . pm_Locale::lmsg('Blocked') . " {" . Modules_FlexFirewallManager_Settings::Country($appjson->countrycode)."}";
						}else{
							$content=$content."<br><b>" . pm_Locale::lmsg('Rule.Name') . "</b> : " . str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$appjson->list[0]->rule);							
						}

						$content=$content."<br><p align=\\\"center\\\"><a class=\\\"pul-button pul-button--disabled pul-button--primary sb-scan\\\" href=\\\"javascript:\\\" title=\\\"".pm_Locale::lmsg('statusNO')."\\\">".pm_Locale::lmsg('Delete')."</a></p>";
					}
				
					$content=$content."</div>";
	
	
					$_SESSION[pm_Context::getModuleInfo()->name]['searchscript']="new Jsw.Popup({title:\"" . $subject . "\",content:\"" . $content . "\",closeButtonEnabled:true});";
					$_SESSION[pm_Context::getModuleInfo()->name]['searchip']=$this->_getParam('ipadress');
				
				}else{

					$data = [];
					$icountList=0;
					foreach($appjson->list as $list){
		
						$todelete=true;
						$apptype=$list->app;
	
						if(strtoupper($apptype)=="WINDOWS"){
							if(!Modules_FlexFirewallManager_Settings::AllowRule($appjson->list[0]->rule)){$todelete=false;}
						}
			
						if(strtoupper($apptype)=="SYSTEM"){
							if(Modules_FlexFirewallManager_Settings::AdminAuth()){$apptype="Windows";}else{$todelete=false;}
						}

						$domain="";
						if(strpos($list->rule, ".")!=false){
							$domain=str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$list->rule);
						}else{
							if($list->domain!="OS"){$domain=$list->domain;}
						}

						$data[] = [
							'type' => "list",
		                			'id' => "<a class=\"pul-button pul-button--primary sb-scan\" href=\"javascript:\" onclick=\"deletelistip(this,'".$list->app."','".$list->mask."','".$list->rule."','".$domain."')\">".pm_Locale::lmsg('Delete')."</a>",
				                	'ip' => $appjson->ip,
				                	'mask' => $list->mask,
			        	        	'app' => $list->app,
		        	        		'rule' => str_replace("-DENY","",str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$list->rule)),
		                			'domain' => $domain,
					        ];	
	
						$icountList++;
				    	}        
	
	
					$_SESSION[pm_Context::getModuleInfo()->name]['searchlist']=json_encode($data);
					$_SESSION[pm_Context::getModuleInfo()->name]['searchip']=$this->_getParam('ipadress');
	
  				}
			

		}else{
	                $this->_status->addInfo(pm_Locale::lmsg("ToSearch_IPKO"));
		}

            } catch (pm_Exception $e) {
                $this->_status->addError($e->getMessage());
            }
		$this->_helper->json(array('redirect' => 'search'));
	}

		if($listview!=null){


				$data = [];
				foreach(json_decode($listview) as $list){

						$data[] = [
	                			'column-0' => $list->id,
			                	'column-1' => $list->ip,
			                	'column-2' => $list->app,
		        	        	'column-3' => $list->rule,
		                		'column-4' => $list->domain,
					        ];

				}

			 	$optionsview = [
				    'pageable' => false,
				    'defaultItemsPerPage' => 200,
			        ];

				$listview = new pm_View_List_Simple($this->view, $this->_request, $optionsview);
			        $listview->setData($data);


				        $listview->setColumns([
				            'column-0' => [
				                'title' => '',
		        			'noEscape' => true,
			        	        'sortable' => false,
			                	'searchable' => false,
				            ],
				            'column-1' => [
				                'title' => pm_Locale::lmsg('IP'),
		        			'noEscape' => true,
			        	        'sortable' => false,
			                	'searchable' => false,
				            ],
				            'column-2' => [
				                'title' => pm_Locale::lmsg('Rule.Type'),
		        			'noEscape' => true,
			        	        'sortable' => false,
			                	'searchable' => false,
				            ],
				            'column-3' => [
				                'title' => pm_Locale::lmsg('Rule.Name'),
		        			'noEscape' => true,
			        	        'sortable' => false,
			                	'searchable' => false,
				            ],
				            'column-4' => [
				                'title' => pm_Locale::lmsg('Domain'),
		        			'noEscape' => true,
			        	        'sortable' => false,
			                	'searchable' => false,
				            ],
	
				        ]);
				

			       $listview->setDataUrl(['action' => 'list-data-search']);    
		}

	$this->view->form = $form;
	$this->view->list = $listview;
	$this->view->script = $script;
	$this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }



    /**
     * Whitelist Page
     */
   public function whitelistAction(){


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

 	$list = $this->_getWhiteList();
        $this->view->list = $list;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }


  private function _getWhiteList(){

	$data = [];

    	$appjson = json_decode($this->app->GetWhiteList());

	if($appjson->result){
		
		foreach($appjson->list as $list){

			$data[] = [
                	'column-0' => '<input type="checkbox" class="checkbox" name="listCheckbox[]" value="'.$list->ip.'"> ',
                	'column-1' => $list->ip,
        	        'column-2' => Modules_FlexFirewallManager_Settings::FormatDateOutput($list->add,pm_Locale::lmsg('formatDate')),
        	        'column-3' => $list->date=='' ? pm_Locale::lmsg('LockPermanent') : Modules_FlexFirewallManager_Settings::FormatDateOutput($list->date,pm_Locale::lmsg('formatDate') . " " . "hh:mm"),
		        ];	        
	    	}        
	}


 	$options = [
            'defaultSortField' => 'column-2',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('IP'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('DateAdd'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-3' => [
                'title' => pm_Locale::lmsg('Date'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => true,
            ],
        ]);


       $list->setTools([[
                'title' => pm_Locale::lmsg('ResetWhiteList'),
                'class' => 'sb-restart',
                'link' => "javascript:PleskExt.FlexFirewallManager.confirmAction('index/whilelistreset','delete',PleskExt.FlexFirewallManager.Config.Lang.ConfirmAdd)",
		'description' => pm_Locale::lmsg('ResetWhiteListDesc'),
            ],
	   [
                'title' => pm_Locale::lmsg('Add'),
                'class' => 'sb-add-new',
                'link' => "addwl",
		'description' => pm_Locale::lmsg('AddWhiteList'),
            ],
            [
                'title' => pm_Locale::lmsg('Delete'),
                'class' => 'sb-delete',
                'link' => "javascript:PleskExt.FlexFirewallManager.deleteAction('index/whilelistdelete')",
            ],
        ]);


        $list->setDataUrl(['action' => 'list-data-wl']);

        return $list;

    }

   public function whilelistresetAction(){


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

    	$appjson = json_decode($this->app->GetWhiteList());

	if($appjson->result){		
		foreach($appjson->list as $list){
			$this->app->DeleteWhiteList($list->ip);		        
	    	}        
	}

        foreach (explode(",",Modules_FlexFirewallManager_Setup::GetIPList()) as $id) {
		$this->app->AddWhiteList($id);
        }


        $this->_status->addMessage('info', pm_Locale::lmsg('pageSaveOK'));
	$this->_redirect('index/whitelist');

    }

   public function whilelistdeleteAction(){


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->DeleteWhiteList($id);
        }


        $this->_status->addMessage('info', pm_Locale::lmsg('pageSaveOK'));
	$this->_redirect('index/whitelist');

    }

    public function listDataWlAction(){
	        $list = $this->_getWhiteList();
        	$this->_helper->json($list->fetchData());
    }


    /**
     * Logs Page
     */
   public function logsAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if($this->_getParam('clean')=="all"){$this->app->CleanLogs();$this->_redirect('index/logs');}

        $form = new Modules_FlexFirewallManager_Form_Logs();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
		$this->_helper->json($form->process());
            } catch (pm_Exception $e) {
		$this->_helper->json(array('status' => 'danger','msg' => $e->getMessage()));
            }
	    return;
        }

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

 	$list = $this->_getLogsList();

        $list->setTools([[
                'title' => pm_Locale::lmsg('Clean'),
                'class' => 'sb-clean',
                'link' => "logs/clean/all",
		'description' => pm_Locale::lmsg('TabSettingLogClean'),
            ]
        ]);

        $this->view->list = $list;

	$this->view->Status=self::IndexStatus();

        $this->view->form = $form;

	$tools[] = [];
       	$this->view->tools = $tools;



        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getSettingTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }



  private function _getLogsList(){

	$data = [];

	try{
	    	$appjson = json_decode($this->app->GetLogs());

		$EnableLOGPlesk=Modules_FlexFirewallManager_Settings::GetSetting("EnableLOGPlesk");

		if($appjson->result){

			$icount=1;
	
			foreach($appjson->logs as $log){

				$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/info.png\"> ";
				if($log->id==1){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/security-scan.png\" loading=\"lazy\" title=\"".pm_Locale::lmsg('attemps')."\"> ";}
				if($log->id==2){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/firewall.png\" loading=\"lazy\" title=\"".pm_Locale::lmsg('Rule.BLOCK')."\"> ";}
				if($log->id==3){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/firewall-unlock.png\" loading=\"lazy\" title=\"".pm_Locale::lmsg('Rule.ALLOW')."\"> ";}
				if($log->id==5 || $log->id==7){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/debug.png\" loading=\"lazy\" title=\"DEBUG\"> ";}

				if(strpos($log->description,"Login Manager")>1){$log->id=9;$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/domain.png\" loading=\"lazy\" title=\"".pm_Locale::lmsg('User')."\"> ";}
				if($log->level==2){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/warning.png\" loading=\"lazy\" title=\"ERROR\"> ";}
			
				if($EnableLOGPlesk=="1"){
					 $data[] = [
        		        		'column-order' => $icount,
                				'column-id' => $icon,
                				'column-datetime' => $log->datetime,
        		        		'column-user' => $log->account,
	                			'column-ip' => $log->id==9 ? pm_Locale::lmsg('User') : $log->ip,
	        		        	'column-desc' => str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",str_replace("\n","<br>",$log->description)),
				            ];
				}else{
					 $data[] = [
        		        		'column-order' => $icount,
                				'column-id' => $icon,
                				'column-datetime' => $log->datetime,
	                			'column-ip' => $log->id==9 ? pm_Locale::lmsg('User') : $log->ip,
	        		        	'column-desc' => str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",str_replace("\n","<br>",$log->description)),
				            ];
				}

				$icount++;
        
		    	}        
		}


	}catch(exception $e){
	}

	$options = [
	    'defaultSortField' => 'column-order'
	];

	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);

	if($EnableLOGPlesk=="1"){
	        $list->setColumns([
        	    'column-order' => [
                	'title' => 'ID',
	                'noEscape' => false,
        	        'sortable' => true,
                	'searchable' => false,
	            ],
        	    'column-id' => [
                	'title' => '',
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => false,
	            ],
        	    'column-datetime' => [
                	'title' => pm_Locale::lmsg('Date'),
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => true,
	            ],
        	    'column-user' => [
                	'title' => pm_Locale::lmsg('User'),
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => true,
	            ],
        	    'column-ip' => [
                	'title' => pm_Locale::lmsg('IP'),
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => true,
	            ],
        	    'column-desc' => [
                	'title' => "",
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => true,
	            ],
	        ]);
	}else{
	        $list->setColumns([
        	    'column-order' => [
                	'title' => 'ID',
	                'noEscape' => false,
        	        'sortable' => true,
                	'searchable' => false,
	            ],
        	    'column-id' => [
                	'title' => '',
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => false,
	            ],
        	    'column-datetime' => [
                	'title' => pm_Locale::lmsg('Date'),
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => true,
	            ],
        	    'column-ip' => [
                	'title' => pm_Locale::lmsg('IP'),
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => true,
	            ],
        	    'column-desc' => [
                	'title' => "",
	                'noEscape' => true,
        	        'sortable' => false,
                	'searchable' => true,
	            ],
	        ]);
	}


        $list->setDataUrl(['action' => 'list-data-gl']);

        return $list;

    }

    public function listDataGlAction(){
	        $list = $this->_getLogsList();
        	$this->_helper->json($list->fetchData());
    }


    /**
     * Mailenable Page
     */
   public function mailenableAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}


	$appjson = json_decode(Modules_FlexFirewallManager_Settings::GetVersionCom($this->app));

	if($appjson->MailServer!="MailEnable"){
		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
		$this->_redirect('index/index');
	}

	if($_SERVER['QUERY_STRING']=="downdefender"){
		$result = pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/installdefender"));
		if ($result['code'] !== 0) {
			$this->_status->addError($result['stderr']. " - " . $result['stdout']);
		}else{
			$this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));

		}
		$this->_redirect('index/mailenable');
		return;
	}

	if($_SERVER['QUERY_STRING']=="downclam"){
		$result = pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/installclam"));
		if ($result['code'] !== 0) {
			$this->_status->addError($result['stderr']. " - " . $result['stdout']);
		}else{
			$this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));

		}
		$this->_redirect('index/mailenable');
		return;
	}

	if($_SERVER['QUERY_STRING']=="setupdefender"){
		$result = pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/defender","-setup"));
		if ($result['code'] !== 0) {
			$this->_status->addError($result['stderr']. " - " . $result['stdout']);
		}else{
			$this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));

		}
		$this->_redirect('index/mailenable');
		return;
	}

	if($_SERVER['QUERY_STRING']=="setupclam"){
		$result = pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/clam","-setup"));
		if ($result['code'] !== 0) {
			$this->_status->addError($result['stderr']. " - " . $result['stdout']);
		}else{
			$this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));

		}
		$this->_redirect('index/mailenable');
		return;
	}

	if($_SERVER['QUERY_STRING']=="downspam"){
		$result = pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/installspam"));
		if ($result['code'] !== 0) {
			$this->_status->addError($result['stderr']. " - " . $result['stdout']);
		}else{
			$this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));

		}
		$this->_redirect('index/mailenable');
		return;
	}

	if($_SERVER['QUERY_STRING']=="setupspam"){
		$result = pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/spam","-enable"));
		if ($result['code'] !== 0) {
			$this->_status->addError($result['stderr']. " - " . $result['stdout']);
		}else{
			$this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));

		}
		$this->_redirect('index/mailenable');
		return;
	}

	$this->view->Status=self::IndexStatus();

        $form = new Modules_FlexFirewallManager_Form_Mailenable();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
		if($form->process()){
	                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
		}else{
	                $this->_status->addError(pm_Locale::lmsg('statusPRO'));
		}
            } catch (pm_Exception $e) {
		$this->_helper->json(array('status' => 'danger','msg' => $e->getMessage()));
            }

		$this->_redirect('mailenable', [ 'exit' => true ]);
        }


        $this->view->form = $form;

	$tools[] = [];
       	$this->view->tools = $tools;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getSettingTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }

 /**
     * SmarterMail Page
     */
   public function smartermailAction(){



	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	

	$appjson = json_decode(Modules_FlexFirewallManager_Settings::GetVersionCom($this->app));

	if($appjson->MailServer!="SmarterMail"){
		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
		$this->_redirect('index/index');
	}


	$this->view->Status=self::IndexStatus();

        $form = new Modules_FlexFirewallManager_Form_SmarterMail();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {
		$propage=0;
		if($form->process()){
			$propage=1;
	                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
		}else{
	                $this->_status->addError(pm_Locale::lmsg('statusPRO'));
		}
            } catch (pm_Exception $e) {
		$this->_helper->json(array('status' => 'danger','msg' => $e->getMessage()));
            }

	    $this->_redirect(pm_Context::getBaseUrl() . 'index.php/index/smartermail/p/'.$propage, [ 'exit' => true ]);
	}


        $this->view->form = $form;

	$tools[] = [];
       	$this->view->tools = $tools;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getSettingTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }

    /**
     * Upgrade Page License
     */
    public function upgradeAction(){

    }

   public function rdpAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

                $this->_helper->json(array('ajax' => "<div class='pul-alert pul-alert--danger pul-status-message pul-status-message--danger'><span class='pul-icon pul-status-message__icon'><img src='". pm_Context::getBaseUrl() ."img/icon/warning.png'></span>".pm_Locale::lmsg('statusNO')."</div>"));
                return;

	}
   

	$appjson = json_decode($this->app->GetRDPList);

	if($appjson->result){

		$tableList="<table>";
		$tableList=$tableList."<tr rel=\"".$appjson->admin."\">";
		$tableList=$tableList."<th>".pm_Locale::lmsg('RDP.Accounts')."</td>";
		$tableList=$tableList."<th>".pm_Locale::lmsg('RDP.Type')."</td>";
		$tableList=$tableList."<th>".pm_Locale::lmsg('RDP.Action')."</td>";
		$tableList=$tableList."</tr>";	    

		foreach($appjson->list as $cuentas){
			$tableList=$tableList."<tr>";
			$tableList=$tableList."<td>" . $cuentas->account . "</td>";
			$tableList=$tableList."<td>" . $cuentas->type . "</td>";
			$tableList=$tableList."<td>" . ($cuentas->deny ? "KO" : "OK")  . "</td>";
			$tableList=$tableList."</tr>";	        
	    	}        

		$tableList=$tableList."</table>";
	}else{
		$tableList="<p>Error : Unknow</p>";	    
	}


	$this->_helper->json(array('ajax' => $tableList));

    }

   public function restoreAction(){

	$path = pm_Context::getVarDir() . "\\" . $_FILES['import']['name'];
	copy($_FILES['import']['tmp_name'], $path);
	$jsonrestore = $this->app->Restore($path);

	unset($_SESSION[pm_Context::getModuleInfo()->name]["Settings"]);
	unset($_SESSION[pm_Context::getModuleInfo()->name]['Settings_Activity']);

	echo $jsonrestore;
	exit;
   }

   public function backupAction(){

	$filename = $this->app->Backup(pm_Context::getVarDir());
	$name = basename($filename);

	try {
	    $fileHandle = fopen($filename, 'rb');
	    if ($fileHandle === false) {
        	throw new Exception("Backup Error");
	    }

	    $fileContents = fread($fileHandle, filesize($filename));
	    fclose($fileHandle);

		header('Content-Description: File Transfer');
		header('Content-Type: application/octet-stream');
		header('Content-Disposition: attachment; filename="'.$name.'"');
		header('Content-Transfer-Encoding: binary');
		header('Expires: 0');
		header('Cache-Control: must-revalidate, post-check=0, pre-check=0');
		header('Pragma: public');
		header('Content-Length: ' . filesize($filename)); //Absolute URL
		ob_clean();
		flush();

	    echo $fileContents;

	} catch (Exception $e) {
		throw new Exception("An error occurred: " . $e->getMessage());
	}
	exit;
   }

   public function poolsAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

                $this->_helper->json(array("tab1"=>"",'tab2'=>"","error" => "<div class='pul-alert pul-alert--danger pul-status-message pul-status-message--danger'><span class='pul-icon pul-status-message__icon'><img src='". pm_Context::getBaseUrl() ."img/icon/warning.png'></span>".pm_Locale::lmsg('statusNO')."</div>"));
                return;

	}
   

	$appjson = json_decode($this->app->PoolsInfo);

	$poolID=isset($_SERVER["QUERY_STRING"]) ? $_SERVER['QUERY_STRING'] : "";

	if( strlen($poolID)>0 && is_numeric($poolID) ){
		pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/pool",$poolID));
		sleep(3);
		$this->_helper->json(array("result"=>"done")); 
		return;
	}

	if($appjson->result){

		$tab1="<table>";
		$tab1=$tab1."<thead>";
		$tab1=$tab1."<tr>";
		$tab1=$tab1."<th>".pm_Locale::lmsg('MODULE.PoolDom')."</td>";
		$tab1=$tab1."<th>".pm_Locale::lmsg('status')."</td>";
		$tab1=$tab1."</tr>";	
		$tab1=$tab1."</thead>";    
		$tab1=$tab1."<tbody>";

		$tab2="<table>";
		$tab2=$tab2."<thead>";
		$tab2=$tab2."<tr>";
		$tab2=$tab2."<th>".pm_Locale::lmsg('MODULE.PoolDom')."</td>";
		$tab2=$tab2."<th>".pm_Locale::lmsg('status')."</td>";
		$tab2=$tab2."</tr>";	
		$tab2=$tab2."</thead>";    
		$tab2=$tab2."<tbody>";

		foreach($appjson->list as $pool){
			if($pool->secure){
				$tab2=$tab2."<tr>";
				$tab2=$tab2."<td data-id=\"" . $pool->id . "\">" . $pool->domain . "</td>";
				$tab2=$tab2."<td>PROTECT</td>";
				$tab2=$tab2."</tr>";	     
			}else{
				$tab1=$tab1."<tr>";
				$tab1=$tab1."<td data-id=\"" . $pool->id . "\">" . $pool->domain . "</td>";
				if (strpos($pool->domain, ".")!==false){
					 $tab1=$tab1."<td>DOMAIN</td>";
				}else{
					 $tab1=$tab1."<td>SYSTEM</td>";
				}
				$tab1=$tab1."</tr>";	     
			}
   
	    	}        

		$this->_helper->json(array("tab1"=> $tab1 ."</tbody></table>" ,'tab2'=> $tab2 ."</tbody></table>" ,"error" => ""));   

	}else{

		$this->_helper->json(array("tab1"=>"",'tab2'=>"","error" => "<p>Error : Unknow</p>"));   
	}




    }

}

