<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk 
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk 
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */

/**
 * Class MailenableController
**/

class MailenableController extends pm_Controller_Action{

    private $app;
    private $version;
    
    public function __call($name, $arguments){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index?call', [ 'exit' => true ]);
                return;
    }

/**
 * init
**/
    public function init(){
        parent::init();

		//error_reporting(E_ALL);

		if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
			$this->_redirect('index/index');
			return;
		}

		if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
			if($this->getRequest()->getParam('action')!="remove-ip"){
	 			$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
        	        	$this->_redirect('index', [ 'exit' => true ]);
                		return;
			}
		}

        	/** @noinspection PhpUndefinedFieldInspection */
	        $this->view->pageTitle = pm_Locale::lmsg('pageTitle');

		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'flex-firewall-manager.css?'.Date('dmhYis'));

		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-library.js?'.Date('dmhYis'));
		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-firewall-manager.js?'.Date('dmhYis'));

		$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

		$appjson = json_decode(Modules_FlexFirewallManager_Settings::GetVersionCom($this->app));

		if($appjson->MailServer!="MailEnable"){
 			$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                	$this->_redirect('index', [ 'exit' => true ]);
                	return;
		}

		$this->version = $appjson->MailEnable;


    }


/**
 * MailEnable Rules Page
**/

    public function indexAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

 	$list = $this->_getRules();
        $this->view->list = $list;

	$tools = $this->_getTools();
        $this->view->tools = $tools;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }

  public function _getTools(){
	$data = [];

        $data[] = [
                'icon' =>  pm_Context::getBaseUrl() ."img/icon/firewall.png",
                'title' => pm_Locale::lmsg('ToBlock'),
                'description' => 'MailEnable',
                'link' => "add",
            ];

	if($this->version!="Standard Edition"){
		$data[] = [
			'icon' => pm_Context::getBaseUrl() ."img/icon/session.png",
			'title' => pm_Locale::lmsg('TabCountryTitle'),
        	        'description' => 'MailEnable',
			'link' => $this->_helper->url('blacklistcountry', 'mailenable', null),
		];
	}

	 return $data;
    }

  private function _getRules(){

	$data = [];

	if($this->version!="Standard Edition"){

		try{
	
		    $appjson = json_decode($this->app->GetCountry("MAILENABLE"));

		}catch(com_exception $e){
			if($e->getCode()==2147614729){
				Modules_FlexFirewallManager_Settings::SaveSetting("Job", "PleskUser");
	                	$this->_redirect('index', [ 'exit' => true ]);
        	        	return;
			}		
		}

		if($appjson->result){

			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" alt=\"disabled\" title=\"".pm_Locale::lmsg('off')."\">";
			if(count($appjson->list)>0){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\">";}

			 $data[] = [
        	        	'column-0' => '<input type="checkbox" class="checkbox" name="hidden" value="" disabled> ' . $icon,
               			'column-1' => '<img src="'. pm_Context::getBaseUrl() .'img/icon/session.png" style="margin:0px;padding:0px;border:none" title="'.pm_Locale::lmsg('TabCountryTitle').'" /> <a href="'.$this->_helper->url('blacklistcountry', 'mailenable', null).'">' . pm_Locale::lmsg('TabCountryTitle') .'</a>',
	        	        'column-2' => pm_Locale::lmsg('Rule.IN'),
        	        	'column-3' => pm_Locale::lmsg('Rule.BLOCK'),
                		'column-4' => pm_Locale::lmsg('Rule.TCP'),
                		'column-5' => "SMTP , POP , IMAP",
	                	'column-6' => "-",
		            ];
		}
	}



    	$appjson = json_decode($this->app->GetRulesNames("MAILENABLE"));

	if($appjson->result){

		foreach($appjson->rules as $rules){

			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" alt=\"disabled\" title=\"".pm_Locale::lmsg('off')."\">";
			if($rules->status){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\">";}


		 $data[] = [
                	'column-0' => '<input type="checkbox" class="checkbox" name="listCheckbox[]" value="'.$rules->rulename.'"> ' . $icon,
                	'column-1' => '<a href="javascript:" title="'.$rules->rulename.'" onclick="PleskExt.FlexFirewallManager.loadRule(\'mailenable/rule\',\''.$rules->rulename.'\',\''.$rules->numbersips.'\')">' . $rules->rulenamext .'</a>',
        	        'column-2' => $rules->ruletype,
                	'column-3' => pm_Locale::lmsg('Rule.'. $rules->action),
                	'column-4' => $rules->ruleprotocol,
                	'column-5' => $rules->ruleport,
                	'column-6' => $rules->numbersips,
	            ];
	        
	    	}        
	}

 	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('Rule.Name'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => true,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('Rule.Type'),
                'noEscape' => true,
                'sortable' => true,
            ],
 	   'column-3' => [
                'title' => pm_Locale::lmsg('Rule.Action'),
                'noEscape' => true,
                'sortable' => true,
            ],
	 'column-4' => [
                'title' => pm_Locale::lmsg('Rule.Protocol'),
                'noEscape' => true,
                'sortable' => true,
            ],
	 'column-5' => [
                'title' => pm_Locale::lmsg('Rule.Port'),
                'noEscape' => true,
                'sortable' => true,
            ],
 	'column-6' => [
                'title' => pm_Locale::lmsg('Rule.NIP'),
                'noEscape' => true,
                'sortable' => true,
            ],
        ]);


       $list->setTools([
            [
                'title' => pm_Locale::lmsg('Delete'),
                'class' => 'sb-delete',
                'link' => 'javascript:PleskExt.FlexFirewallManager.deleteAction("mailenable/remove")',
            ],
        ]);


        $list->setDataUrl(['action' => 'list-data-rules']);

        return $list;

    }


    public function removeAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}


	$appjson = json_decode(Modules_FlexFirewallManager_Settings::GetVersionCom($this->app));

	if($appjson->result){
		if($appjson->MailServer!="MailEnable"){ 
            		$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
			$this->_redirect('index', [ 'exit' => true ]);
			return;
		}
	}


        foreach ((array)$this->_getParam('ids') as $id) {
		$appjson = json_decode($this->app->DeleteRuleName($id,"MAILENABLE"));
		if($appjson->result){
		    $this->_status->addMessage('info', str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OnOK')),true);
		}else{
		    $this->_status->addMessage('error', str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OnKO')),true);
		}
        }

	$this->_redirect('mailenable/index');

    }

    public function listDataRuleAction(){
	        $list = $this->_getIPs(urldecode($_SESSION[pm_Context::getModuleInfo()->name]['rule']));
        	$this->_helper->json($list->fetchData());
    }
    public function listDataRulesAction(){
	        $list = $this->_getRules();
        	$this->_helper->json($list->fetchData());
    }

    public function removeIpAction(){

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
	        $messages[] = ['status' => 'error', 'content' => pm_Locale::lmsg('statusPRO')];
		$this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
                return;
	}

        $messages = [];
        foreach ((array)$this->_getParam('ids') as $id) {

		$appjson = json_decode($this->app->UnlockIP($id,"MAILENABLE",$_GET["rule"]));
		if($appjson->result){
	        if($this->_getParam('do')=="search" || $this->_getParam('do')=="searchlist"){
		       $messages[] = ['status' => 'success', 'content' => str_replace("%2",$_GET["rule"],str_replace("%1","<b>".$id."</b>",pm_Locale::lmsg('IPDeleteOK')))];
		    }else{
		    	$this->_status->addMessage('info', str_replace("%2",$_GET["rule"],str_replace("%1","<b>".$id."</b>",pm_Locale::lmsg('IPDeleteOK'))),true);
		    }
			
		}else{
		    if($this->_getParam('do')=="search"){
		      	     $messages[] = ['status' => 'error', 'content' => str_replace("%2",$_GET["rule"],str_replace("%1","<b>".$id."</b>",pm_Locale::lmsg('IPDeleteKO')))];
		    }else{
			    $this->_status->addMessage('error', str_replace("%2",$_GET["rule"],str_replace("%1","<b>".$id."</b>",pm_Locale::lmsg('IPDeleteKO'))),true);
		    }
		}
        }

       if($this->_getParam('do')=="search" || $this->_getParam('do')=="searchlist"){
  	        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);
	}else{
	        $this->_redirect('mailenable/rule?rule='.$_GET["rule"]);
	}

	

    }

/**
 * Add IP to MailEnable
**/
   public function addAction(){

	if($this->app==null){
		$this->_redirect('index/setup');
	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}


        $form = new Modules_FlexFirewallManager_ME_Add();

        if ($this->getRequest()->isPost() && $form->isValid($this->getRequest()->getPost())) {
            try {

		$ValProcess=explode(";",$form->process());

                if($ValProcess[1]=="1"){
	                $this->_status->addInfo(pm_Locale::lmsg('pageSaveOK'));
		} elseif ($ValProcess[1]=="2") {
			$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
		}else{
	                $this->_status->addError(str_replace("%1","",pm_Locale::lmsg('statusERROR'))." (".$ValProcess[2].")");
		}

            } catch (pm_Exception $e) {
                $this->_status->addError($e->getMessage());
            }
            $this->_helper->json(array('redirect' => 'index'));
        }

        $this->view->form = $form;
        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
    }


/**
 * MailEnable Rule Page
**/

  public function ruleAction(){

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

 	$list = $this->_getIPs(urldecode($_GET["rule"]));
        $this->view->list = $list;


        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

	$tools = [];
	$tools[] = [
		'icon' => pm_Context::getBaseUrl() ."img/icon/firewall.png",
		'title' => pm_Locale::lmsg('ToBlock'),
                'description' => 'MailEnable',
		'link' => $this->_helper->url('add', 'mailenable')."?rule=".rawurlencode($_GET["rule"]),
	];
	

	$this->view->tools = $tools;

    }


   private function _getIPs($rule){

	$_SESSION[pm_Context::getModuleInfo()->name]['rule']=$rule;

	$data = [];


	$allowaction='checkbox';
	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){$allowaction='hidden';}

    	$appjson = json_decode($this->app->GetIPListFromRule($rule,"MAILENABLE"));

	if($appjson->result){

		foreach($appjson->list as $listip){

		$reputation="";
		$ip=str_replace("/128","",str_replace("/255.255.255.255","",$listip->ip));
		if(strpos($ip, '/')>0 || strpos($ip, '-')>0 || strpos($ip, '*')>0){
			// no cargar reputacion
		}else{
			if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip])){
				$reputation="<img src='". pm_Context::getBaseUrl() ."img/icon/indicator.gif' loading='lazy' border='0' class='reputation' alt='".$ip."'/>";
			}else{
				if($_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]!="NORMAL"){
					$reputation="<img src='". pm_Context::getBaseUrl() ."img/icon/warning.png' loading='lazy' border='0' alt='".$ip."' rel='".$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]."'/> ".$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip];
				}
			}
		}


		$flag="<img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($listip->code). ".svg' loading='lazy' title='" .Modules_FlexFirewallManager_Settings::Country($listip->code). "' style='height:12px;margin:0px;padding:0px;border:none' /> ";
		if($listip->code==''){$flag='';}

		 $data[] = [
                	'column-0' => '<input type="'.$allowaction.'" class="checkbox" name="listCheckbox[]" value="'.$listip->ip.'"> ',
                	'column-1' => $listip->ip,
                	'column-2' => $listip->code,
                	'column-3' => $flag . Modules_FlexFirewallManager_Settings::Country($listip->code),
                	'column-4' => $listip->isp,
                	'column-5' => $listip->asn,
                	'column-6' => $reputation,
	            ];
	        
	    	}        
	}

 	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('IP'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('IP_CCountry'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-3' => [
                'title' => pm_Locale::lmsg('IP_Country'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-4' => [
                'title' => pm_Locale::lmsg('IP_ISP'),
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-5' => [
                'title' => "ASN",
                'noEscape' => true,
                'sortable' => true,
                'searchable' => true,
            ],
            'column-6' => [
                'title' => pm_Locale::lmsg('IP_Reputation'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
        ]);

	if($allowaction!="checkbox"){
		$list->setTools([]);
	}else{
	       $list->setTools([
            [
                'title' => pm_Locale::lmsg('Delete'),
                'class' => 'sb-delete',
		'link' => 'javascript:PleskExt.FlexFirewallManager.deleteAction("mailenable/remove-ip","'.$rule.'")',
            ],
        	]);
	}



        $list->setDataUrl(['action' => 'list-data-rule']);

        return $list;

    }




/**
 * BlackList Country Page
**/

   public function blacklistcountryAction(){

	if($this->version=="Standard Edition"){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

 	$list = $this->_getBlackCountry();
        $this->view->list = $list;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }

  private function _getBlackCountry(){

	$data = [];


    	$appjson = json_decode($this->app->GetCountry("MAILENABLE"));


	if($appjson->result){

	    	$FWappjson = json_decode($this->app->GetCountry());

		foreach($appjson->list as $country){

			$status=pm_Locale::lmsg('Rule.ALLOW');
			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> ";
			if( $country->status == "B" ){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/lock.png\" alt=\"lock\"> ";$status= pm_Locale::lmsg('ToBlock');}

			$checkboxdisabled="";
			$checkreg = false;
			if( $country->status == "A" ){
				$checkreg = Modules_FlexFirewallManager_Settings::CheckCountryExist($FWappjson->list,[
				'code' => $country->code,
                		'name' => $country->name,
                		'status' => $country->status
		           	]);
			}
			if($checkreg){$checkboxdisabled="disabled";$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/protected.png\" alt=\"lock\"> ";$status="Firewall";}
			
		 $data[] = [
                	'column-0' => '<input type="checkbox" '.$checkboxdisabled.' class="checkbox" name="listCheckbox[]" value="'.$country->code.'"> ' . $icon,
                	'column-1' => $status,
                	'column-2' => Modules_FlexFirewallManager_Settings::Country($country->code),
                	'column-3' => $country->code." <img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($country->code). ".svg' loading='lazy' title='" .Modules_FlexFirewallManager_Settings::Country($country->code). "' style='height:12px;margin:0px;padding:0px;border:none' />",
	            ];
	        
	    	}        
	}


 	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('status'),
                'noEscape' => true,
                'sortable' => true,
                 'searchable' => false,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('IP_Country'),
                'noEscape' => true,
                'sortable' => false,
                 'searchable' => true,
            ],
            'column-3' => [
                'title' => pm_Locale::lmsg('IP_CCountry'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => true,
            ],
        ]);


       $list->setTools([
            [
                'title' => pm_Locale::lmsg('Rule.BLOCK'),
                'class' => 'sb-lock',
                'execGroupOperation' => $this->_helper->url('blockcountry'),
            ],
 		[
                'title' => pm_Locale::lmsg('Rule.ALLOW'),
                'class' => 'sb-unlock',
                'execGroupOperation' => $this->_helper->url('allowcountry'),
            ],
        ]);



        $list->setDataUrl(['action' => 'list-data-blc']);

        return $list;

    }

    public function listDataBlcAction(){
        $list = $this->_getBlackCountry();
        $this->_helper->json($list->fetchData());
    }


 public function allowcountryAction(){


        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id,"A","MAILENABLE");
        }

	$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);


	$this->_redirect('blacklistcountry');

    }


   public function blockcountryAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id,"B","MAILENABLE");
        }


	$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);

	$this->_redirect('blacklistcountry');

    }


}

