<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */

/**
 * Class SmarterMailController
**/

class SmarterMailController extends pm_Controller_Action{

    private $app;
    private $version;
    private $Propagation;
    

    public function __call($name, $arguments){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index?call', [ 'exit' => true ]);
                return;
    }

/**
 * init
**/
    public function init(){
        parent::init();

		//error_reporting(E_ALL);


		if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
	 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
        	        $this->_redirect('index', [ 'exit' => true ]);
                	return;
		}

        	/** @noinspection PhpUndefinedFieldInspection */
	        $this->view->pageTitle = pm_Locale::lmsg('pageTitle');

		$this->view->headLink()->appendStylesheet(pm_Context::getBaseUrl() . 'flex-firewall-manager.css?'.Date('dmhYis'));

		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-library.js?'.Date('dmhYis'));
		$this->view->headScript()->appendFile(pm_Context::getBaseUrl() . 'js/ext-flex-firewall-manager.js?'.Date('dmhYis'));

		$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

		$appjson = json_decode($_SESSION[pm_Context::getModuleInfo()->name]['version']);

		if($appjson->MailServer!="SmarterMail"){
 			$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                	$this->_redirect('index', [ 'exit' => true ]);
                	return;
		}

		$this->version = $appjson->SmarterMail;
		$this->Propagation=$this->app->isPropagationSmarterMail;

    }


/**
 * Check SmarterMail isPropagation
**/

    public function ispropagationAction(){

	if($this->Propagation){
		$this->_helper->json(array('result' => true));
	}else{
		$this->_helper->json(array('result' => false));
	}

    }


/**
 * SmarterMail Rules Page
**/

    public function indexAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

 	$list = $this->_getRules();
        $this->view->list = $list;
        $this->view->Propagation = $this->Propagation;

	$tools = $this->_getTools();
        $this->view->tools = $tools;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }

  public function _getTools(){
	$data = [];

        $data[] = [
                'icon' =>  pm_Context::getBaseUrl() ."img/icon/firewall.png",
                'title' => pm_Locale::lmsg('ToBlock'),
                'description' => 'SmarterMail',
                'link' => "add",
            ];

	$data[] = [
		'icon' => pm_Context::getBaseUrl() ."img/icon/session.png",
		'title' => pm_Locale::lmsg('TabCountryTitle'),
                'description' => 'SmarterMail',
		'link' => $this->_helper->url('blacklistcountry', 'smartermail', null),
	];

	 return $data;
    }

  private function _getRules(){

	$data = [];


		try{
	
		    $appjson = json_decode($this->app->GetCountry("SmarterMail"));

		}catch(com_exception $e){
			if($e->getCode()==2147614729){
				Modules_FlexFirewallManager_Settings::SaveSetting("Job", "PleskUser");
	                	$this->_redirect('index', [ 'exit' => true ]);
        	        	return;
			}		
		}

		if($appjson->result){

			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/off.png\" alt=\"disabled\" title=\"".pm_Locale::lmsg('off')."\">";
			if(count($appjson->list)>0){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\">";}

			 $data[] = [
        	        	'column-0' => '<input type="checkbox" class="checkbox" name="hidden" value="" disabled> ' . $icon,
               			'column-1' => '<img src="'. pm_Context::getBaseUrl() .'img/icon/session.png" style="margin:0px;padding:0px;border:none" title="'.pm_Locale::lmsg('TabCountryTitle').'" /> <a href="'.$this->_helper->url('blacklistcountry', 'smartermail', null).'">' . pm_Locale::lmsg('TabCountryTitle') .'</a>',
	        	        'column-2' => pm_Locale::lmsg('Rule.IN'),
        	        	'column-3' => pm_Locale::lmsg('Rule.BLOCK'),
                		'column-4' => pm_Locale::lmsg('Rule.TCP'),
                		'column-5' => "SMTP , POP , IMAP",
	                	'column-6' => "-",
		            ];
		}


 	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('Rule.Name'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => true,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('Rule.Type'),
                'noEscape' => true,
                'sortable' => true,
            ],
 	   'column-3' => [
                'title' => pm_Locale::lmsg('Rule.Action'),
                'noEscape' => true,
                'sortable' => true,
            ],
	 'column-4' => [
                'title' => pm_Locale::lmsg('Rule.Protocol'),
                'noEscape' => true,
                'sortable' => true,
            ],
	 'column-5' => [
                'title' => pm_Locale::lmsg('Rule.Port'),
                'noEscape' => true,
                'sortable' => true,
            ],
 	'column-6' => [
                'title' => pm_Locale::lmsg('Rule.NIP'),
                'noEscape' => true,
                'sortable' => true,
            ],
        ]);


       $list->setTools([]);


        $list->setDataUrl(['action' => 'list-data-rules']);

        return $list;

    }


    public function removeAction(){

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){

 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusNO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;

	}

	if(Modules_FlexFirewallManager_Settings::isJob()){
		$this->_redirect('index/job');
	}

    	$appjson = json_decode($this->app->Version);

	if($appjson->result){
		if($appjson->MailServer!="SmarterMail"){ 
            		$this->_status->addMessage('error', pm_Locale::lmsg('statusKO'));
			$this->_redirect('index', [ 'exit' => true ]);
			return;
		}
	}


        foreach ((array)$this->_getParam('ids') as $id) {
		$appjson = json_decode($this->app->DeleteRuleName($id,"SmarterMail"));
		if($appjson->result){

		    $this->_status->addMessage('info', str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OnOK')),true);
		}else{
		    $this->_status->addMessage('error', str_replace("%1","<b>".str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$id)."</b>",pm_Locale::lmsg('Rule.OnKO')),true);
		}
        }

	$this->_redirect('smartermail/index');

    }

    public function listDataRuleAction(){
	        $list = $this->_getIPs(urldecode($_SESSION[pm_Context::getModuleInfo()->name]['rule']));
        	$this->_helper->json($list->fetchData());
    }
    public function listDataRulesAction(){
	        $list = $this->_getRules();
        	$this->_helper->json($list->fetchData());
    }


/**
 * BlackList Country Page
**/

   public function blacklistcountryAction(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
 		$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
                $this->_redirect('index', [ 'exit' => true ]);
                return;
	}

 	$list = $this->_getBlackCountry();
        $this->view->list = $list;
        $this->view->Propagation = $this->Propagation;

        $this->view->tabs = Modules_FlexFirewallManager_Settings::_getTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));
        $this->view->subtabs = Modules_FlexFirewallManager_Settings::_getRuleTabs($this->app,$this->getRequest()->getParam('controller') .'-'. $this->getRequest()->getParam('action'));

    }

  private function _getBlackCountry(){

	$data = [];


    	$appjson = json_decode($this->app->GetCountry("SmarterMail"));


	if($appjson->result){

	    	$FWappjson = json_decode($this->app->GetCountry());

		foreach($appjson->list as $country){

			$status=pm_Locale::lmsg('Rule.ALLOW');
			$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/on.png\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> ";
			if( $country->status == "B" ){$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/lock.png\" alt=\"lock\"> ";$status= pm_Locale::lmsg('ToBlock');}

			$checkboxdisabled="";
			$checkreg = false;
			if( $country->status == "A" ){
				$checkreg = Modules_FlexFirewallManager_Settings::CheckCountryExist($FWappjson->list,[
				'code' => $country->code,
                		'name' => $country->name,
                		'status' => $country->status
		           	]);
			}
			if($checkreg){$checkboxdisabled="disabled";$icon="<img src=\"". pm_Context::getBaseUrl() ."img/icon/protected.png\" alt=\"lock\"> ";$status="Firewall";}
			
		 $data[] = [
                	'column-0' => '<input type="checkbox" '.$checkboxdisabled.' class="checkbox" name="listCheckbox[]" value="'.$country->code.'"> ' . $icon,
                	'column-1' => $status,
                	'column-2' => Modules_FlexFirewallManager_Settings::Country($country->code),
                	'column-3' => $country->code." <img src='//flagicons.lipis.dev/flags/4x3/" .strtolower($country->code). ".svg' loading='lazy' title='" .Modules_FlexFirewallManager_Settings::Country($country->code). "' style='height:12px;margin:0px;padding:0px;border:none' />",
	            ];
	        
	    	}        
	}


 	$options = [
            'defaultSortField' => 'column-1',
            'defaultSortDirection' => pm_View_List_Simple::SORT_DIR_DOWN,
            'defaultItemsPerPage ' => 30,
        ];


	$list = new pm_View_List_Simple($this->view, $this->_request,$options);


        $list->setData($data);
        $list->setColumns([
            'column-0' => [
                'title' => '',
                'noEscape' => true,
                'sortable' => false,
                'searchable' => false,
            ],
            'column-1' => [
                'title' => pm_Locale::lmsg('status'),
                'noEscape' => true,
                'sortable' => true,
                 'searchable' => false,
            ],
            'column-2' => [
                'title' => pm_Locale::lmsg('IP_Country'),
                'noEscape' => true,
                'sortable' => false,
                 'searchable' => true,
            ],
            'column-3' => [
                'title' => pm_Locale::lmsg('IP_CCountry'),
                'noEscape' => true,
                'sortable' => false,
                'searchable' => true,
            ],
        ]);


       $list->setTools([
            [
                'title' => pm_Locale::lmsg('Rule.BLOCK'),
                'class' => 'sb-lock',
                'execGroupOperation' => $this->_helper->url('blockcountry'),
            ],
 		[
                'title' => pm_Locale::lmsg('Rule.ALLOW'),
                'class' => 'sb-unlock',
                'execGroupOperation' => $this->_helper->url('allowcountry'),
            ],
        ]);



        $list->setDataUrl(['action' => 'list-data-blc']);

        return $list;

    }

    public function listDataBlcAction(){
        $list = $this->_getBlackCountry();
        $this->_helper->json($list->fetchData());
    }


 public function allowcountryAction(){


        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id,"A","SmarterMail");
        }

	$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);


	$this->_redirect('blacklistcountry');

    }


   public function blockcountryAction(){

	$_SESSION['panel']['pm_View_List_Simple']['searchFilter']['any']['searchText']="";

        foreach ((array)$this->_getParam('ids') as $id) {
		$this->app->UpdateCountryLimit($id,"B","SmarterMail");
        }


	$messages[] = ['status' => 'info', 'content' => pm_Locale::lmsg('pageSaveOK')];
        $this->_helper->json(['status' => 'success', 'statusMessages' => $messages]);

	$this->_redirect('blacklistcountry');

    }


}

