<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */

class Modules_FlexFirewallManager_ApiRpc extends pm_Hook_ApiRpc{
    

	public function call($params){

		$result = null;

		if(count($params)==0){
			throw new pm_Exception("Error : Arguments",1);
			return;
		}

		$command = array_keys($params)[0];

		switch ($command) {
		case "version":
			$result = self::CallBin(1,array("--".$command));
		break;
		case "add":
		case "remove":
			$param = array_keys($params[$command])[0];
			$ip = $params[$command][array_keys($params[$command])[0]];
			$result = self::CallBin(3,array("--".$command,$param,$ip));

		break;
		case "find":
			$param = array_keys($params[$command])[0];
			$ip = $params[$command][array_keys($params[$command])[0]];
			$result = self::CallBin(3,array("--".$command,"-".$param,$ip));
		break;
		case "disable":
		case "enable":
		case "list":
		case "on":
		case "off":
		case "status":
		case "protection":
		case "whitelist":
			$result = self::CallBin(2, array("--".$command,$params[$command]) );
		break;
		case "help":
			$result = self::CallBin(1, array("--".$command,$params[$command]) );
		break;
		default:
			throw new pm_Exception("Error : Arguments",4);
			return;
		}


		if(is_array($result)){
			throw new pm_Exception(rtrim($result[0], PHP_EOL),$result[1]);
			return;
		}else{
			return str_replace(PHP_EOL," , ",rtrim($result, PHP_EOL));
		}




	}



   private function CallBin($items,$argments) { 
		if(count($argments)!=$items){
			return ["Error : Arguments",2];
		}
		$arg = [];
		for($i=0;$i<$items;$i++){
			$arg[] = $argments[$i];
		}

		return self::Write(pm_ApiCli::callSbin("ffm.exe",$arg,1));
   }
    private function Write($result){


	if($result['code']===0){
		return $result['stdout'];
	}else{
		return [$result['stderr'],3];
	}

    }

}



