<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */

class Modules_FlexFirewallManager_CustomButtons extends pm_Hook_CustomButtons{


    public function getButtons(){

        $buttons = [[
            'place' => self::PLACE_ADMIN_HOME,
            'title' => "Flex Firewall Manager",
	    'description' => "Firewall",
            'icon' => pm_Context::getBaseUrl() . 'img/icon.png',
            'link' => pm_Context::getActionUrl('index'),
        ],[
            'place' => self::PLACE_ADMIN_HOME,
            'title' => pm_Locale::lmsg('SessionsPK'),
	    'description' => pm_Locale::lmsg('SessionsPK'),
            'icon' => 	pm_Context::getBaseUrl() . 'img/icon/admin.png',
            'link' => '/admin/sessions/list',
        ],[
            'place' => self::PLACE_ADMIN_HOME,
            'title' => pm_Locale::lmsg('SessionsTS'),
	    'description' => pm_Locale::lmsg('SessionsTS'),
            'icon' => pm_Context::getBaseUrl() . 'img/icon/admin.png',
            'link' => '/cp/server/ts-sessions/',
        ],[
            'place' => self::PLACE_ADMIN_TOOLS_AND_SETTINGS,
            'title' => "Flex Firewall Manager",
            'description' => pm_Locale::lmsg('AppDesc'),
            'icon' => pm_Context::getBaseUrl() . 'img/icon.png',
            'link' => pm_Context::getActionUrl('index'),
        ]];


	if (Modules_FlexFirewallManager_Settings::AdminAuth()) {
 		$buttons = array_merge($buttons, [[
           	 'place' => self::PLACE_ADMIN_NAVIGATION,
		 'section' => self::SECTION_NAV_SERVER_MANAGEMENT,
	         'order' => 2,
           	 'title' => "Flex Firewall",
           	 'description' => pm_Locale::lmsg('AppDesc'),
           	 'icon' => pm_Context::getBaseUrl() . 'img/icon/security-scan-active.png',
          	  'link' => pm_Context::getActionUrl('index'),
        	],[
        	    'place' => self::PLACE_HOSTING_PANEL_NAVIGATION,
	            'title' => "Flex Firewall Manager",
           	    'description' => pm_Locale::lmsg('AppDesc'),
           	    'icon' => pm_Context::getBaseUrl() . 'img/icon/security-scan-active.png',
          	    'link' => pm_Context::getActionUrl('index'),
        	]]);

	}

	if (Modules_FlexFirewallManager_Settings::ResellerAuth()) {

		if(Modules_FlexFirewallManager_Settings::isEnablePermission() || Modules_FlexFirewallManager_Settings::GetSetting("status_Reseller")=="1"){
 			$buttons = array_merge($buttons, [[
	        	    'place' => self::PLACE_RESELLER_HOME,
		            'title' => "Flex Firewall Manager",
        		    'icon' => pm_Context::getBaseUrl() . 'img/icon.png',
            		    'link' => pm_Context::getActionUrl('firewall','index'),
	        	],[
        		    'place' => self::PLACE_RESELLER_TOOLS_AND_SETTINGS,
	        	    'title' => "Flex Firewall Manager",
	        	    'icon' => pm_Context::getBaseUrl() . 'img/icon.png',
        	    		'link' => pm_Context::getActionUrl('firewall','index'),
        		],[
	        	    'place' => self::PLACE_RESELLER_NAVIGATION,
		            'title' => "Flex Firewall Manager",
			    'description' => pm_Locale::lmsg('AppDesc'),
	        	    'icon' => pm_Context::getBaseUrl() .'img/icon/security-scan-active.png',
        	    		'link' => pm_Context::getActionUrl('firewall','index'),
        		]
			]);
		}
	}
	
	if(Modules_FlexFirewallManager_Settings::ClientAuth()){

		$buttons = array_merge($buttons, [[
        	   	'place' => self::PLACE_DOMAIN_PROPERTIES,
           		'title' => "Flex Firewall Manager",
	           	'description' => pm_Locale::lmsg('AppDesc'),
        	   	'icon' => pm_Context::getBaseUrl() . 'img/icon.png',
          		'link' => pm_Context::getActionUrl('firewall','index'),
			'contextParams' => true,
          		'visibility'         => [
                    		$this,
	                       'getClientVisibilityProperties'
        		        		],
	        	]]);

		$buttons = array_merge($buttons, [[
        	   	'place' => self::PLACE_HOSTING_PANEL_TABS,
           		'title' => "Flex Firewall Manager",
	           	'description' => pm_Locale::lmsg('AppDesc'),
        	   	'icon' => pm_Context::getBaseUrl() . 'img/icon/security-scan-active.png',
          		'link' => pm_Context::getActionUrl('firewall','index'),
			'contextParams' => true,
          		'visibility'         => [
                    		$this,
	                       'getClientVisibilityAccount'
        		        		],
	        	]]);

	}


        return $buttons;
    }



    public function getClientVisibilityProperties($options){

	if(Modules_FlexFirewallManager_Settings::GetSetting("status_Client")=="1"){return true;}

	if(isset($options['site_id'])){
		$auth=pm_Domain::getByDomainId($options['site_id'])->hasPermission('firewall_ext_enable');
		if($auth=="1"){
			return true;
		}else{
			return false;
		}
	}
	return false;
    }

    public function getClientVisibilityAccount(){

	if(Modules_FlexFirewallManager_Settings::GetSetting("status_Client")=="1"){return true;}

	$result=false;
	foreach (pm_Domain::getDomainsByClient(pm_Session::getClient(),true) as $domain) {
            	if ($domain->hasPermission('firewall_ext_enable')){
						$result=true;
	                			break;
            	}
        }
	return $result;
    }

}
