<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_CF_Config
 */
class Modules_FlexFirewallManager_CF_Config extends pm_Form_Simple{

    const PFM_User = 'CF_User';
    const PFM_Email = 'CF_Eamil';
    const PFM_Pass = 'CF_Pass';

    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_CF_Config constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init()
    {
        parent::init();

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
	$this->app->CloudflareUserSetting=Modules_FlexFirewallManager_Settings::UserCom();

        $this->addElement((pm_Session::getClient()->hasPermission('firewall_ext_api') && Modules_FlexFirewallManager_Settings::ClientAuth()) ? 'simpleText' : 'hidden', static::PFM_Email, [
            'label'      => pm_Locale::lmsg('UserDomain'),
            'value'      => Modules_FlexFirewallManager_Settings::UserCom(),
            'validators' => [],
        ]);

        $this->addElement('Text', static::PFM_User, [
            'label'      => pm_Locale::lmsg('Email'),
            'required'   => true,
            'value'      => $this->app->CloudflareUserSetting,
            'validators' => [
		['EmailAddress', true],
                ['NotEmpty', true],
            ],
        ]);

        $this->addElement('Password', static::PFM_Pass, [
            'label'      => pm_Locale::lmsg('CloudFlare.Key'),
	    'description' => pm_Locale::lmsg('CloudFlare.KeyDesc'),
            'required'   => true,
            'validators' => [
                ['NotEmpty', true],
            ],
        ]);

        $this->addControlButtons([
		'sendTitle' => pm_Locale::lmsg('Save'),
		'cancelHidden' => true,
        ]);
    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }


        return true;
    }

    /**
     * @return integer
     */
    public function process(){


	$User=$this->getValue(static::PFM_User);
	$Pass=$this->getValue(static::PFM_Pass);


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
		return 2;
	}

	if($this->app->CloudFlareLogin($User,$Pass,Modules_FlexFirewallManager_Settings::UserCom())){
		return 1;
	}else{
		return 0;
	}

    }


 }

