<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_CF_Settings
 */
class Modules_FlexFirewallManager_CF_Settings extends pm_Form_Simple{

    const PFM_SYNC = 'auto_sync';

    const PFM_SL = 'security_level';
    private $PFM_SL_Option;

    const PFM_HSTS = 'strict_transport_security';
    const PFM_HSTS_Sub = 'strict_transport_security_Sub';
    const PFM_HSTS_Max = 'strict_transport_security_Max';

    private $PFM_HSTS_OptionEnable;
    private $PFM_HSTS_OptionSub;
    private $PFM_HSTS_OptionMax;

    const PFM_FM = 'fight_mode';

    const PFM_SSL = 'ssl';
    private $PFM_SSL_Option;

    const PFM_MI_JS = 'minify_js';
    const PFM_MI_CSS = 'minify_css';
    const PFM_MI_HTML = 'minify_html';

    const PFM_AO = 'always_online';
    const PFM_AUSHTTP = 'always_use_https';
    const PFM_AHTTPSRW = 'automatic_https_rewrites';
    const PFM_BC = 'browser_check';
    const PFM_CL = 'cache_level';
    const PFM_DM = 'development_mode';
    const PFM_EO = 'email_obfuscation';
    const PFM_HL = 'hotlink_protection';
    const PFM_HTTP3 = 'http3';
    const PFM_GEO = 'ip_geolocation';
    const PFM_B = 'brotli';
    const PFM_EH = 'early_hints';
    const PFM_R = 'rocket_loader';




    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_CF_Settings constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init()
    {
        parent::init();


	$this->PFM_SL_Option = array('under_attack' => pm_Locale::lmsg('CloudFlare.SL.Attack'), 'high' => pm_Locale::lmsg('CloudFlare.SL.High'), 'medium' => pm_Locale::lmsg('CloudFlare.SL.Normal'), 'essentially_off' => pm_Locale::lmsg('CloudFlare.SL.Off'));
	$this->PFM_SSL_Option = array('off' => pm_Locale::lmsg('CloudFlare.SSL.Off'), 'flexible' => pm_Locale::lmsg('CloudFlare.SSL.Flexible'), 'full' => pm_Locale::lmsg('CloudFlare.SSL.Full'), 'strict' => pm_Locale::lmsg('CloudFlare.SSL.Strict'));
	$this->PFM_HSTS_OptionEnable = array(1 => pm_Locale::lmsg('on'), 0 => pm_Locale::lmsg('off'));
	$this->PFM_HSTS_OptionSub = array(1 => pm_Locale::lmsg('Yes'), 0 => pm_Locale::lmsg('No'));
	$this->PFM_HSTS_OptionMax = array(0 =>  pm_Locale::lmsg('off'),2592000 => '1 '. pm_Locale::lmsg('month'), 15552000 => '6 '. pm_Locale::lmsg('months'));


	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
	$this->app->CloudflareUserSetting=Modules_FlexFirewallManager_Settings::UserCom();
	$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];

	$appjson = json_decode($this->app->CloudFlareDomainSetting());

	if($appjson->result){


		/***********************/

		$this->addElement('SimpleText', "Drawer_".static::PFM_SL, [
		    'label'  => pm_Locale::lmsg('status'),
         	    'title' => pm_Locale::lmsg('CloudFlare.SettingSLDesc'),
		    'escape' => false,
        	    'value' => "<span>" . $this->PFM_SL_Option[$appjson->settings->security_level] . "</span><a id='btnSL' href='javascript:' style='margin:10px'><span class='pul-icon pul-icon--size-16 pul-action__icon'><svg focusable='false'><path fill-rule='evenodd' d='M2 .5a.5.5 0 0 1 1 0v1.55a2.5 2.5 0 0 1 0 4.9v8.55a.5.5 0 1 1-1 0V6.95a2.5 2.5 0 0 1 0-4.9V.5zm2 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM7 .5a.5.5 0 0 1 1 0v8.55a2.5 2.5 0 0 1 0 4.9v1.55a.5.5 0 1 1-1 0v-1.55a2.5 2.5 0 0 1 0-4.9V.5zM7.5 13a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zM12.5 0a.5.5 0 0 0-.5.5v4.55a2.5 2.5 0 0 0 0 4.9v5.55a.5.5 0 1 0 1 0V9.95a2.5 2.5 0 0 0 0-4.9V.5a.5.5 0 0 0-.5-.5zM14 7.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z' clip-rule='evenodd' /></svg></span></a>",
		]);


		$this->addElement('hidden', static::PFM_SL, [
        	    'value' => $appjson->settings->security_level,
		]);

		$this->addDisplayGroup(array("Drawer_".static::PFM_SL), 'SLGroup');
		$this->getDisplayGroup('SLGroup')->removeDecorator('HtmlTag');
		$this->getDisplayGroup('SLGroup')->removeDecorator('DtDdWrapper');
	        $this->getDisplayGroup('SLGroup')->setLegend(pm_Locale::lmsg('CloudFlare.SettingSL'));


		/***********************/

		$this->addElement('SimpleText', "Drawer_".static::PFM_HSTS, [
		    'label'  => pm_Locale::lmsg('status'),
         	    'title' => pm_Locale::lmsg('CloudFlare.SettingHSTSDesc'),
		    'escape' => false,
        	    'value' => "<span>" . ($appjson->settings->security_header->strict_transport_security->enabled ? pm_Locale::lmsg('on') : pm_Locale::lmsg('off')) . "</span><a id='btnHSTS' href='javascript:' style='margin:10px'><span class='pul-icon pul-icon--size-16 pul-action__icon'><svg focusable='false'><path fill-rule='evenodd' d='M2 .5a.5.5 0 0 1 1 0v1.55a2.5 2.5 0 0 1 0 4.9v8.55a.5.5 0 1 1-1 0V6.95a2.5 2.5 0 0 1 0-4.9V.5zm2 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM7 .5a.5.5 0 0 1 1 0v8.55a2.5 2.5 0 0 1 0 4.9v1.55a.5.5 0 1 1-1 0v-1.55a2.5 2.5 0 0 1 0-4.9V.5zM7.5 13a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zM12.5 0a.5.5 0 0 0-.5.5v4.55a2.5 2.5 0 0 0 0 4.9v5.55a.5.5 0 1 0 1 0V9.95a2.5 2.5 0 0 0 0-4.9V.5a.5.5 0 0 0-.5-.5zM14 7.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z' clip-rule='evenodd' /></svg></span></a>",
		]);


		$this->addElement('hidden', static::PFM_HSTS, [
        	    'value' => ($appjson->settings->security_header->strict_transport_security->enabled ? 1 : 0),
		]);

		$this->addElement('hidden', static::PFM_HSTS_Sub, [
        	    'value' => ($appjson->settings->security_header->strict_transport_security->include_subdomains ? 1 : 0),
		]);

		$this->addElement('hidden', static::PFM_HSTS_Max, [
        	    'value' => $appjson->settings->security_header->strict_transport_security->max_age,
		]);

		$this->addDisplayGroup(array("Drawer_".static::PFM_HSTS), 'HSTSGroup');
		$this->getDisplayGroup('HSTSGroup')->removeDecorator('HtmlTag');
		$this->getDisplayGroup('HSTSGroup')->removeDecorator('DtDdWrapper');
	        $this->getDisplayGroup('HSTSGroup')->setLegend(pm_Locale::lmsg('CloudFlare.SettingHSTS'));



		/***********************/


		$this->addElement('SimpleText', "Drawer_".static::PFM_SSL, [
        	    'label'      => pm_Locale::lmsg('status'),
         	    'title' => pm_Locale::lmsg('CloudFlare.SettingSSLDesc'),
		    'escape' => false,
        	    'value' => "<span>" . $this->PFM_SSL_Option[$appjson->settings->ssl] . "</span><a id='btnSSL' href='javascript:' style='margin:10px'><span class='pul-icon pul-icon--size-16 pul-action__icon'><svg focusable='false'><path fill-rule='evenodd' d='M2 .5a.5.5 0 0 1 1 0v1.55a2.5 2.5 0 0 1 0 4.9v8.55a.5.5 0 1 1-1 0V6.95a2.5 2.5 0 0 1 0-4.9V.5zm2 4a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0zM7 .5a.5.5 0 0 1 1 0v8.55a2.5 2.5 0 0 1 0 4.9v1.55a.5.5 0 1 1-1 0v-1.55a2.5 2.5 0 0 1 0-4.9V.5zM7.5 13a1.5 1.5 0 1 0 0-3 1.5 1.5 0 0 0 0 3zM12.5 0a.5.5 0 0 0-.5.5v4.55a2.5 2.5 0 0 0 0 4.9v5.55a.5.5 0 1 0 1 0V9.95a2.5 2.5 0 0 0 0-4.9V.5a.5.5 0 0 0-.5-.5zM14 7.5a1.5 1.5 0 1 1-3 0 1.5 1.5 0 0 1 3 0z' clip-rule='evenodd' /></svg></span></a>",
		]);

		$this->addElement('hidden', static::PFM_SSL, [
        	    'value' => $appjson->settings->ssl,
        	    'required' => false,
		]);


		$this->addDisplayGroup(array("Drawer_".static::PFM_SSL), 'SSLGroup');
		$this->getDisplayGroup('SSLGroup')->removeDecorator('HtmlTag');
		$this->getDisplayGroup('SSLGroup')->removeDecorator('DtDdWrapper');
	        $this->getDisplayGroup('SSLGroup')->setLegend(pm_Locale::lmsg('CloudFlare.SettingSSL'));



		/***********************/

		$valueAS='';
		$isAlias=(Modules_FlexFirewallManager_Settings::isAliasDomain($_SESSION[pm_Context::getModuleInfo()->name]['domain']));
		if(!$isAlias){
			$valueAS=Modules_FlexFirewallManager_Settings::PleskDomainAutoSyncCF($_SESSION[pm_Context::getModuleInfo()->name]['domain']);
			if($valueAS==''){$valueAS=1;}
		}
		

		$this->addElement('hidden', static::PFM_SYNC, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingSync')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingSyncDesc'),
	            'value'      => $valueAS,
        	    'required'   => false,
        	    'class'   => $isAlias ? '' : 'switch',
	            'validators' => [],
		]);

		/***********************/

		$this->addElement('hidden', static::PFM_FM, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingFM')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingFMDesc'),
	            'value'      => $appjson->settings->fight_mode=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);

		/***********************/

		$this->addElement('hidden', static::PFM_AO, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingAO')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingAODesc'),
	            'value'      => $appjson->settings->always_online=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);



		/***********************/

		$this->addElement('hidden', static::PFM_AUSHTTP, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingAUSHTTP')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingAUSHTTPDesc'),
	            'value'      => $appjson->settings->always_use_https=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);



		/***********************/

		$this->addElement('hidden', static::PFM_AHTTPSRW, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingAHTTPSRW')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingAHTTPSRWDesc'),
	            'value'      => $appjson->settings->automatic_https_rewrites=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);




		/***********************/

		$this->addElement('hidden', static::PFM_BC, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingBC')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingBCDesc'),
	            'value'      => $appjson->settings->browser_check=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);



		/***********************/

		$this->addElement('hidden', static::PFM_CL, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingCL')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingCLDesc'),
	            'value'      => $appjson->settings->cache_level=="aggressive" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);


		/***********************/

		$this->addElement('hidden', static::PFM_DM, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingDM')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingDMDesc'),
	            'value'      => $appjson->settings->development_mode=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);

 


		/***********************/

		$this->addElement('hidden', static::PFM_EO, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingEO')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingEODesc'),
	            'value'      => $appjson->settings->email_obfuscation=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);



		/***********************/

		$this->addElement('hidden', static::PFM_HL, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingHL')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingHLDesc'),
	            'value'      => $appjson->settings->hotlink_protection=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);




		/***********************/

		$this->addElement('hidden', static::PFM_HTTP3, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingHTTP3')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingHTTP3Desc'),
	            'value'      => $appjson->settings->http3=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);

  


		/***********************/

		$this->addElement('hidden', static::PFM_GEO, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingGEO')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingGEODesc'),
	            'value'      => $appjson->settings->ip_geolocation=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);

  

		/***********************/

		$this->addElement('hidden', static::PFM_EH, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingEH')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingEHDesc'),
	            'value'      => $appjson->settings->early_hints=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);

		/***********************/

		$this->addElement('hidden', static::PFM_R, [
        	    'title'      => "<b>".pm_Locale::lmsg('CloudFlare.SettingR')."</b>",
		    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingRDesc'),
	            'value'      => $appjson->settings->rocket_loader=="on" ? 1 : 0,
        	    'required'   => true,
        	    'class'   => 'switch',
	            'validators' => [],
		]);


		$this->addDisplayGroup(array(static::PFM_SYNC,static::PFM_FM,static::PFM_AO,static::PFM_AUSHTTP,static::PFM_AHTTPSRW,static::PFM_BC,static::PFM_CL,static::PFM_DM,static::PFM_EO,static::PFM_HL,static::PFM_HTTP3,static::PFM_GEO,static::PFM_EH,static::PFM_R), 'OptGroup');
		$this->getDisplayGroup('OptGroup')->removeDecorator('HtmlTag');
		$this->getDisplayGroup('OptGroup')->removeDecorator('DtDdWrapper');
	        $this->getDisplayGroup('OptGroup')->setLegend(pm_Locale::lmsg('TabSettingTitle'));



		/***********************/


		$formSL = new pm_Form_Simple();
		$formSL->addElement('select', static::PFM_SL, [
        	    'label'      => pm_Locale::lmsg('CloudFlare.SettingSL'),
         	    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingSLDesc'),
        	    'multiOptions' => $this->PFM_SL_Option,
        	    'value' => $appjson->settings->security_level,
        	    'required' => true,
		]);
		$this->addSubForm($formSL,"SubFormSL");


		$formSSL = new pm_Form_Simple();
		$formSSL->addElement('select', static::PFM_SSL, [
        	    'label'      => pm_Locale::lmsg('CloudFlare.SettingSSL'),
         	    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingSSLDesc'),
        	    'multiOptions' => $this->PFM_SSL_Option,
        	    'value' => $appjson->settings->ssl,
        	    'required' => true,
		]);
		$this->addSubForm($formSSL,"SubFormSSL");


		$formHSTS = new pm_Form_Simple();
		$formHSTS->addElement('select', static::PFM_HSTS, [
        	    'label'      => pm_Locale::lmsg('CloudFlare.SettingHSTS'),
         	    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingHSTSDesc'),
        	    'multiOptions' => $this->PFM_HSTS_OptionEnable,
        	    'value' => ($appjson->settings->security_header->strict_transport_security->enabled ? 1 : 0),
        	    'required' => true,
		]);
		$formHSTS->addElement('select', static::PFM_HSTS_Sub, [
        	    'label'      => pm_Locale::lmsg('CloudFlare.SettingHSTS_Sub'),
         	    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingHSTS_SubDesc'),
        	    'multiOptions' => $this->PFM_HSTS_OptionSub,
        	    'value' => ($appjson->settings->security_header->strict_transport_security->include_subdomains ? 1 : 0),
        	    'required' => true,
		]);
		$formHSTS->addElement('select', static::PFM_HSTS_Max, [
        	    'label'      => pm_Locale::lmsg('CloudFlare.SettingHSTS_Max'),
         	    'data-tooltip' => pm_Locale::lmsg('CloudFlare.SettingHSTS_MaxDesc'),
        	    'multiOptions' => $this->PFM_HSTS_OptionMax,
        	    'value' => $appjson->settings->security_header->strict_transport_security->max_age,
        	    'required' => true,
		]);
		$this->addSubForm($formHSTS,"SubFormHSTS");


		/***********************/

	        $this->addControlButtons([
			'sendTitle' => pm_Locale::lmsg('Save'),
			'cancelHidden' => true,
	        ]);



	}




    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }


        return true;
    }

    /**
     * @return integer
     */
    public function process(){

	$data = "";

	$data .= static::PFM_SL ."," . $this->getValue(static::PFM_SL) . "|";
	$data .= static::PFM_SSL ."," . $this->getValue(static::PFM_SSL) . "|";
	$data .= static::PFM_AO ."," . $this->getValue(static::PFM_AO) . "|";
	$data .= static::PFM_FM ."," . $this->getValue(static::PFM_FM) . "|";
	$data .= static::PFM_AUSHTTP ."," . $this->getValue(static::PFM_AUSHTTP) . "|";
	$data .= static::PFM_AHTTPSRW ."," . $this->getValue(static::PFM_AHTTPSRW) . "|";
	$data .= static::PFM_BC ."," . $this->getValue(static::PFM_BC) . "|";
	if($this->getValue(static::PFM_CL)==1){	$data .= static::PFM_CL .",aggressive|";}else{$data .= static::PFM_CL .",simplified|";}
	$data .= static::PFM_DM ."," . $this->getValue(static::PFM_DM) . "|";
	$data .= static::PFM_EO ."," . $this->getValue(static::PFM_EO) . "|";
	$data .= static::PFM_HL ."," . $this->getValue(static::PFM_HL) . "|";
	$data .= static::PFM_HTTP3 ."," . $this->getValue(static::PFM_HTTP3) . "|";
	$data .= static::PFM_GEO ."," . $this->getValue(static::PFM_GEO) . "|";
	$data .= static::PFM_EH ."," . $this->getValue(static::PFM_EH) . "|";
	$data .= static::PFM_R ."," . $this->getValue(static::PFM_R) . "|";
	$data .= static::PFM_HSTS ."," . $this->getValue(static::PFM_HSTS) . "|";
	$data .= static::PFM_HSTS_Sub ."," . $this->getValue(static::PFM_HSTS_Sub) . "|";
	$data .= static::PFM_HSTS_Max ."," . $this->getValue(static::PFM_HSTS_Max);

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
		return 2;
	}

	if($this->getValue(static::PFM_SYNC)!=''){
		Modules_FlexFirewallManager_Settings::PleskDomainAutoSyncCF($_SESSION[pm_Context::getModuleInfo()->name]['domain'],$this->getValue(static::PFM_SYNC));
	}

	if($this->app->CloudFlareDomainSetting($data)){
		return 1;
	}else{
		return 0;
	}

    }


 }



