<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_CF_Transfer
 */
class Modules_FlexFirewallManager_CF_Transfer extends pm_Form_Simple
{

    const PFM_FWRule = 'fwrules';
    const PFM_CFRule = 'cfrules';

    private $isConsole = false;
    private $app;
    private $domain;
    

    /**
     * Modules_FlexFirewallManager_CF_Transfer constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {



        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

        parent::__construct($options);
    }



    /**
     * Init
     */
    public function init()
    {
        parent::init();

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
	$this->app->CloudflareUserSetting=Modules_FlexFirewallManager_Settings::UserCom();
	$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];

	$rulesname = [];
	$rulesnameCF[Modules_FlexFirewallManager_Settings::Ext . " - Web"]="Web";
	
        foreach (pm_Domain::getAllDomains(true) as $domain) {
            	if (!pm_Session::getClient()->isAdmin() && !pm_Session::getClient()->hasAccessToDomain($domain->getId())) {
                	continue;
            	}

		if($domain->getName()==$_SESSION[pm_Context::getModuleInfo()->name]['domain']){
			$appjson = json_decode($this->app->GetRuleName(Modules_FlexFirewallManager_Settings::Ext . " - " . $domain->getName()));
			if($appjson->result){
				$rulesname[Modules_FlexFirewallManager_Settings::Ext . " - " . $domain->getName()]=$domain->getName();
			}
			break;
		}

       	}


	if(count($rulesname)==0 && $rulesname[0]==''){
		        $this->addElement('SimpleText', "showrule", [
        		    'label'      => pm_Locale::lmsg('PathRulesC'),
			    'escape' => false,
			    'value' => "<img src=\"".pm_Context::getBaseUrl() . "img/icon/warning.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"error\"> " . pm_Locale::lmsg('Rule.Deny'),
        		]);
	}else{


		$this->addElement('select', static::PFM_FWRule, [
        		'label'      => pm_Locale::lmsg('PathRulesF'),
			'multiOptions' => $rulesname,
        		'required'   => false,
	        	'validators' => [],
	        ]);



		if(count($rulesnameCF)==1 || $rulesnameCF[0]!=''){
		        $this->addElement('hidden', static::PFM_CFRule, [
			    'value' => ((bool) is_array($rulesnameCF)) ? array_keys($rulesnameCF)[0] : $rulesnameCF,
	        	]);
		        $this->addElement('SimpleText', "showrule", [
        		    'label'      => pm_Locale::lmsg('PathRulesC'),
			    'value' => ((bool) is_array($rulesnameCF)) ? str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",array_keys($rulesnameCF)[0]) : str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rulesnameCF),
        		]);
		}else{
	
		        $this->addElement('select', static::PFM_CFRule, [
        		    'label'      => pm_Locale::lmsg('PathRulesC'),
			    'multiOptions' => $rulesnameCF,
        		    'required'   => true,
	        	    'validators' => [],
	        	]);
		}

	        $this->addControlButtons([
			'sendTitle' => pm_Locale::lmsg('Import'),
			'cancelHidden' => true,
	        ]);
	}


    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

        return true;
    }

    /**
     * @return string
     */
    public function process(){


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
			$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
			$this->_redirect('index', [ 'exit' => true ]);
			return "2";
	}

	$this->app->CloudflareDomain = $_SESSION[pm_Context::getModuleInfo()->name]['domain'];

	$appjson = json_decode($this->app->TransferFWtoCF($this->getValue(static::PFM_FWRule),$this->getValue(static::PFM_CFRule)));
	if($appjson->result){return "1";}else{return "0";}


    }


 }

