<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */
/**
 * Class Modules_FlexFirewallManager_EventListener
 */
class Modules_FlexFirewallManager_EventListener implements EventListener
{
    public function filterActions()
    {
        return [
            "plesk_component_upgrade",
            "domain_dns_update",
	    "site_dns_update",
	    "domain_limits_update",
	    "domain_create",
	    "domain_delete",
	    "license_update",
	    "license_expired",
        ];
    }


    public function handleEvent($objectType, $objectId, $action, $oldValues, $newValues){

	pm_Context::init('flex-firewall-manager');

	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
		return;
	}

        switch ($action) {
            case "plesk_component_upgrade":
		if(Modules_FlexFirewallManager_Settings::GetSetting("Job")==""){
			Modules_FlexFirewallManager_Settings::SaveSetting("Job","PleskUser");
		}
                break;
            case "domain_create":
            case "domain_limits_update":

		$domInfo = pm_Domain::getByDomainId($objectId);

		if($domInfo->hasPermission('firewall_ext_api')){
			if(Modules_FlexFirewallManager_Settings::GetSetting($domInfo->getSysUserLogin(),"0","API")=="0"){
				Modules_FlexFirewallManager_Settings::SaveSetting($domInfo->getSysUserLogin(),"1","API");
			}
		}else{
			if(Modules_FlexFirewallManager_Settings::GetSetting($domInfo->getSysUserLogin(),"0","API")=="1"){
				Modules_FlexFirewallManager_Settings::SaveSetting($domInfo->getSysUserLogin(),"0","API");
			}
		}
                break;
            case "domain_delete":
		$domInfo = pm_Domain::getByDomainId($objectId);
		Modules_FlexFirewallManager_Settings::DeleteSetting($domInfo->getSysUserLogin(),"API");
                break;
            case "license_expired":
		try{
			$app = Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
			$app->BlockRDP(false);

		      if(Modules_FlexFirewallManager_Settings::GetSetting("status_RDP") == "1"){
		      		$notificationManager = new pm_Notification();
			      	$notificationManager->send("alert", ["customkey"=> "license_expired" , "customMessage" => pm_Locale::lmsg('Service.RDPlicense') , "customTitle" => pm_Locale::lmsg('Service.RDP')]);
		      }

		}catch(exception $e){
			error_log("[FlexFirewallManager] Exception plesk_license_expired : " . var_export($e,true));
		}
                break;
            case "license_update":
		if(Modules_FlexFirewallManager_Settings::GetSetting("status_RDP") == "1"){
			try{

				$app = Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
				$appjsonversion = json_decode($app->version);
				
				if($appjsonversion->result){
					if($appjsonversion->PleskLicense){
						$appjsonversion = json_decode($app->GetRuleName("Deny RDP"));
						if($appjsonversion->result && !$appjsonversion->status){
							$app->BlockRDP(true);
					      		$notificationManager = new pm_Notification();
						      	$notificationManager->send("info", ["customkey"=> "license_update" , "customMessage" => pm_Locale::lmsg('Service.RDPDelay') , "customTitle" => pm_Locale::lmsg('Service.RDP')]);
						}
					}else{
						$app->BlockRDP(false);
					}
				}else{
					$app->BlockRDP(false);
				}
			}catch(exception $e){
				error_log("[FlexFirewallManager] Exception plesk_license_update : " . var_export($e,true));
			}
		}
                break;
            case "domain_dns_update":
	    case "site_dns_update":

                $domain = new pm_Domain($objectId);

		$AutoSync=Modules_FlexFirewallManager_Settings::PleskDomainAutoSyncCF($domain->getName());
		if($AutoSync!="1"){return;}

		$CloudflareUserSetting = Modules_FlexFirewallManager_Settings::PleskDomainAccountCF($domain->getName());

		if(Modules_FlexFirewallManager_Settings::GetLength($CloudflareUserSetting)<2){return;}

		try{
			$txtdns = [];
			foreach(Modules_FlexFirewallManager_Settings::GetPleskDomainDnsRecords($domain->getName()) as $dns){
				if($dns->getType()=="A" || $dns->getType()=="AAAA" || $dns->getType()=="TXT"){
					$txtdns[]=array($dns->getType(),substr($dns->getHost(), 0, -1),$dns->getValue(),"");
				}else{
					$txtdns[]=array($dns->getType(),substr($dns->getHost(), 0, -1),substr($dns->getValue(), 0, -1),$dns->getOption("option"));
				}

			}

		}catch(exception $e){
		}

		Modules_FlexFirewallManager_Cloudflare::syncDns($domain->getName(),$CloudflareUserSetting,$txtdns);

		foreach(pm_DomainAlias::getByDomain($domain) as $alias){
			Modules_FlexFirewallManager_Cloudflare::SyncDomain($alias->getDisplayName(),$CloudflareUserSetting);
		}

                break;
        }
    }
}

return new Modules_FlexFirewallManager_EventListener();
