<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_FW_Add
 */
class Modules_FlexFirewallManager_FW_Add extends pm_Form_Simple
{

    const PFM_IP = 'iptoblock';
    const PFM_IPRule = 'iprule';

    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_Form_Add constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {

	
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

        parent::__construct($options);
    }



    /**
     * Init
     */
    public function init()
    {
        parent::init();

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

	$rulesname = [];
	$foundsession=false;
	$mainrulename="ADMIN";
	$mainrulenameid="Flex Firewall Manager - ADMIN";
	$rulesname = [$mainrulenameid=>$mainrulename];


	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){


		if(Modules_FlexFirewallManager_Settings::ClientAuth()){
			if(Modules_FlexFirewallManager_Settings::GetSetting("status_Client")!="1"){
				if(!pm_Session::getClient()->hasPermission('firewall_ext_add')){
					throw new pm_Exception(pm_Locale::lmsg('statusNO'));
				}
			}
		}

		unset($rulesname[$mainrulenameid]);

        	foreach (pm_Domain::getAllDomains(true) as $domain) {
            			if (!pm_Session::getClient()->isAdmin() && !pm_Session::getClient()->hasAccessToDomain($domain->getId())) {
                			continue;
	            		}

			if(Modules_FlexFirewallManager_Settings::ClientAuth()){
				if(Modules_FlexFirewallManager_Settings::GetSetting("status_ClientAdd")!="1" && !$domain->hasPermission('firewall_ext_add')){continue;}
			}

			$rulesname[Modules_FlexFirewallManager_Settings::Ext . " - " . $domain->getName()]=$domain->getName();

        	}

	}

	if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['rule'])){$_SESSION[pm_Context::getModuleInfo()->name]['rule']="";}


    	$appjson = json_decode($this->app->GetRulesNames());

	if($appjson->result){
		foreach($appjson->rules as $rules){

			if(Modules_FlexFirewallManager_Settings::AllowRule($rules->rulename)){
				$rulesname[$rules->rulename]=str_replace("Flex Firewall Manager - ", "", $rules->rulename);
			}

			if($rules->rulename==$_SESSION[pm_Context::getModuleInfo()->name]['rule']){$foundsession=true;}
	        
	    	}    
    
	}


	if($foundsession){
		unset($rulesname);
		$rulesname=$_SESSION[pm_Context::getModuleInfo()->name]['rule'];
	}

	if( (is_array($rulesname) && count($rulesname)==0) && $rulesname[0]==''){
		        $this->addElement('SimpleText', "showrule", [
        		    'label'      => pm_Locale::lmsg('PathRulesF'),
			    'escape' => false,
			    'value' => "<img src=\"".pm_Context::getBaseUrl() . "img/icon/warning.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"error\"> " . pm_Locale::lmsg('Rule.Deny'),
        		]);
	}else{

	       	$this->addElement('Text', static::PFM_IP, [
        	    'label'      => pm_Locale::lmsg('ToBlock_IP'),
		    'description' => pm_Locale::lmsg('ToBlock_IPDesc'),
        	    'required'   => true,
		    'validators' => array(
	                array('NotEmpty', true),
	            ),
        	]);


		if( (is_array($rulesname) && count($rulesname)==1) || !is_array($rulesname) ){

		        $this->addElement('hidden', static::PFM_IPRule, [
			    'value' => is_array($rulesname) ? array_keys($rulesname)[0] : $rulesname,
			    'escape' => false,
	        	]);

		        $this->addElement('SimpleText', "showrule", [
        		    'label'      => pm_Locale::lmsg('PathRulesF'),
			    'value' => is_array($rulesname) ? str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",array_keys($rulesname)[0]) : str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$rulesname),
        		]);
		}else{
	
		        $this->addElement('select', static::PFM_IPRule, [
        		    'label'      => pm_Locale::lmsg('PathRulesF'),
			    'multiOptions' => $rulesname,
        		    'required'   => false,
	        	    'validators' => [],
	        	]);
		}

	        $this->addControlButtons([
			'sendTitle' => pm_Locale::lmsg('Save'),
			'cancelHidden' => true,
	        ]);
	}


    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

        return true;
    }

    /**
     * @return string
     */
    public function process(){

	$IP=$this->getValue(static::PFM_IP);
	$TyBl="IP";
	if(substr($IP,0,2)=="AS"){$TyBl="ASN";}


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
		if($TyBl=="IP"){
			$appjson = json_decode($this->app->GetRuleName($this->getValue(static::PFM_IPRule)));

			if($appjson->result){
				if($appjson->numbersips>10){
					if(isset($_POST["domain"])){
						$output[]=array('status' => 'warning','msg' => pm_Locale::lmsg('statusPRO'));
						echo json_encode($output);
						exit;
					}
		                	return $TyBl.";2";
				}
			}
		}
		if($TyBl=="ASN"){
			if(isset($_POST["domain"])){
				$output[]=array('status' => 'warning','msg' => pm_Locale::lmsg('statusPRO'));
				echo json_encode($output);
				exit;
			}
			return $TyBl.";2";
		}


	}

	if($TyBl=="IP"){
		$appjson = json_decode($this->app->BlockIp($IP,"WINDOWS",$this->getValue(static::PFM_IPRule)));


		if($appjson->result){
			if(isset($_POST["domain"])){
				$output[]=array('status' => 'success','msg' => pm_Locale::lmsg('pageSaveOK'));
				echo json_encode($output);
				exit;
			}
			return $TyBl.";1;OK";
		}else{
			if(strpos($appjson->desc, "Pro Version")==false){
				if(isset($_POST["domain"])){
					$output[]=array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')) . ' ('.$appjson->desc.')');
					echo json_encode($output);
					exit;
				}
				return $TyBl.";0;".$appjson->desc;
			}else{
				if(isset($_POST["domain"])){
					$output[]=array('status' => 'warning','msg' => pm_Locale::lmsg('statusPRO'));
					echo json_encode($output);
					exit;
				}
				return $TyBl.";2;PRO";
			}
		}
	}

	if($TyBl=="ASN"){

		$appjson = json_decode($this->app->BlockASN($IP));

		if($appjson->result){
			$newasn=[];
			$asnlist=explode(",", Modules_FlexFirewallManager_Settings::GetSetting('ASNBlackList'));
			$found=array_search($IP, $asnlist);
			if($found==false){
				$newasn[]=$IP;
			}
			$asnnew=implode(",", array_merge($asnlist,$newasn));
			if($asnnew[0]==','){$asnnew=substr($asnnew, 1,-1);}
			Modules_FlexFirewallManager_Settings::SaveSetting('ASNBlackList', $asnnew);

			if(isset($_POST["domain"])){
				$output[]=array('status' => 'success','msg' => pm_Locale::lmsg('pageSaveOK'));
				echo json_encode($output);
				exit;
			}
			return $TyBl.";1;OK";
		}else{

			if(strpos($appjson->desc, "Pro Version")==false){
				if(isset($_POST["domain"])){
					$output[]=array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')). ' ('.$appjson->desc.')');
					echo json_encode($output);
					exit;
				}
				return $TyBl.";0;".$appjson->desc;
			}else{
				if(isset($_POST["domain"])){
					$output[]=array('status' => 'warning','msg' => pm_Locale::lmsg('statusPRO'));
					echo json_encode($output);
					exit;
				}
				return $TyBl.";2;PRO";
			}
		}
	}


    }


 }

