<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_Form_AddWL
 */
class Modules_FlexFirewallManager_Form_AddWL extends pm_Form_Simple
{

    const PFM_IP = 'WhiteListAdd';
    const PFM_REMOVE = 'RemoveBlocked';


    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_Form_AddWL constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init()
    {
        parent::init();

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

        $this->addElement('Text', static::PFM_IP, [
            'label'      => pm_Locale::lmsg('AddWhiteList'),
	    'description' => pm_Locale::lmsg('AddWhiteListDesc'),
            'required'   => true,
	    'validators' => array(
                array('NotEmpty', true),
            ),
        ]);


 	$this->addElement('checkbox', static::PFM_REMOVE, array(
           	'label' => pm_Locale::lmsg('AddWhiteListRemove'),
	    	'description' => pm_Locale::lmsg('AddWhiteListRemoveDesc'),
	        'required'   => false,
	        'value' => "0",
        ));

        $this->addControlButtons([
		'sendTitle' => pm_Locale::lmsg('Save'),
		'cancelHidden' => true,
        ]);
    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }


	if($data[static::PFM_IP]=="*.*.*.*" || $data[static::PFM_IP]=="::1"){
		$this->markAsError();
		$this->getElement(static::PFM_IP)->addError(pm_Locale::lmsg('Error.Format'));
		return false;
	}

	if(strpos($data[static::PFM_IP], ".")!== false && strpos($data[static::PFM_IP], "*")=== false){
		if (!filter_var($data[static::PFM_IP], FILTER_VALIDATE_IP)) {
			$this->markAsError();
			$this->getElement(static::PFM_IP)->addError(pm_Locale::lmsg('Error.Format'));
			return false;
		}
	}

	if(strpos($data[static::PFM_IP], ":")!== false){
		if (!filter_var($data[static::PFM_IP], FILTER_VALIDATE_IP)) {
			$this->markAsError();
			$this->getElement(static::PFM_IP)->addError(pm_Locale::lmsg('Error.Format'));
			return false;
		}
	}

	if($data[static::PFM_REMOVE]=="1" && strpos($data[static::PFM_IP], '*')>0){
		$this->markAsError();
		$this->getElement(static::PFM_REMOVE)->addError(pm_Locale::lmsg('AddWhiteListRemoveDescError'));
		return false;
	}


	if(strpos($data[static::PFM_IP], ".")!== false && strpos($data[static::PFM_IP], "*")!== false){
		$found = false ;
		foreach (explode('.',$data[static::PFM_IP]) as $item){
			if($found && $item!='*'){
				$this->markAsError();
				$this->getElement(static::PFM_IP)->addError(pm_Locale::lmsg('Error.Format'));
				return false;
			}
			if($item!='*' && !is_numeric($item)){
				$this->markAsError();
				$this->getElement(static::PFM_IP)->addError(pm_Locale::lmsg('Error.Format'));
				return false;
			}

			if($item=='*'){$found=true;}
		}
	}


        return true;
    }

    /**
     * @return integer
     */
    public function process(){


	$ip=$this->getValue(static::PFM_IP);

	if(strpos(Modules_FlexFirewallManager_Settings::GetSetting('Whitelist'), $ip)!=false){
		return "0";
	}
	

	if(!Modules_FlexFirewallManager_Settings::isLicenced()){
		if(count(explode(",", Modules_FlexFirewallManager_Settings::GetSetting('Whitelist')))>3){
	                return "2";
		}
	}

	$wildcardip=str_replace("*", "1", $ip);


	if($this->app->isIP($wildcardip)){

		$appjson = json_decode($this->app->AddWhiteList($ip));

		if($appjson->result){
			if($this->getValue(static::PFM_REMOVE)=="1"){
				$this->app->UnlockIPFromAllRules($ip);
			}

			return "1";
		}else{
			return $appjson->desc;
		}
	}else{
		return "0";
	}

    }


 }

