<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_Form_Firewall
 */
class Modules_FlexFirewallManager_Form_Firewall extends pm_Form_Simple
{

    const PFM_Risk_Status = 'EnableRisk';
    const PFM_Abuse_Status = 'ReportAbuseIP';

    const PFM_SMTP_Status = 'EnableSMTP';
    const PFM_IMAP_Status = 'EnableIMAP';
    const PFM_POP_Status = 'EnablePOP';
    const PFM_FTP_Status = 'EnableFTP';
    const PFM_Security_Status = 'EnableSecurity';
    const PFM_DB_Status = 'EnableDB';
    const PFM_RDP_Status = 'EnableRDP';

    const PFM_SMTP_Port = 'PortSMTP';
    const PFM_IMAP_Port = 'PortIMAP';
    const PFM_POP_Port = 'PortPOP';
    const PFM_FTP_Port = 'PortFTP';

    const PFM_SMTP_Lock = 'LockSMTP';
    const PFM_IMAP_Lock = 'LockIMAP';
    const PFM_POP_Lock = 'LockPOP';
    const PFM_FTP_Lock = 'LockFTP';
    const PFM_Security_Lock = 'LockSecurity';
    const PFM_DB_Lock = 'LockDB';
    const PFM_RDP_Lock = 'LockRDP';

    const PFM_SMTP_Attemp = 'DetectSMTP';
    const PFM_IMAP_Attemp = 'DetectIMAP';
    const PFM_POP_Attemp = 'DetectPOP';
    const PFM_FTP_Attemp = 'DetectFTP';
    const PFM_Security_Attemp = 'DetectSecurity';
    const PFM_DB_Attemp = 'DetectDB';
    const PFM_RDP_Attemp = 'DetectRDP';

    const PFM_SMTP_Reload = 'ReloadSMTP';
    const PFM_IMAP_Reload = 'ReloadIMAP';
    const PFM_POP_Reload = 'ReloadPOP';
    const PFM_FTP_Reload = 'ReloadFTP';
    const PFM_Security_Reload = 'ReloadSecurity';
    const PFM_DB_Reload = 'ReloadDB';
    const PFM_RDP_Reload = 'ReloadRDP';

    const PFM_SMTP_Delete = 'DeleteSMTP';
    const PFM_IMAP_Delete = 'DeleteIMAP';
    const PFM_POP_Delete = 'DeletePOP';
    const PFM_FTP_Delete = 'DeleteFTP';
    const PFM_RDP_Delete = 'DeleteRDP';

    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_Form_Firewall constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init(){
        parent::init();

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

	$appjson = json_decode($this->app->version);

	$langmins=pm_Locale::lmsg('mins');
	$langhours=pm_Locale::lmsg('hours');
	$langdays=pm_Locale::lmsg('days');
	$langattemp=pm_Locale::lmsg('attemps');


	$attemp = array(3 => "3 $langattemp",4 => "4 $langattemp",5 => "5 $langattemp",6 => "6 $langattemp",7 => "7 $langattemp",8 => "8 $langattemp",9 => "9 $langattemp",10 => "10 $langattemp");
	if (!Modules_FlexFirewallManager_Settings::isLicenced()){$attemp = array(6 => "6 $langattemp",7 => "7 $langattemp",8 => "8 $langattemp",9 => "9 $langattemp",10 => "10 $langattemp");}

	$tiempo_lock = array(5 => "5 $langmins",10 => "10 $langmins",15 => "15 $langmins",30 => "30 $langmins");
	if (Modules_FlexFirewallManager_Settings::isLicenced()){
		for ($i = 1; $i <= 24; $i++) {
			 $tiempo_lock += [ (60 * $i) => "$i $langhours"];
		}
		$tiempo_lock += [ (60 * 24 * 2) => "2 $langdays"];
		$tiempo_lock += [ (60 * 24 * 3) => "3 $langdays"];
		$tiempo_lock += [ (60 * 24 * 4) => "4 $langdays"];
		$tiempo_lock += [ (60 * 24 * 5) => "5 $langdays"];
		$tiempo_lock += [ 0 => pm_Locale::lmsg('LockPermanent')];
	}




	$DisabledElement=true;
	if ($appjson->MailServer!="None"){$DisabledElement=null;}

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
	
	
		/****** SMTP ****/

	        $this->addElement('SimpleText', static::PFM_SMTP_Status, [
        	    'label'      => pm_Locale::lmsg('SMTPStatus'),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Status)),
	        ]);


	        $this->addElement('SimpleText', static::PFM_SMTP_Port, [
        	    'label'      => pm_Locale::lmsg('SMTPPort'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Port),
	        ]);

	        $this->addElement('SimpleText', static::PFM_SMTP_Attemp, [
        	    'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Attemp),
	       	]);


	        $this->addElement('SimpleText', static::PFM_SMTP_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => self::LockStringTime(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Lock)),
	        ]);

		$this->addDisplayGroup(array(static::PFM_SMTP_Port,static::PFM_SMTP_Attemp, static::PFM_SMTP_Lock), 'SMTP');

		/****** IMAP ****/
	
	
	        $this->addElement('SimpleText', static::PFM_IMAP_Status, [
	            'label'      => pm_Locale::lmsg('IMAPStatus'),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Status)),
	        ]);
	
	
	        $this->addElement('SimpleText', static::PFM_IMAP_Port, [
	            'label'      => pm_Locale::lmsg('IMAPPort'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Port),
	        ]);
	
	        $this->addElement('SimpleText', static::PFM_IMAP_Attemp, [
	            'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Attemp),
	        ]);
	
	
	        $this->addElement('SimpleText', static::PFM_IMAP_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => self::LockStringTime(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Lock)),
	        ]);
	
		$this->addDisplayGroup(array(static::PFM_IMAP_Port,static::PFM_IMAP_Attemp, static::PFM_IMAP_Lock), 'IMAP');
	
		/****** POP ****/
	
	
	        $this->addElement('SimpleText', static::PFM_POP_Status, [
	            'label'      => pm_Locale::lmsg('POPStatus'),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Status)),
	        ]);
	
	        $this->addElement('SimpleText', static::PFM_POP_Port, [
	            'label'      => pm_Locale::lmsg('POPPort'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Port),
	        ]);
	
	        $this->addElement('SimpleText', static::PFM_POP_Attemp, [
	            'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Attemp),
	        ]);
	
	
	        $this->addElement('SimpleText', static::PFM_POP_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => self::LockStringTime(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Lock)),
	        ]);

		$this->addDisplayGroup(array(static::PFM_POP_Port,static::PFM_POP_Attemp, static::PFM_POP_Lock), 'POP');
	
		/****** FTP ****/
	
	
	        $this->addElement('SimpleText', static::PFM_FTP_Status, [
	            'label'      => pm_Locale::lmsg('FTPStatus'),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Status)),
	        ]);
	
	        $this->addElement('SimpleText', static::PFM_FTP_Port, [
	            'label'      => pm_Locale::lmsg('FTPPort'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Port),
	        ]);
	
	        $this->addElement('SimpleText', static::PFM_FTP_Attemp, [
	            'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Attemp),
	        ]);
	
	
	        $this->addElement('SimpleText', static::PFM_FTP_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => self::LockStringTime(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Lock)),
	        ]);
	
		$this->addDisplayGroup(array(static::PFM_FTP_Port,static::PFM_FTP_Attemp, static::PFM_FTP_Lock), 'FTP');


		/****** Security ****/
	
	
	        $this->addElement('SimpleText', static::PFM_Security_Status, [
	            'label'      => pm_Locale::lmsg('SecurityStatus'),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Security_Status)),
	        ]);
	
	
	        $this->addElement('SimpleText', static::PFM_Security_Attemp, [
	            'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Security_Attemp),
	        ]);
	
	
	        $this->addElement('SimpleText', static::PFM_Security_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => self::LockStringTime(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Security_Lock)),
	        ]);
	
		$this->addDisplayGroup(array(static::PFM_Security_Attemp, static::PFM_Security_Lock), 'Security');

		/****** DB ****/
	
		
	        $this->addElement('SimpleText', static::PFM_DB_Status, [
	            'label'      => pm_Locale::lmsg('DBStatus'),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DB_Status)),
	        ]);
	
	
		        $this->addElement('SimpleText', static::PFM_DB_Attemp, [
	        	    'label'      => pm_Locale::lmsg('Attemp'),
		            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DB_Attemp),
	        	]);
	
		
	        	$this->addElement('SimpleText', static::PFM_DB_Lock, [
		            'label'      => pm_Locale::lmsg('Lock'),
	        	    'value'      => self::LockStringTime(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DB_Lock)),
		        ]);
	
			$this->addDisplayGroup(array(static::PFM_DB_Attemp, static::PFM_DB_Lock), 'DB');

		/****** RDP ****/
	
	
	        $this->addElement('SimpleText', static::PFM_RDP_Status, [
	            'label'      => pm_Locale::lmsg('RDPStatus'),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Status)),
	        ]);
	
	
		        $this->addElement('SimpleText', static::PFM_RDP_Attemp, [
	        	    'label'      => pm_Locale::lmsg('Attemp'),
		            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Attemp),
	        	]);
		
	
	
		        $this->addElement('SimpleText', static::PFM_RDP_Lock, [
	        	    'label'      => pm_Locale::lmsg('Lock'),
		            'value'      => self::LockStringTime(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Lock)),
	        	]);
	
		$this->addDisplayGroup(array(static::PFM_RDP_Attemp, static::PFM_RDP_Lock), 'RDP');


	}else{

		$ME_override = Modules_FlexFirewallManager_Settings::GetSetting("EnableMEOverride",0);

		$this->addElement('hidden', static::PFM_Risk_Status, [
        		    'title'      => pm_Locale::lmsg('RiskStatus'),
       			    'data-description'      => pm_Locale::lmsg('RiskStatusDesc') ,
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Risk_Status),
	        	    'required'   => false,
        		    'class'   => 'switch',
        		    'data-action'   => 'saveitems',
        		    'data-loading'   => 'true',

        	]);


	        $this->addElement('SimpleText', "Item".static::PFM_Abuse_Status, [
        	    'label'      => pm_Locale::lmsg('AbuseStatus'),
	            'value'      => pm_Locale::lmsg('AbuseStatusDesc'),
        	    'class'   => 'hint',
	       	]);

		$this->addElement('hidden', static::PFM_Abuse_Status, [
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Abuse_Status),
	        	    'required'   => false,
        	]);

		$formAbuse = new pm_Form_Simple();
	        $formAbuse->addElement('textarea', "draw".static::PFM_Abuse_Status, [
        	    'label'      => pm_Locale::lmsg('AbuseIP.Key'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Abuse_Status),
		    'title' => pm_Locale::lmsg('AbuseIP.KeyDesc'),
		    'description' => pm_Locale::lmsg('AbuseIP.disable'),
	            'required'   => false,
	            'cols'   => 40,
	            'rows'   => 3,
	        ]);

		$this->addSubForm($formAbuse,"SubFormAbuse");

		/*************************/

		/****** SMTP ****/

		$this->addElement('hidden', static::PFM_SMTP_Status, [
			'value'      => ($DisabledElement==null ? Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Status) : 0),
			'class'   => 'card',
			'disabled'   => $DisabledElement,
		        'title'   => pm_Locale::lmsg('SMTPStatus'),
		]);

		$formSMTP = new pm_Form_Simple();

		if(pm_Config::get('CleanRule') && $ME_override=="0"){
	        	$this->addElement('hidden', static::PFM_SMTP_Delete, [
        		    'value'      => "1",
		        ]);
	        	$formSMTP->addElement('hidden', "draw".static::PFM_SMTP_Delete, [
        		    'value'      => "1",
		        ]);
		}else{

			if( $ME_override=="0" ){
		        	$this->addElement('hidden', static::PFM_SMTP_Delete, [
        			    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Delete),
			        ]);
		        	$formSMTP->addElement('select', "draw".static::PFM_SMTP_Delete, [
			            'label'      => pm_Locale::lmsg('Clean'),
		        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Delete),
				    'description' => pm_Locale::lmsg('AutoDelete'),
				    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
		        	    'required'   => true,
			            'validators' => [],
			        ]);
			}else{
		        	$this->addElement('hidden', static::PFM_SMTP_Delete, [
        			    'value'      => "0",
			        ]);
		        	$formSMTP->addElement('hidden', "draw".static::PFM_SMTP_Delete, [
			            'value'      => "0",
			        ]);
			}
		}


		if( $ME_override=="0" ){
		        $formSMTP->addElement('Text', "draw".static::PFM_SMTP_Port, [
        		    'label'      => pm_Locale::lmsg('SMTPPort'),
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Port),
			    'description' => pm_Locale::lmsg('SMTPPortDesc'),
		            'required'   => false,
	        	]);
		}else{
		        $formSMTP->addElement('hidden', "draw".static::PFM_SMTP_Port, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Port),
	        	]);
		}

		$this->addElement('hidden', static::PFM_SMTP_Port, [
        		'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Port),
		]);


	        $formSMTP->addElement('select', "draw".static::PFM_SMTP_Attemp, [
        	    'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Attemp),
		    'description' => pm_Locale::lmsg('AttempDesc'),
		    'multiOptions' => $attemp,
        	    'required'   => true,
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::PFM_SMTP_Attemp, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Attemp),
		]);

	        $formSMTP->addElement('select', "draw".static::PFM_SMTP_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Lock),
		    'description' => pm_Locale::lmsg('LockDesc'),
		    'multiOptions' => $tiempo_lock,
	            'required'   => true,
	            'onchange'   => 'ShowRowForm("SMTP")',
	            'validators' => [],
	        ]);

	        $this->addElement('hidden', static::PFM_SMTP_Lock, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Lock),
		]);

		if(pm_Config::get('onChangeSettingUpdateRule')){
	        	$formSMTP->addElement('hidden', "draw".static::PFM_SMTP_Reload, [
        		    'value'      => "1",
		        ]);

		        $this->addElement('hidden', static::PFM_SMTP_Reload, [
        		    'value'      => "1",
			]);
		}else{
		        $formSMTP->addElement('select', "draw".static::PFM_SMTP_Reload, [
		            'label'      => pm_Locale::lmsg('Reload'),
	        	    'value'      => 0,
			    'description' => pm_Locale::lmsg('ReloadDesc'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);

		        $this->addElement('hidden', static::PFM_SMTP_Reload, [
        		    'value'      => "0",
			]);
		}


		$this->addSubForm($formSMTP,"SubFormSMTP");



		/****** IMAP ****/
	

		$this->addElement('hidden', static::PFM_IMAP_Status, [
			'value'      => ($DisabledElement==null ? Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Status) : 0),
			'class'   => 'card',
			'disabled'   => $DisabledElement,
		        'title'   => pm_Locale::lmsg('IMAPStatus'),
		]);

		$formIMAP = new pm_Form_Simple();

	
		if(pm_Config::get('CleanRule')){
	        	$formIMAP->addElement('hidden', "draw".static::PFM_IMAP_Delete, [
        		    'value'      => "1",
		        ]);
		        $this->addElement('hidden', static::PFM_IMAP_Delete, [
        		    'value'      => "1",
			]);
		}else{
		        $formIMAP->addElement('select', "draw".static::PFM_IMAP_Delete, [
		            'label'      => pm_Locale::lmsg('Clean'),
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Delete),
			    'description' => pm_Locale::lmsg('AutoDelete'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);

		        $this->addElement('hidden', static::PFM_IMAP_Delete, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Delete),
			]);
		}
	
	        $formIMAP->addElement('Text', "draw".static::PFM_IMAP_Port, [
	            'label'      => pm_Locale::lmsg('IMAPPort'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Port),
		    'description' => pm_Locale::lmsg('IMAPPortDesc'),
	            'required'   => false,
	        ]);
		$this->addElement('hidden', static::PFM_IMAP_Port, [
        		'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Port),
		]);
	
	        $formIMAP->addElement('select', "draw".static::PFM_IMAP_Attemp, [
	            'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Attemp),
		    'description' => pm_Locale::lmsg('AttempDesc'),
		    'multiOptions' => $attemp,
	            'required'   => true,
	            'validators' => [],
	        ]);
		$this->addElement('hidden', static::PFM_IMAP_Attemp, [
        		'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Attemp),
		]);
	
	
	        $formIMAP->addElement('select', "draw".static::PFM_IMAP_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Lock),
		    'description' => pm_Locale::lmsg('LockDesc'),
		    'multiOptions' => $tiempo_lock,
	            'required'   => true,
	            'onchange'   => 'ShowRowForm("IMAP")',
	            'validators' => [],
	        ]);
		$this->addElement('hidden', static::PFM_IMAP_Lock, [
        		'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Lock),
		]);
	

		if(pm_Config::get('onChangeSettingUpdateRule')){
	        	$formIMAP->addElement('hidden', "draw".static::PFM_IMAP_Reload, [
        		    'value'      => "1",
		        ]);
			$this->addElement('hidden', static::PFM_IMAP_Reload, [
        			'value'      => 1,
			]);
		}else{
		        $formIMAP->addElement('select', "draw".static::PFM_IMAP_Reload, [
		            'label'      => pm_Locale::lmsg('Reload'),
	        	    'value'      => 0,
			    'description' => pm_Locale::lmsg('ReloadDesc'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);
			$this->addElement('hidden', static::PFM_IMAP_Reload, [
        			'value'      => 0,
			]);
		}
	

		$this->addSubForm($formIMAP,"SubFormIMAP");

		/****** POP ****/
	

		$this->addElement('hidden', static::PFM_POP_Status, [
			'value'      => ($DisabledElement==null ? Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Status) : 0),
			'class'   => 'card',
			'disabled'   => $DisabledElement,
		        'title'   => pm_Locale::lmsg('POPStatus'),
		]);

		$formPOP = new pm_Form_Simple();
	

		if(pm_Config::get('CleanRule') && $ME_override=="0"){
	        	$formPOP->addElement('hidden', "draw".static::PFM_POP_Delete, [
        		    'value'      => "1",
		        ]);
			$this->addElement('hidden', static::PFM_POP_Delete, [
        			'value'      => 1,
			]);
		}else{

			if( $ME_override=="0" ){
			        $formPOP->addElement('select', "draw".static::PFM_POP_Delete, [
			            'label'      => pm_Locale::lmsg('Clean'),
	        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Delete),
				    'description' => pm_Locale::lmsg('AutoDelete'),
				    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
		        	    'required'   => true,
			            'validators' => [],
		        	]);
				$this->addElement('hidden', static::PFM_POP_Delete, [
        				'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Delete),
				]);
			}else{
			        $formPOP->addElement('hidden', "draw".static::PFM_POP_Delete, [
			            'value'      => "0",
		        	]);
				$this->addElement('hidden', static::PFM_POP_Delete, [
        				'value'      => "0",
				]);
			}
		}
	
		if( $ME_override=="0" ){
		        $formPOP->addElement('Text', "draw".static::PFM_POP_Port, [
		            'label'      => pm_Locale::lmsg('POPPort'),
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Port),
			    'description' => pm_Locale::lmsg('POPPortDesc'),
		            'required'   => false,
	        	]);
		}else{
		        $formPOP->addElement('hidden', "draw".static::PFM_POP_Port, [
		            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Port),
	        	]);
		}
		$this->addElement('hidden', static::PFM_POP_Port, [
        		'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Port),
		]);
	
	        $formPOP->addElement('select', "draw".static::PFM_POP_Attemp, [
	            'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Attemp),
		    'description' => pm_Locale::lmsg('AttempDesc'),
		    'multiOptions' => $attemp,
	            'required'   => true,
	            'validators' => [],
	        ]);
		$this->addElement('hidden', static::PFM_POP_Attemp, [
        		'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Attemp),
		]);	
	
	        $formPOP->addElement('select', "draw".static::PFM_POP_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Lock),
		    'description' => pm_Locale::lmsg('LockDesc'),
		    'multiOptions' => $tiempo_lock,
	            'required'   => true,
	            'onchange'   => 'ShowRowForm("POP")',
	            'validators' => [],
	        ]);
		$this->addElement('hidden', static::PFM_POP_Lock, [
        		'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Lock),
		]);	

		if(pm_Config::get('onChangeSettingUpdateRule')){
	        	$formPOP->addElement('hidden', "draw".static::PFM_POP_Reload, [
        		    'value'      => "1",
		        ]);
			$this->addElement('hidden', static::PFM_POP_Reload, [
        			'value'      => 1,
			]);
		}else{
		        $formPOP->addElement('select', "draw".static::PFM_POP_Reload, [
		            'label'      => pm_Locale::lmsg('Reload'),
	        	    'value'      => 0,
			    'description' => pm_Locale::lmsg('ReloadDesc'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);
			$this->addElement('hidden', static::PFM_POP_Reload, [
        			'value'      => 0,
			]);
		}
	

		$this->addSubForm($formPOP,"SubFormPOP");

		/****** FTP ****/
	

		$this->addElement('hidden', static::PFM_FTP_Status, [
			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Status),
			'class'   => 'card',
		        'title'   => pm_Locale::lmsg('FTPStatus'),
		]);

		$formFTP = new pm_Form_Simple();
	

		if(pm_Config::get('CleanRule')){
	        	$formFTP->addElement('hidden', "draw".static::PFM_FTP_Delete, [
        		    'value'      => "1",
		        ]);
			$this->addElement('hidden', static::PFM_FTP_Delete, [
        			'value'      => 1,
			]);
		}else{
		        $formFTP->addElement('select', "draw".static::PFM_FTP_Delete, [
		            'label'      => pm_Locale::lmsg('Clean'),
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Delete),
			    'description' => pm_Locale::lmsg('AutoDelete'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);
			$this->addElement('hidden', static::PFM_FTP_Delete, [
        			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Delete),
			]);
		}
	
	        $formFTP->addElement('Text', "draw".static::PFM_FTP_Port, [
	            'label'      => pm_Locale::lmsg('FTPPort'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Port),
		    'description' => pm_Locale::lmsg('FTPPortDesc'),
	            'required'   => false,
	        ]);
		$this->addElement('hidden', static::PFM_FTP_Port, [
       			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Port),
		]);
	
	        $formFTP->addElement('select', "draw".static::PFM_FTP_Attemp, [
	            'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Attemp),
		    'description' => pm_Locale::lmsg('AttempDesc'),
		    'multiOptions' => $attemp,
	            'required'   => true,
	            'validators' => [],
	        ]);
		$this->addElement('hidden', static::PFM_FTP_Attemp, [
       			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Attemp),
		]);
	
	
	        $formFTP->addElement('select', "draw".static::PFM_FTP_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Lock),
		    'description' => pm_Locale::lmsg('LockDesc'),
		    'multiOptions' => $tiempo_lock,
	            'required'   => true,
	            'onchange'   => 'ShowRowForm("FTP")',
	            'validators' => [],
	        ]);
		$this->addElement('hidden', static::PFM_FTP_Lock, [
       			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Lock),
		]);

		if(pm_Config::get('onChangeSettingUpdateRule')){
	        	$formFTP->addElement('hidden', "draw".static::PFM_FTP_Reload, [
        		    'value'      => "1",
		        ]);
			$this->addElement('hidden', static::PFM_FTP_Reload, [
       				'value'      => 1,
			]);
		}else{
		        $formFTP->addElement('select', "draw".static::PFM_FTP_Reload, [
		            'label'      => pm_Locale::lmsg('Reload'),
	        	    'value'      => 0,
			    'description' => pm_Locale::lmsg('ReloadDesc'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);
			$this->addElement('hidden', static::PFM_FTP_Reload, [
       				'value'      => 0,
			]);
		}
	
		$this->addSubForm($formFTP,"SubFormFTP");
	
		/****** Security ****/
	

		$this->addElement('hidden', static::PFM_Security_Status, [
			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Security_Status),
			'class'   => 'card',
		        'title'   => pm_Locale::lmsg('SecurityStatus'),
		]);

		$formSecurity = new pm_Form_Simple();
	
	
	        $formSecurity->addElement('select', "draw".static::PFM_Security_Attemp, [
	            'label'      => pm_Locale::lmsg('Attemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Security_Attemp),
		    'description' => pm_Locale::lmsg('AttempDesc'),
		    'multiOptions' => $attemp,
	            'required'   => true,
	            'validators' => [],
	        ]);
		$this->addElement('hidden', static::PFM_Security_Attemp, [
			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Security_Attemp),
		]);	
	
	        $formSecurity->addElement('select', "draw".static::PFM_Security_Lock, [
	            'label'      => pm_Locale::lmsg('Lock'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Security_Lock),
		    'description' => pm_Locale::lmsg('LockDesc'),
		    'multiOptions' => $tiempo_lock,
	            'required'   => true,
	            'onchange'   => 'ShowRowForm("Security")',
	            'validators' => [],
	        ]);
		$this->addElement('hidden', static::PFM_Security_Lock, [
			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Security_Lock),
		]);

		if(pm_Config::get('onChangeSettingUpdateRule')){
	        	$formSecurity->addElement('hidden', "draw".static::PFM_Security_Reload, [
        		    'value'      => "1",
		        ]);
			$this->addElement('hidden', static::PFM_Security_Reload, [
				'value'      => 1,
			]);
		}else{
		        $formSecurity->addElement('select', "draw".static::PFM_Security_Reload, [
		            'label'      => pm_Locale::lmsg('Reload'),
	        	    'value'      => 0,
			    'description' => pm_Locale::lmsg('ReloadDesc'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);
			$this->addElement('hidden', static::PFM_Security_Reload, [
				'value'      => 0,
			]);
		}


		$this->addSubForm($formSecurity,"SubFormSecurity");
	
		/****** DB ****/
	
		$this->addElement('hidden', static::PFM_DB_Status, [
			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DB_Status),
			'class'   => 'card',
		        'title'   => pm_Locale::lmsg('DBStatus'),
		]);

		$formDB = new pm_Form_Simple();	
	
	
		        $formDB->addElement('select', "draw".static::PFM_DB_Attemp, [
	        	    'label'      => pm_Locale::lmsg('Attemp'),
		            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DB_Attemp),
			    'description' => pm_Locale::lmsg('AttempDesc'),
			    'multiOptions' => $attemp,
	        	    'required'   => true,
		            'validators' => [],
	        	]);
			$this->addElement('hidden', static::PFM_DB_Attemp, [
				'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DB_Attemp),
			]);
	
		
	        	$formDB->addElement('select', "draw".static::PFM_DB_Lock, [
		            'label'      => pm_Locale::lmsg('Lock'),
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DB_Lock),
			    'description' => pm_Locale::lmsg('LockDesc'),
			    'multiOptions' => $tiempo_lock,
		            'required'   => true,
		            'onchange'   => 'ShowRowForm("DB")',
	        	    'validators' => [],
		        ]);

			$this->addElement('hidden', static::PFM_DB_Lock, [
				'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DB_Lock),
			]);

		if(pm_Config::get('onChangeSettingUpdateRule')){
	        	$formDB->addElement('hidden', "draw".static::PFM_DB_Reload, [
        		    'value'      => "1",
		        ]);
			$this->addElement('hidden', static::PFM_DB_Reload, [
				'value'      => 1,
			]);
		}else{
			 $formDB->addElement('select', "draw".static::PFM_DB_Reload, [
		            'label'      => pm_Locale::lmsg('Reload'),
	        	    'value'      => 0,
			    'description' => pm_Locale::lmsg('ReloadDesc'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);
			$this->addElement('hidden', static::PFM_DB_Reload, [
				'value'      => 0,
			]);
		}

		$this->addSubForm($formDB,"SubFormDB");
	
		/****** RDP ****/
	

		$this->addElement('hidden', static::PFM_RDP_Status, [
			'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Status),
			'class'   => 'card',
		        'title'   => pm_Locale::lmsg('RDPStatus'),
		]);

		$formRDP = new pm_Form_Simple();	

	        $formRDP->addElement('select', "draw".static::PFM_RDP_Delete, [
	            'label'      => pm_Locale::lmsg('Clean'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Delete),
		    'description' => pm_Locale::lmsg('AutoDelete'),
		    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	            'required'   => true,
	            'validators' => [],
	        ]);
			$this->addElement('hidden', static::PFM_RDP_Delete, [
				'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Delete),
			]);
	
		        $formRDP->addElement('select', "draw".static::PFM_RDP_Attemp, [
	        	    'label'      => pm_Locale::lmsg('Attemp'),
		            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Attemp),
			    'description' => pm_Locale::lmsg('AttempDesc'),
			    'multiOptions' => $attemp,
	        	    'required'   => true,
		            'validators' => [],
	        	]);
			$this->addElement('hidden', static::PFM_RDP_Attemp, [
				'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Attemp),
			]);		
	
	
		        $formRDP->addElement('select', "draw".static::PFM_RDP_Lock, [
	        	    'label'      => pm_Locale::lmsg('Lock'),
		            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Lock),
			    'description' => pm_Locale::lmsg('LockDesc'),
			    'multiOptions' => $tiempo_lock,
		            'onchange'   => 'ShowRowForm("RDP")',
	        	    'required'   => true,
		            'validators' => [],
	        	]);
			$this->addElement('hidden', static::PFM_RDP_Lock, [
				'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RDP_Lock),
			]);	

		if(pm_Config::get('onChangeSettingUpdateRule')){
	        	$formRDP->addElement('hidden', "draw".static::PFM_RDP_Reload, [
        		    'value'      => "1",
		        ]);
			$this->addElement('hidden', static::PFM_RDP_Reload, [
				'value'      => 1,
			]);	
		}else{
			 $formRDP->addElement('select', "draw".static::PFM_RDP_Reload, [
		            'label'      => pm_Locale::lmsg('Reload'),
	        	    'value'      => 0,
			    'description' => pm_Locale::lmsg('ReloadDesc'),
			    'multiOptions' => [ 0 => pm_Locale::lmsg('No') , 1 => pm_Locale::lmsg('Yes')],
	        	    'required'   => true,
		            'validators' => [],
		        ]);
			$this->addElement('hidden', static::PFM_RDP_Reload, [
				'value'      => 0,
			]);	
		}
	
		
		$this->addSubForm($formRDP,"SubFormRDP");
	        
	    }
	        
    }



	public function LockStringTime($value){
		if($value==0){
			return pm_Locale::lmsg('LockPermanent');
		}else{
			if($value<60){
				return $value ." " . pm_Locale::lmsg('mins');
			}else{
				if($value<(60*24)){
					return $value/60 ." " . pm_Locale::lmsg('hours');
				}else{
					return $value/60/24 ." " . pm_Locale::lmsg('days');
				}
			}
		}
	}

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }


        return true;
    }

    /**
     * @return boolean
     */
    public function process()
    {
        
	$UpdateSMTP=false;
	$UpdateIMAP=false;
	$UpdatePOP=false;
	$UpdateFTP=false;

	$ReloadSMTP=false;
	$ReloadIMAP=false;
	$ReloadPOP=false;
	$ReloadFTP=false;
	$ReloadSecurity=false;
	$ReloadDB=false;
	$ReloadRDP=false;



        Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_Risk_Status,$this->getValue(static::PFM_Risk_Status));
	if(Modules_FlexFirewallManager_Settings::isLicenced()){
        	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_Abuse_Status,$this->getValue(static::PFM_Abuse_Status));
	}

	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_SMTP_Status, $this->getValue(static::PFM_SMTP_Status));
	if($this->getValue(static::PFM_SMTP_Status)=="1"){
		$UpdateSMTP=(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_SMTP_Port)!=$this->getValue(static::PFM_SMTP_Port));
		if($this->getValue(static::PFM_SMTP_Reload)=="1"){$ReloadSMTP=true;}
	}
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_SMTP_Port, preg_replace('/\s+/', '', $this->getValue(static::PFM_SMTP_Port)));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_SMTP_Lock, $this->getValue(static::PFM_SMTP_Lock));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_SMTP_Attemp, $this->getValue(static::PFM_SMTP_Attemp));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_SMTP_Delete, $this->getValue(static::PFM_SMTP_Delete));



	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_IMAP_Status, $this->getValue(static::PFM_IMAP_Status));
	if($this->getValue(static::PFM_IMAP_Status)=="1"){
		$UpdateIMAP=(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_IMAP_Port)!=$this->getValue(static::PFM_IMAP_Port));
		if($this->getValue(static::PFM_IMAP_Reload)=="1"){$ReloadIMAP=true;}
	}

	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_IMAP_Port, preg_replace('/\s+/', '',$this->getValue(static::PFM_IMAP_Port)));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_IMAP_Lock, $this->getValue(static::PFM_IMAP_Lock));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_IMAP_Attemp, $this->getValue(static::PFM_IMAP_Attemp));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_IMAP_Delete, $this->getValue(static::PFM_IMAP_Delete));


	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_POP_Status, $this->getValue(static::PFM_POP_Status));
	if($this->getValue(static::PFM_POP_Status)=="1"){
		$UpdatePOP=(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_POP_Port)!=$this->getValue(static::PFM_POP_Port));
		if($this->getValue(static::PFM_POP_Reload)=="1"){$ReloadPOP=true;}
	}
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_POP_Port, preg_replace('/\s+/', '',$this->getValue(static::PFM_POP_Port)));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_POP_Lock, $this->getValue(static::PFM_POP_Lock));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_POP_Attemp, $this->getValue(static::PFM_POP_Attemp));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_POP_Delete, $this->getValue(static::PFM_POP_Delete));


	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_FTP_Status, $this->getValue(static::PFM_FTP_Status));
	if($this->getValue(static::PFM_FTP_Status)=="1"){
		$UpdateFTP=(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_FTP_Port)!=$this->getValue(static::PFM_FTP_Port));
		if($this->getValue(static::PFM_FTP_Reload)=="1"){$ReloadFTP=true;}
	}
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_FTP_Port, preg_replace('/\s+/', '',$this->getValue(static::PFM_FTP_Port)));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_FTP_Lock, $this->getValue(static::PFM_FTP_Lock));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_FTP_Attemp, $this->getValue(static::PFM_FTP_Attemp));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_FTP_Delete, $this->getValue(static::PFM_FTP_Delete));



	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_Security_Status, $this->getValue(static::PFM_Security_Status));
	if($this->getValue(static::PFM_FTP_Status)=="1"){
		if($this->getValue(static::PFM_Security_Reload)=="1"){$ReloadSecurity=true;}
	}
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_Security_Lock, $this->getValue(static::PFM_Security_Lock));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_Security_Attemp, $this->getValue(static::PFM_Security_Attemp));



	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_DB_Status, $this->getValue(static::PFM_DB_Status));
	if($this->getValue(static::PFM_DB_Status)=="1"){
		if($this->getValue(static::PFM_DB_Reload)=="1"){$ReloadDB=true;}
	}
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_DB_Lock, $this->getValue(static::PFM_DB_Lock));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_DB_Attemp, $this->getValue(static::PFM_DB_Attemp));



	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RDP_Status, $this->getValue(static::PFM_RDP_Status));
	if($this->getValue(static::PFM_RDP_Status)=="1"){
		if($this->getValue(static::PFM_RDP_Reload)=="1"){$ReloadRDP=true;}
	}
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RDP_Delete, $this->getValue(static::PFM_RDP_Delete));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RDP_Lock, $this->getValue(static::PFM_RDP_Lock));
	Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RDP_Attemp, $this->getValue(static::PFM_RDP_Attemp));


	if($ReloadSMTP){$this->app->ReloadRule("SMTP");}
	if($ReloadIMAP){$this->app->ReloadRule("IMAP");}
	if($ReloadPOP){$this->app->ReloadRule("POP");}
	if($ReloadFTP){$this->app->ReloadRule("FTP");}
	if($ReloadSecurity){$this->app->ReloadRule("Security");}
	if($ReloadDB){$this->app->ReloadRule("DB");}
	if($ReloadRDP){$this->app->ReloadRule("RDP");}

	if($UpdateSMTP){$this->app->UpdateRulePorts("SMTP");}
	if($UpdateIMAP){$this->app->UpdateRulePorts("IMAP");}
	if($UpdatePOP){$this->app->UpdateRulePorts("POP");}
	if($UpdateFTP){$this->app->UpdateRulePorts("FTP");}


        return true;
    }


 }

