<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_Form_Logs
 */
class Modules_FlexFirewallManager_Form_Logs extends pm_Form_Simple
{

    const PFM_LAttemp = 'EnableLOGAttemp';
    const PFM_LBlock = 'EnableLOGBlock';
    const PFM_LPlesk = 'EnableLOGPlesk';



    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_Form_Logs constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init()
    {
        parent::init();


	        $this->addElement('hidden', static::PFM_LAttemp, [
        	    'title'      => pm_Locale::lmsg('TabSettingLogAttemp'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_LAttemp),
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitch',
        	    'data-loading'   => 'true',
	            'validators' => [],
	        ]);

	        $this->addElement('hidden', static::PFM_LBlock, [
        	    'title'      => pm_Locale::lmsg('TabSettingLogBlock'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_LBlock),
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitch',
        	    'data-loading'   => 'true',
	            'validators' => [],
	        ]);

	        $this->addElement('hidden', static::PFM_LPlesk, [
        	    'title'      => pm_Locale::lmsg('TabSettingLogPlesk'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_LPlesk),
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitch',
        	    'data-loading'   => 'true',
	            'validators' => [],
	        ]);


    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

        return true;
    }

    /**
     * @return string
     */
    public function process()
    {

	$output=[];
	$savedItems = [];

		if($this->getValue(static::PFM_LAttemp)=="1"){
			if(Modules_FlexFirewallManager_Settings::isLicenced()){
				if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_LAttemp))>0){$savedItems[]=static::PFM_LAttemp;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_LAttemp, $this->getValue(static::PFM_LAttemp));}
			}else{
				$output[]=array('status' => 'info','msg' => pm_Locale::lmsg('pageSaveBasic'));
			}
		}else{
			if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_LAttemp))>0){$savedItems[]=static::PFM_LAttemp;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_LAttemp, $this->getValue(static::PFM_LAttemp));}
		}


		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_LBlock))>0){$savedItems[]=static::PFM_LAttemp;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_LBlock, $this->getValue(static::PFM_LBlock));}
		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_LPlesk))>0){$savedItems[]=static::PFM_LPlesk;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_LPlesk, $this->getValue(static::PFM_LPlesk));}



		if(count($savedItems)==0){
			$output[]=array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')));
		}else{
			$output[]=array('status' => 'success','msg' => pm_Locale::lmsg('pageSaveOK'),'items' => $savedItems);
		}
	
		echo json_encode($output);
		exit;

     } 



 }



