<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_Form_Mailenable
 */
class Modules_FlexFirewallManager_Form_Mailenable extends pm_Form_Simple
{



    const ME_override = 'EnableMEOverride';

    const SMTP_outbound = 'EnableSMTPOtbound';

    const SMTP_recipients = 'EnableSMTPrecipients';

    const SMTP_reported = 'EnableSMTPreported';
    const SMTP_reportedthreshold = 'EnableSMTPreportedthreshold';

    const SMTP_resolve = 'EnableSMTPresolve';
    const SMTP_sendervalid = 'EnableSMTPsendervalid';
    const SMTP_headersid = 'EnableSMTPheadersid';
    const SMTP_delay = 'EnableSMTPdelay';
    const SMTP_fail = 'EnableSMTPfail';
    const SMTP_drop = 'EnableSMTPdrop';
    const SMTP_nullsender = 'EnableSMTPnullsender';
    const SMTP_plus = 'EnableSMTPplus';
    const SMTP_perdomain = 'EnableSMTPperdomain';

    const SMTP_alias = 'EnableSMTPalias';
    const SMTP_plain = 'EnableSMTPPlainPassSMTP';
    const SMTP_msg = 'EnableSMTPMsgSMTP';

    const POP_concurrent = 'EnablePOPconcurrent';
    const POP_msg = 'EnablePOPMsgPOP';

    const IMAP_threadsenable = 'EnableIMAPthreadsenable';
    const IMAP_threads = 'EnableIMAPthreads';
    const IMAP_plain = 'EnableIMAPPlainPassIMAP';

    const WEBMAIL_directory = 'EnableWebMaildirectory';
    const WEBMAIL_folders = 'EnableWebMailfolders';
    const WEBMAIL_calendaring = 'EnableWebMailcalendaring';
    const WEBMAIL_tasks = 'EnableWebMailtasks';
    const WEBMAIL_recovery = 'EnableWebMailrecovery';
    const WEBMAIL_images = 'EnableWebMailimages';
    const WEBMAIL_spam = 'EnableWebMailspam';
    const WEBMAIL_login = 'EnableWebMaillogin';


    const Spam_Enable = 'EnableSpam';
    const Spam_Trainer = 'EnableSpamTrainer';


    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_Form_Mailenable constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init(){
        parent::init();

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

	$appjson = json_decode($this->app->MailEnable());
	if($appjson->result){

		$this->addElement('hidden', "meversion", [
			        'value'      => $appjson->MailEnable,
        			'required'   => false,
			        'validators' => [],
        	]);


		$this->addElement('hidden', static::ME_override, [
       	   	    'title'      => pm_Locale::lmsg('MailEnable.Override'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::ME_override,0),
      		    'data-description' => pm_Locale::lmsg("MailEnable.OverrideDesc"),
       	   	    'required'   => false,
	      	    'class'   => 'switch',
       	    	    'data-action'   => 'saveswitch',
	       	    'validators' => [],
	        ]);


		if($appjson->MailEnable=="Standard Edition"){

			$this->addElement('hidden', "wrongversionDefender", [
        			'title'      => pm_Locale::lmsg('MailEnable.PluginDefenderEnable'),
        			'data-tooltip'      => pm_Locale::lmsg('MailEnable.PluginDefenderVersion'),
			        'value'      => 0,
        			'required'   => false,
			        'disabled'      => 'disabled',
		        	'class'   => 'switch',
			        'validators' => [],
        		]);

			$this->addElement('hidden', "wrongversionClam", [
        			'title'      => pm_Locale::lmsg('MailEnable.PluginClamEnable'),
        			'data-tooltip'      => pm_Locale::lmsg('MailEnable.PluginClamVersion'),
			        'value'      => 0,
        			'required'   => false,
			        'disabled'      => 'disabled',
		        	'class'   => 'switch',
			        'validators' => [],
        		]);

			$this->addElement('hidden', "wrongversionSpam", [
        			'title'      => pm_Locale::lmsg('MailEnable.PluginSpamBlockEnable'),
        			'data-tooltip'      => pm_Locale::lmsg('MailEnable.PluginSpamVersion'),
			        'value'      => 0,
        			'required'   => false,
			        'disabled'      => 'disabled',
		        	'class'   => 'switch',
			        'validators' => [],
        		]);

			$this->addDisplayGroup(array(static::ME_override,"wrongversionDefender","wrongversionClam","wrongversionSpam"), 'vs', array('legend' =>pm_Locale::lmsg('MailEnable.PluginVS')));
			$this->getDisplayGroup('vs')->setAttrib("data-icon", "security");
			$this->getDisplayGroup('vs')->setAttrib("class", "itemTabToRender");


		}else{

			$this->addElement('hidden', 'mta', [ 'value'      => '0',]);

			/** Defender **/

			if(!$appjson->Defender->plugin){

		        	$this->addElement('button', "defender", [
	        	    		'label'      => '<img src="' . pm_Context::getBaseUrl() . 'img/icon/install.png" border="0" style="padding: 10px;width: 60px;"> '. pm_Locale::lmsg("MailEnable.PluginDefender"),
			    		'description' => pm_Locale::lmsg("MailEnable.PluginDefenderDesc"),
			            	'required'   => false,
			            	'validators' => [],
					'class' => 'action plugindefender',
	        		]);


			}else{

				if(!$appjson->Defender->setup){

			        	$this->addElement('button', "defender", [
			            		'label'      => '<img src="' . pm_Context::getBaseUrl() . 'img/icon/install.png" border="0" style="padding: 10px;width: 60px;"> '. pm_Locale::lmsg("MailEnable.DefenderSetup"),
				    		'description' => pm_Locale::lmsg("MailEnable.DefenderSetupDesc"),
	            				'required'   => false,
	            				'validators' => [],
						'class' => 'action plugindefendersetup',
			        	]);
				}else{
			        	$this->addElement('hidden', "defender", [
        			    	'title'      => pm_Locale::lmsg('MailEnable.PluginDefenderEnable'),
				            'value'      => $appjson->Defender->enable ? 1 : 0,
        				    'required'   => false,
			        	    'class'   => 'switch',
			        	    'onchange'   => 'TrogleAntivirus(\'defender\')',
        				    'data-action'   => 'saveswitchmta',
			        	    'validators' => [],
	        			]);
				}

			}

			/** Clam **/

			if(!$appjson->Clam->plugin){

		        	$this->addElement('button', "clam", [
	        	    		'label'      => '<img src="' . pm_Context::getBaseUrl() . 'img/icon/install.png" border="0" style="padding: 10px;width: 60px;"> '. pm_Locale::lmsg("MailEnable.PluginClam"),
			    		'description' => pm_Locale::lmsg("MailEnable.PluginClamDesc"),
			            	'required'   => false,
			            	'validators' => [],
					'class' => 'action pluginclam',
	        		]);


			}else{

				if(!$appjson->Clam->setup){

			        	$this->addElement('button', "clam", [
			            		'label'      => '<img src="' . pm_Context::getBaseUrl() . 'img/icon/install.png" border="0" style="padding: 10px;width: 60px;"> '. pm_Locale::lmsg("MailEnable.ClamSetup"),
				    		'description' => pm_Locale::lmsg("MailEnable.ClamSetupDesc"),
	            				'required'   => false,
	            				'validators' => [],
						'class' => 'action pluginclamsetup',
			        	]);
				}else{
			        	$this->addElement('hidden', "clam", [
        			    	'title'      => pm_Locale::lmsg('MailEnable.PluginClamEnable'),
				            'value'      => $appjson->Clam->enable ? 1 : 0,
        				    'required'   => false,
			        	    'class'   => 'switch',
			        	    'onchange'   => 'TrogleAntivirus(\'clam\')',
        				    'data-action'   => 'saveswitchmta',
			        	    'validators' => [],
	        			]);
				}

			}
	
			/** Spam **/

	
	
			if(!$appjson->Spam->plugin){

		        	$this->addElement('button', "spam", [
	        	    		'label'      => '<img src="' . pm_Context::getBaseUrl() . 'img/icon/install.png" border="0" style="padding: 10px;width: 60px;"> '. pm_Locale::lmsg("MailEnable.PluginSpam"),
			    		'description' => pm_Locale::lmsg("MailEnable.PluginSpamDesc"),
			            	'required'   => false,
			            	'validators' => [],
					'class' => 'action pluginspam',
	        		]);


			}else{

				if(!$appjson->Spam->setup){

			        	$this->addElement('button', "spam", [
			            		'label'      => '<img src="' . pm_Context::getBaseUrl() . 'img/icon/install.png" border="0" style="padding: 10px;width: 60px;"> '. pm_Locale::lmsg("MailEnable.SpamSetup"),
				    		'description' => pm_Locale::lmsg("MailEnable.SpamSetupDesc"),
	            				'required'   => false,
	            				'validators' => [],
						'class' => 'action pluginspamsetup',
			        	]);
				}else{
			        	$this->addElement('hidden', "spam", [
        			    	'title'      => pm_Locale::lmsg('MailEnable.PluginSpamEnable'),
				            'value'      => $appjson->Spam->enable ? 1 : 0,
        				    'required'   => false,
			        	    'class'   => 'switch',
			        	    'onchange'   => 'TrogleSpamAtemp(\'spam\')',
        				    'data-action'   => 'saveswitchmta',
			        	    'validators' => [],
	        			]);

			        	$this->addElement('hidden', static::Spam_Enable, [
        			    	'title'      => pm_Locale::lmsg('MailEnable.PluginSpamBlockEnable'),
				            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::Spam_Enable)==null ? 0 : Modules_FlexFirewallManager_Settings::GetSetting(static::Spam_Enable),
        				    'required'   => false,
			        	    'class'   => 'switch',
			        	    'data-class'   => 'subswitch',
			        	    'validators' => [],
	        			]);

			        	$this->addElement('hidden', static::Spam_Trainer, [
        			    	'title'      => pm_Locale::lmsg('MailEnable.PluginSpamTrainer'),
				            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::Spam_Trainer)==null ? 0 : Modules_FlexFirewallManager_Settings::GetSetting(static::Spam_Trainer),
        				    'required'   => false,
			        	    'class'   => 'switch',
			        	    'data-class'   => 'subswitch',
			        	    'validators' => [],
	        			]);

				}

			}

			if($appjson->Spam->setup){
				$this->addDisplayGroup(array(static::ME_override,"defender","clam","spam",static::Spam_Enable,static::Spam_Trainer), 'vs', array('legend' =>pm_Locale::lmsg('MailEnable.PluginVS')));
			}else{
				$this->addDisplayGroup(array(static::ME_override,"defender","clam","spam"), 'vs', array('legend' =>pm_Locale::lmsg('MailEnable.PluginVS')));
			}
			$this->getDisplayGroup('vs')->removeDecorator('DtDdWrapper');
			$this->getDisplayGroup('vs')->removeDecorator('HtmlTag');
			$this->getDisplayGroup('vs')->setAttrib("data-icon", "security");
			$this->getDisplayGroup('vs')->setAttrib("class", "itemTabToRender");


		}

	}

	$appjson = json_decode($this->app->MailEnable("SETTINGS"));
	if($appjson->result){

		$this->addElement('hidden', 'smtp', [ 'value'      => '0',]);


	        $this->addElement('Text', static::SMTP_recipients, [
	            'label'      => pm_Locale::lmsg('MailEnable.Recipients'),
	            'value'      => $appjson->recipients,
		    'description' => pm_Locale::lmsg('MailEnable.RecipientsDesc'),
	            'required'   => false,
        	    'class'   => 'text-small',
        	    'onchange'   => 'saveswitchsmtp()',
		    'validators' => array(
	                array('digits', true),
	            ),
	        ]);

		$this->addElement('hidden', static::SMTP_reported, [
        		    'title'      => pm_Locale::lmsg('MailEnable.Reporter'),
       			    'data-tooltip'      => $appjson->MailEnable=="Standard Edition" ? pm_Locale::lmsg('MailEnable.PluginDefenderVersion') : pm_Locale::lmsg('MailEnable.Reporter'),
			    'disabled'      => $appjson->MailEnable=="Standard Edition" ? 'disabled' : null,
	        	    'value'      => $appjson->reported ? 1 : 0,
	        	    'required'   => false,
        		    'class'   => 'switch',
        		    'data-action'   => 'saveswitchsmtp',
	        	    'onchange'   => 'TrogleSwitchSub(\''.static::SMTP_reported.'\',\''.static::SMTP_reportedthreshold.'\',\'0\')',
		            'validators' => [],
        	]);

	
		$this->addElement('Text', static::SMTP_reportedthreshold, [
	        	    'label'      => pm_Locale::lmsg('MailEnable.ReportedThreshold'),
       			    'data-tooltip'      => $appjson->MailEnable=="Standard Edition" ? pm_Locale::lmsg('MailEnable.PluginDefenderVersion') : pm_Locale::lmsg('MailEnable.ReportedThreshold'),
			    'disabled'      => $appjson->MailEnable=="Standard Edition" ? 'disabled' : null,
		            'value'      => $appjson->reportedthreshold,
			    'description' => pm_Locale::lmsg('MailEnable.ReportedThresholdDesc'),
	        	    'required'   => false,
	        	    'class'   => 'text-small',
	        	    'onchange'   => 'saveswitchsmtp()',
			    'validators' => array(
		                array('digits', true),
		            ),
	       ]);

	        $this->addElement('hidden', static::SMTP_plain, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Plain'),
	            'value'      => $appjson->PlainPassSMTP ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::SMTP_drop, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Drop'),
	            'value'      => $appjson->drop ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
	            'validators' => [],
        	]);


	        $this->addElement('hidden', static::SMTP_resolve, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Resolve'),
	            'value'      => $appjson->resolve ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::SMTP_sendervalid, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Sendervalid'),
	            'value'      => $appjson->sendervalid ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-description'   => pm_Locale::lmsg('MailEnable.SendervalidDesc'),
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::SMTP_headersid, [
        	    'title'      => pm_Locale::lmsg('MailEnable.HeadersID'),
	            'value'      => $appjson->headersid ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
	            'validators' => [],
        	]);


	        $this->addElement('hidden', static::SMTP_delay, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Delay'),
	            'value'      => $appjson->delay ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::SMTP_fail, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Fail'),
	            'value'      => $appjson->fail ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::SMTP_nullsender, [
        	    'title'      => pm_Locale::lmsg('MailEnable.NullSender'),
	            'value'      => $appjson->nullsender ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
        	    'data-description'   => pm_Locale::lmsg('MailEnable.NullSenderDesc'),
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::SMTP_plus, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Plus'),
	            'value'      => $appjson->plus ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
        	    'data-description'   => pm_Locale::lmsg('MailEnable.PlusDesc'),
	            'validators' => [],
        	]);

		$this->addElement('Text', static::SMTP_perdomain, [
	        	    'label'      => pm_Locale::lmsg('MailEnable.PerDomain'),
       			    'data-tooltip'      => pm_Locale::lmsg('MailEnable.PerDomain'),
		            'value'      => $appjson->perdomain,
			    'description' => pm_Locale::lmsg('MailEnable.PerDomainDesc'),
	        	    'required'   => false,
        	    	    'class'   => 'text-small',
	        	    'onchange'   => 'saveswitchsmtp',
			    'validators' => array(
		                array('digits', true),
		            ),
	       ]);

	        $this->addElement('hidden', static::SMTP_outbound, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Outbound'),
	            'value'      => $appjson->outbound ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
        	    'data-description'   => pm_Locale::lmsg('MailEnable.OutboundDesc'),
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::SMTP_alias, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Alias'),
	            'value'      => $appjson->alias ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchsmtp',
        	    'data-description'   => pm_Locale::lmsg('MailEnable.AliasDesc'),
	            'validators' => [],
        	]);

	        $this->addElement('Text', static::SMTP_msg, [
        	    'label'      => pm_Locale::lmsg('MailEnable.MSG'),
        	    'description'      => pm_Locale::lmsg('MailEnable.MSGDesc'),
	            'value'      => strlen($appjson->MsgSMTP)>0 ? $appjson->MsgSMTP : '',
        	    'class'   => 'text-big',
        	    'required'   => false,
        	    'placeholder'   => "%LOCALDOMAIN% ESMTP MailEnable Service -- ready at %TIME%",
        	    'data-action'   => 'saveswitchsmtp',
	            'validators' => [],
        	]);

		$this->addDisplayGroup(array(static::SMTP_recipients,static::SMTP_perdomain,static::SMTP_reported,static::SMTP_reportedthreshold,static::SMTP_plain,static::SMTP_drop,static::SMTP_resolve,static::SMTP_sendervalid,static::SMTP_headersid,static::SMTP_delay,static::SMTP_fail,static::SMTP_nullsender,static::SMTP_plus,static::SMTP_outbound,static::SMTP_alias,static::SMTP_msg), 'SMTP', array('legend' =>' SMTP '));
		$this->getDisplayGroup('SMTP')->removeDecorator('DtDdWrapper');
		$this->getDisplayGroup('SMTP')->removeDecorator('HtmlTag');
		$this->getDisplayGroup('SMTP')->setAttrib("data-icon", "out");
		$this->getDisplayGroup('SMTP')->setAttrib("class", "itemTabToRender");

		$this->addElement('hidden', 'pop', [ 'value'      => '0',]);

	        $this->addElement('hidden', static::POP_concurrent, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Concurrent'),
	            'value'      => $appjson->concurrent ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchpop',
	            'validators' => [],
        	]);

	        $this->addElement('Text', static::POP_msg, [
        	    'label'      => pm_Locale::lmsg('MailEnable.MSG'),
        	    'description'      => pm_Locale::lmsg('MailEnable.MSGDesc'),
	            'value'      => strlen($appjson->MsgPOP)>0 ? $appjson->MsgPOP : '',
        	    'required'   => false,
        	    'class'   => 'text-big',
        	    'data-action'   => 'saveswitchpop',
        	    'placeholder'   => "Welcome to MailEnable POP3 Server",
	            'validators' => [],
        	]);


		$this->addDisplayGroup(array(static::POP_concurrent,static::POP_msg), 'POP', array('legend' =>' POP '));
		$this->getDisplayGroup('POP')->removeDecorator('DtDdWrapper');
		$this->getDisplayGroup('POP')->removeDecorator('HtmlTag');
		$this->getDisplayGroup('POP')->setAttrib("data-icon", "in");
		$this->getDisplayGroup('POP')->setAttrib("class", "itemTabToRender");


		$this->addElement('hidden', 'imap', [ 'value'      => '0',]);

	        $this->addElement('hidden', static::IMAP_threadsenable, [
        	    'title'      => pm_Locale::lmsg('MailEnable.ThreadsEnable'),
	            'value'      => $appjson->threadsenable ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchimap',
        	    'onchange'   => 'TrogleSwitchSub(\''.static::IMAP_threadsenable.'\',\''.static::IMAP_threads.'\',\'1\')',
	            'validators' => [],
        	]);


	        $this->addElement('Text', static::IMAP_threads, [
	            'label'      => pm_Locale::lmsg('MailEnable.Threads'),
	            'value'      => $appjson->threads,
		    'description' => pm_Locale::lmsg('MailEnable.ThreadsDesc'),
	            'required'   => false,
        	    'class'   => 'text-small',
        	    'onchange'   => 'saveswitchimap',
		    'validators' => array(
	                array('digits', true),
	            ),
	        ]);

	        $this->addElement('hidden', static::IMAP_plain, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Plain'),
	            'value'      => $appjson->PlainPassIMAP ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitchimap',
	            'validators' => [],
        	]);

		$this->addDisplayGroup(array(static::IMAP_threadsenable,static::IMAP_threads,static::IMAP_plain), 'IMAP', array('legend' =>' IMAP '));
		$this->getDisplayGroup('IMAP')->removeDecorator('DtDdWrapper');
		$this->getDisplayGroup('IMAP')->removeDecorator('HtmlTag');
		$this->getDisplayGroup('IMAP')->setAttrib("data-icon", "in");
		$this->getDisplayGroup('IMAP')->setAttrib("class", "itemTabToRender");

	}

	$appjson = json_decode($this->app->MailEnable("WEBMAIL"));
	if($appjson->result){


		 $this->addElement('hidden', static::WEBMAIL_recovery, [
        		    'title'      => pm_Locale::lmsg('MailEnable.Recovery'),
       			    'data-tooltip'      => $appjson->MailEnable=="Standard Edition" ? pm_Locale::lmsg('MailEnable.PluginDefenderVersion') : pm_Locale::lmsg('MailEnable.Recovery'),
			    'disabled'      => $appjson->MailEnable=="Standard Edition" ? 'disabled' : null,
		            'value'      => $appjson->recovery ? 1 : 0,
        		    'required'   => false,
        		    'class'   => 'switch',
		            'validators' => [],
	        ]);

		$this->addElement('hidden', static::WEBMAIL_directory, [
        		    'title'      => pm_Locale::lmsg('MailEnable.Directory'),
       			    'data-tooltip'      => $appjson->MailEnable=="Standard Edition" ? pm_Locale::lmsg('MailEnable.PluginDefenderVersion') : pm_Locale::lmsg('MailEnable.Directory'),
			    'disabled'      => $appjson->MailEnable=="Standard Edition" ? 'disabled' : null,
	        	    'value'      => $appjson->directory ? 1 : 0,
	        	    'required'   => false,
        		    'class'   => 'switch',
	        	    'validators' => [],
	        ]);

		$this->addElement('hidden', static::WEBMAIL_folders, [
        		    'title'      => pm_Locale::lmsg('MailEnable.Folders'),
       			    'data-tooltip'      => $appjson->MailEnable=="Standard Edition" ? pm_Locale::lmsg('MailEnable.PluginDefenderVersion') : pm_Locale::lmsg('MailEnable.Folders'),
			    'disabled'      => $appjson->MailEnable=="Standard Edition" ? 'disabled' : null,
	        	    'value'      => $appjson->folders ? 1 : 0,
	        	    'required'   => false,
        		    'class'   => 'switch',
	        	    'validators' => [],
	        ]);


	        $this->addElement('hidden', static::WEBMAIL_calendaring, [
       		    'title'      => pm_Locale::lmsg('MailEnable.Calendaring'),
        	    'value'      => $appjson->calendaring ? 1 : 0,
        	    'required'   => false,
       		    'class'   => 'switch',
        	    'validators' => [],
        	]);

	        $this->addElement('hidden', static::WEBMAIL_tasks, [
       		    'title'      => pm_Locale::lmsg('MailEnable.Tasks'),
        	    'value'      => $appjson->tasks ? 1 : 0,
        	    'required'   => false,
       		    'class'   => 'switch',
        	    'validators' => [],
        	]);

	        $this->addElement('hidden', static::WEBMAIL_images, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Images'),
	            'value'      => $appjson->images ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::WEBMAIL_spam, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Spam'),
	            'value'      => $appjson->spam ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::WEBMAIL_login, [
        	    'title'      => pm_Locale::lmsg('MailEnable.Login'),
	            'value'      => $appjson->login ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'switch',
	            'validators' => [],
        	]);


		$this->addDisplayGroup(array(static::WEBMAIL_directory,static::WEBMAIL_folders,static::WEBMAIL_calendaring,static::WEBMAIL_tasks,static::WEBMAIL_recovery,static::WEBMAIL_images,static::WEBMAIL_spam,static::WEBMAIL_login), 'WEBMAIL', array('legend' =>' WEBMAIL '));
		$this->getDisplayGroup('WEBMAIL')->removeDecorator('DtDdWrapper');
		$this->getDisplayGroup('WEBMAIL')->removeDecorator('HtmlTag');
		$this->getDisplayGroup('WEBMAIL')->setAttrib("data-icon", "websetting");
		$this->getDisplayGroup('WEBMAIL')->setAttrib("class", "itemTabToRender");


	}

	$this->addControlButtons([
		'sendTitle' => pm_Locale::lmsg('Save'),
		'cancelHidden' => true,
	]);
	        
   }
	        




    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

	if($data["meversion"]!='Standard Edition'){

		if($data[static::SMTP_reportedthreshold]==''){
		        $this->markAsError();
        		$this->getElement(static::SMTP_reportedthreshold)->addError("Error");
			return false;
		}
			if(!is_numeric($data[static::SMTP_reportedthreshold])){
			        $this->markAsError();
			        $this->getElement(static::SMTP_reportedthreshold)->addError("Error");
				return false;
		}
	}

	
	if(! is_numeric($data[static::SMTP_recipients])){
		$this->markAsError();
		$this->getElement(static::SMTP_recipients)->addError(pm_Locale::lmsg("Error.Format"));
		return false;
	}

	if(! is_numeric($data[static::SMTP_perdomain])){
		$this->markAsError();
		$this->getElement(static::SMTP_perdomain)->addError(pm_Locale::lmsg("Error.Format"));
		return false;
	}

	if(isset($data[static::SMTP_reportedthreshold])){
		if(! is_numeric($data[static::SMTP_reportedthreshold])){
			$this->markAsError();
			$this->getElement(static::SMTP_reportedthreshold)->addError(pm_Locale::lmsg("Error.Format"));
			return false;
		}
	}

	if(! is_numeric($data[static::IMAP_threads])){
		$this->markAsError();
		$this->getElement(static::IMAP_threads)->addError(pm_Locale::lmsg("Error.Format"));
		return false;
	}

	if($data["defender"]=="1" && $data["clam"]=="1"){
		$this->markAsError();
		return false;
	}



        return true;
    }

    /**
     * @return boolean
     */
    public function process()
    {
         
	if (!Modules_FlexFirewallManager_Settings::isLicenced()){
		return false;
	}

	$this->app->MailEnable("alias",$this->getValue(static::SMTP_alias));
	$this->app->MailEnable("outbound",$this->getValue(static::SMTP_outbound));
	$this->app->MailEnable("perdomain",$this->getValue(static::SMTP_perdomain));
	$this->app->MailEnable("reported",$this->getValue(static::SMTP_reported));
	$this->app->MailEnable("reportedthreshold",$this->getValue(static::SMTP_reportedthreshold));
	$this->app->MailEnable("resolve",$this->getValue(static::SMTP_resolve));
	$this->app->MailEnable("sendervalid",$this->getValue(static::SMTP_sendervalid));
	$this->app->MailEnable("headersid",$this->getValue(static::SMTP_headersid));
	$this->app->MailEnable("delay",$this->getValue(static::SMTP_delay));
	$this->app->MailEnable("fail",$this->getValue(static::SMTP_fail));
	$this->app->MailEnable("drop",$this->getValue(static::SMTP_drop));
	$this->app->MailEnable("nullsender",$this->getValue(static::SMTP_nullsender));
	$this->app->MailEnable("recipients",$this->getValue(static::SMTP_recipients));
	$this->app->MailEnable("PlainPassSMTP",$this->getValue(static::SMTP_plain));
	$this->app->MailEnable("MsgSMTP",$this->getValue(static::SMTP_msg)." ");

	$this->app->MailEnable("concurrent",$this->getValue(static::POP_concurrent));
	$this->app->MailEnable("MsgPOP",$this->getValue(static::POP_msg)." ");

	$this->app->MailEnable("threadsenable",$this->getValue(static::IMAP_threadsenable));
	$this->app->MailEnable("threads",$this->getValue(static::IMAP_threads));
	$this->app->MailEnable("PlainPassIMAP",$this->getValue(static::IMAP_plain));

	$this->app->MailEnable("directory",$this->getValue(static::WEBMAIL_directory));
	$this->app->MailEnable("folders",$this->getValue(static::WEBMAIL_folders));
	$this->app->MailEnable("calendaring",$this->getValue(static::WEBMAIL_calendaring));
	$this->app->MailEnable("tasks",$this->getValue(static::WEBMAIL_tasks));
	$this->app->MailEnable("recovery",$this->getValue(static::WEBMAIL_recovery));
	$this->app->MailEnable("images",$this->getValue(static::WEBMAIL_images));
	$this->app->MailEnable("spam",$this->getValue(static::WEBMAIL_spam));
	$this->app->MailEnable("plus",$this->getValue(static::SMTP_plus));
	$this->app->MailEnable("login",$this->getValue(static::WEBMAIL_login));


	if($this->getValue("smtp")=="1"){$this->app->MailEnable("SMTP","RELOAD");}
	if($this->getValue("pop")=="1"){$this->app->MailEnable("POP","RELOAD");}
	if($this->getValue("imap")=="1"){$this->app->MailEnable("IMAP","RELOAD");}

	if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::Spam_Enable))>0){Modules_FlexFirewallManager_Settings::SaveSetting(static::Spam_Enable, $this->getValue(static::Spam_Enable));}
	if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::Spam_Trainer))>0){Modules_FlexFirewallManager_Settings::SaveSetting(static::Spam_Trainer, $this->getValue(static::Spam_Trainer));}
	if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::ME_override))>0){Modules_FlexFirewallManager_Settings::SaveSetting(static::ME_override, $this->getValue(static::ME_override));}


	if($this->getValue("defender")==""){
		// not installed
	}else{
		if($this->getValue("mta")=="1"){
			if($this->getValue("defender")=="1"){
				pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/defender","-enable"));
			}else{
				pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/defender","-disable"));
			}
		}
	}

	if($this->getValue("clam")==""){
		// not installed
	}else{
		if($this->getValue("mta")=="1"){
			if($this->getValue("clam")=="1"){
				pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/clam","-enable"));
			}else{
				pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/clam","-disable"));
			}
		}
	}

	if($this->getValue("spam")==""){
		// not installed
	}else{
		if($this->getValue("mta")=="1"){
			if($this->getValue("spam")=="1"){
				pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/spam","-enable"));
			}else{
				pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/spam","-disable"));
			}
		}
	}

        return true;
    }


 }

