<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_Form_Search
 */
class Modules_FlexFirewallManager_Form_Search extends pm_Form_Simple
{

    const PFM_IP = 'ipadress';
    const PFM_STOP = 'stopsearch';
    const PFM_Type = 'type_search';

    private $isConsole = false;
    private $app;

    /**
     * Modules_FlexFirewallManager_Form_Search constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init()
    {
        parent::init();

	$userip = $_SERVER['REMOTE_ADDR'];
	if (isset($_SERVER["HTTP_X_FORWARDED_FOR"])) {
		$userip = explode(":",$_SERVER["HTTP_X_FORWARDED_FOR"])[0];
	}


	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
	$this->app->CloudflareUserSetting=Modules_FlexFirewallManager_Settings::UserCom();

	$required=true;
	if(Modules_FlexFirewallManager_Settings::AdminAuth()){$required=false;}


        $this->addElement('hidden', static::PFM_Type, [
            'value'   => "ip",		
            'validators' => [],
        ]);

        $this->addElement('Text', static::PFM_IP, [
            'label'      => pm_Locale::lmsg('ToBlock_IP'),
            'required'   => $required,
            'description'      => str_replace("%1",$userip,pm_Locale::lmsg('ToSearch_YourIPDesc')),
            'value'   => (isset($_SESSION[pm_Context::getModuleInfo()->name]['searchip']) ? $_SESSION[pm_Context::getModuleInfo()->name]['searchip'] : ''),		
            'validators' => [],
        ]);

	$this->addElement('checkbox', static::PFM_STOP, [
        	'label'      => pm_Locale::lmsg('ToBlock_IP_Stop'),
            	'description' => pm_Locale::lmsg('ToBlock_IP_StopDesc'),
		'value'      => 1,
        	'required'   => false,
        	'validators' => [],
	 ]);



      $this->addControlButtons([
		'sendHidden' => true,
		'cancelHidden' => true,
        ]);


    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

	if($data[static::PFM_IP]==''){
		$this->markAsError();
		$this->getElement(static::PFM_IP)->addError("Error");
		return false;
	}

	if(filter_var($data[static::PFM_IP], FILTER_VALIDATE_IP) == false) {
		$this->markAsError();
		$this->getElement(static::PFM_IP)->addError(pm_Locale::lmsg("Error.Format"));
		return false;
	}

	return true;

    }

    /**
     * @return string
     */
    public function process(){

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
	$this->app->CloudflareUserSetting=Modules_FlexFirewallManager_Settings::UserCom();

	$stop = ($this->getValue(static::PFM_STOP)=="1" ? true : false);

	if(Modules_FlexFirewallManager_Settings::AdminAuth()){

		if($this->getValue(static::PFM_Type)=="ip"){
			return $this->app->FindIP($this->getValue(static::PFM_IP));
		}else{
			return $this->app->FindIP($this->getValue(static::PFM_IP),$stop);
		}


	}else{
		if($this->getValue(static::PFM_Type)=="ip"){
			return $this->app->FindIP($this->getValue(static::PFM_IP));
		}else{
			return $this->app->FindIP($this->getValue(static::PFM_IP),$stop);
		}
		

	}


    }


 }

