<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_Form_Settings
 */
class Modules_FlexFirewallManager_Form_Settings extends pm_Form_Simple
{

    const PFM_DBDATE = 'db_date';
    const PFM_Status = 'status';
    const PFM_StatusR = 'status_Reseller';
    const PFM_StatusC = 'status_Client';
    const PFM_Service = 'status_Service';
    const PFM_Bot = 'EnableBOT';
    const PFM_RuleBot = 'status_RuleBot';
    const PFM_ClienteAdd = 'status_ClientAdd';
    const PFM_PromoCode = 'PROMO';
    const PFM_RDP = 'status_RDP';
    const PFM_WT = 'wellcome_tour';
    const PFM_RF = 'recomend_firewall_on';
    const PFM_RD = 'recomend_rdp_on';

    const PFM_PExpired = 'pleskexp';


    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_Form_Settings constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init()
    {
        parent::init();

	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){ // start Init

	        $this->addElement('hidden', static::PFM_Service, [
        	    'value'      => "Running",
	        ]);

		$this->addElement('simpleText', 'infoauth', array(
	            'label' => pm_Locale::lmsg('InitInfoLabel'),
	            'escape' => false,
        	    'value' => pm_Locale::lmsg('InitInfoText'),
	        ));

        	$this->addElement('checkbox', 'initauth', array(
           	    'label' => pm_Locale::lmsg('InitAuth'),
	            'value' => "0",
        	));

	        $this->addElement('hidden', static::PFM_PExpired, [
        	    'value'      => 1,
	        ]);

        	$this->addControlButtons(array(
            	'sendTitle' => pm_Locale::lmsg('InitSubmit'),
            	'cancelHidden' => true,

	        ));

		
	}else{		// else Init


		$setupdate = Modules_FlexFirewallManager_Settings::GetSetting("setup_date");
		$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());


		if(isset($_SERVER['QUERY_STRING']) && $_SERVER['QUERY_STRING']=="init"){

		        $this->addElement('hidden', static::PFM_PExpired, [
        		    'value'      => 1,
	        	]);

			if($this->app==null){
				$this->_redirect('index/setup');
				return;
			}else{
				$this->app->ServiceStatus("Run");
				sleep(2);
			}

		}


		$appjsonversion = json_decode($this->app->version);

		if($appjsonversion->result){

			$this->addElement('hidden', static::PFM_Status, [
			        'value'      => (Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Status)==1 && $appjsonversion->Service!="Paused" && $appjsonversion->Service!="Stopped" ) ? 1 : 0,
		        	'class'   => 'card',
	       		        'data-loading'   => 'true',
		        	'title'   =>  pm_Config::get('ShowLicense') ? pm_Locale::lmsg('AppPro') . " : " .(Modules_FlexFirewallManager_Settings::IsLicenced() ? pm_Locale::lmsg('AppProFull').$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo'] : pm_Locale::lmsg('AppProBasic')) . " | " . pm_Locale::lmsg('COMVersion') . " : " . $appjsonversion->version : pm_Locale::lmsg('COMVersion') . " : " . $appjsonversion->version  ,
			]);


			try{
				$appjson = json_decode($this->app->FirewallStatus);
			}catch (Exception $e) {
	
				pm_Log::err("[" . Modules_FlexFirewallManager_Settings::Ext . "] Error CreateCom " . $e->getCode() . " : " . $e->getMessage());
				pm_Log::err("[" . Modules_FlexFirewallManager_Settings::Ext . "] Internal Error , Bad Permission Disk or Damaged Configuration");
				$this->_status->addMessage("danger", "Internal Error , Bad Permission Disk or Damaged Configuration");
				$this->_redirect('index/setup');
				return;
			}

			if($appjson->result){
				$this->addElement('hidden', 'firewall', [
				        'value'      => ($appjson->status) ? 1 : 0,
			        	'class'   => 'card',
		       		        'data-loading'   => 'true',
		        	'title'   => $appjsonversion->SO,
				]);

				$appjson = json_decode($this->app->GetRuleName("Deny RDP"));

				$this->addElement('hidden', 'rdp', [
				        'value'      => ($appjson->result && $appjson->status) ? 1 : 0,
			        	'class'   => 'card',
		       		        'data-loading'   => 'true',
					'title'   => ($appjson->result && $appjson->status) ? pm_Locale::lmsg('Service.RDPon') : null,
				]);

			}

			$this->addDisplayGroup(array('firewall',static::PFM_Status,'rdp'), 'firewallGroup');
			$this->getDisplayGroup('firewallGroup')->removeDecorator('HtmlTag');
			$this->getDisplayGroup('firewallGroup')->removeDecorator('DtDdWrapper');


		}

		if(!pm_Config::get('PermissionsGlobal')){
		        $this->addElement('note', 'PermissionsGlobal', array( 'value' => "<p><img src=\"". pm_Context::getBaseUrl() ."img/icon/info.png\" style=\"width: 20px;margin-right: 10px;\"> " . pm_Locale::lmsg('TabSettingClientResellerPermissions') ."</p>" ));
			$this->getElement('PermissionsGlobal')->removeDecorator('DtDdWrapper');
			$this->getElement('PermissionsGlobal')->removeDecorator('HtmlTag');
		}

		if(pm_Config::get('PermissionsGlobal')){

		        $this->addElement('hidden', static::PFM_ClienteAdd, [
	        	    'title'      => pm_Locale::lmsg('TabSettingRuleClientAdd'),
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_ClienteAdd),
        		    'required'   => false,
	        	    'class'   => 'switch',
        		    'data-action'   => 'saveswitch',
        		    'data-loading'   => 'true',
			    'data-description'   => pm_Locale::lmsg('statusAddDesc'),
		            'validators' => [],
		        ]);

		        $this->addElement('hidden', static::PFM_StatusR, [
		            'title'      => pm_Locale::lmsg('TabSettingReseller'),
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_StatusR),
	        	    'required'   => false,
        		    'class'   => 'switch',
        		    'data-action'   => 'saveswitch',
        		    'data-loading'   => 'true',
	        	    'data-description'   => pm_Locale::lmsg('TabSettingClientResellerDisabled'),
		            'validators' => [],
        		]);


		        $this->addElement('hidden', static::PFM_StatusC, [
        		    'title'      => pm_Locale::lmsg('TabSettingClient'),
	        	    'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_StatusC),
	        	    'required'   => false,
        		    'class'   => 'switch',
        		    'data-action'   => 'saveswitch',
        		    'data-loading'   => 'true',
	        	    'data-description'   => pm_Locale::lmsg('TabSettingClientResellerDisabled'),
		            'validators' => [],
        		]);
		}
	


	        $this->addElement('hidden', static::PFM_Bot, [
        	    'title'      => pm_Locale::lmsg('TabSettingBot'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Bot),
        	    'required'   => false,
        	    'class'   => 'switch',
        	    'data-action'   => 'saveswitch',
       		    'data-loading'   => 'true',
        	    'data-description'   => pm_Locale::lmsg('TabSettingBotDesc'),
	            'validators' => [],
        	]);

	        $this->addElement('hidden', static::PFM_RuleBot, [
        	    'title'      => pm_Locale::lmsg('TabSettingRuleBot'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RuleBot),
        	    'required'   => false,
        	    'class'   => 'switch',
       		    'data-loading'   => 'true',
        	    'data-description'   => pm_Locale::lmsg('TabSettingRuleBotDesc'),
        	    'data-action'   => 'saveswitch',
	            'validators' => [],
	        ]);

	        $this->addElement('hidden', static::PFM_Service, [
        	    'value'      => $appjsonversion->Service,
	        ]);

	        $this->addElement('hidden', static::PFM_PExpired, [
        	    'value'      => ($appjsonversion->PleskLicense ? 1 : 0),
	        ]);

	        $this->addElement('hidden', static::PFM_DBDATE, [
        	    'value'      => '',
	        ]);

		if(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_Status)=="0" && $setupdate==Date('Y-m-d')){
			if(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_RF)!="1"){
	        		$this->addElement('hidden', static::PFM_RF, [
	        		    'value'      => '1',
			        ]);
			}
		}


	       $this->addElement('hidden', static::PFM_RD, [
	        		    'value'      => '1',
		]);


		if(pm_Config::get('PermissionsGlobal') || pm_Config::get('ExportImportRule')){
	        	$this->addElement('note', 'migration', array('value' => '<div id="migration"></div>'  ));
			$this->getElement('migration')->removeDecorator('DtDdWrapper');

			$this->addDisplayGroup(array('migration'), 'migrationGroup');
			$this->getDisplayGroup('migrationGroup')->removeDecorator('HtmlTag');
			$this->getDisplayGroup('migrationGroup')->removeDecorator('DtDdWrapper');

		}

	        $this->addElement('note', 'hriplocation', array(       'value' => '<hr size="1"/>'     ));
		$this->getElement('hriplocation')->removeDecorator('DtDdWrapper');
		$this->getElement('hriplocation')->removeDecorator('HtmlTag');

	
		if($setupdate==Date('Y-m-d')){
			if(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_WT)!="1"){
		        	$this->addElement('hidden', static::PFM_WT, [
        			    'value'      => '1',
			        ]);
			}
		}else{

			$dateupdatesetting=Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_DBDATE);
			$dateupdate=' <div class="objects-toolbar bttools"><a class="s-btn sb-scan" id="sb-scan" href="javascript:">'.pm_Locale::lmsg("PFM_DBACT").'</a></div>';
			if($dateupdatesetting==null){
					$dateupdatesetting=pm_Locale::lmsg('PFM_DBDATEKO');
			}else{
					$ardate=explode("-", $dateupdatesetting);
					$dateupdatesetting=Modules_FlexFirewallManager_Settings::FormatDateOutput($dateupdatesetting,pm_Locale::lmsg('formatDate'));
					if( Date('Y-m-d') < Date('Y-m-d',strtotime(Date("Y-m-d", mktime(0, 0, 0, $ardate[1], $ardate[2], $ardate[0])) . " +15 days")) ){$dateupdate="";}
			}
			if($dateupdate!=""){
				$this->addElement('note', 'link', array('value' => '<b>'.pm_Locale::lmsg('PFM_DBDATE').' :</b> '.$dateupdatesetting.$dateupdate));

			}
		}

		if(isset($_GET['PROMO'])){
			$this->addElement('Text', static::PFM_PromoCode, [
	        	    'label'      => pm_Locale::lmsg('TabSettingCode') ." :",
		            'value'      => $_GET['PROMO'],
        		    'required'   => false,
		            'validators' => [],
        		]);
		}



	} // end Init



    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
		if($data["initauth"]!='1'){
		        $this->markAsError();
		        $this->getElement("initauth")->addError("Error");
			return false;
		}
	}

        return true;
    }

    /**
     * @return string
     */
    public function process()
    {

	$output=[];

	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
		return self::initSetup();
	}else{

		$savedItems = [];
		

		if($this->getValue(static::PFM_Bot)=="1" || $this->getValue(static::PFM_RuleBot)=="1"){
				if(Modules_FlexFirewallManager_Settings::isLicenced()){
					if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_Bot))>0){$savedItems[]=static::PFM_Bot;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_Bot, $this->getValue(static::PFM_Bot));}
					if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_RuleBot))>0){$savedItems[]=static::PFM_RuleBot;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RuleBot, $this->getValue(static::PFM_RuleBot));}
	
				}else{
					$output[]=array('status' => 'info','msg' => pm_Locale::lmsg('pageSaveBasic'));
				}

		}else{
				if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_Bot))>0){$savedItems[]=static::PFM_Bot;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_Bot, $this->getValue(static::PFM_Bot));}
				if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_RuleBot))>0){$savedItems[]=static::PFM_RuleBot;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RuleBot, $this->getValue(static::PFM_RuleBot));}
		}


		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_PromoCode))>0){$output[]=array('status' => 'info','msg' => pm_Locale::lmsg('Promo.Wait')); $savedItems[]=static::PFM_PromoCode;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_PromoCode, $this->getValue(static::PFM_PromoCode));$_SESSION[pm_Context::getModuleInfo()->name]['License']="";}
		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_DBDATE))>0){$savedItems[]=static::PFM_DBDATE;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_DBDATE, $this->getValue(static::PFM_DBDATE));}
		if(pm_Config::get('PermissionsGlobal')){
			if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_ClienteAdd))>0){$savedItems[]=static::PFM_ClienteAdd;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_ClienteAdd, $this->getValue(static::PFM_ClienteAdd));}
			if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_StatusR))>0){$savedItems[]=static::PFM_StatusR;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_StatusR, $this->getValue(static::PFM_StatusR));}
			if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_StatusC))>0){$savedItems[]=static::PFM_StatusC;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_StatusC, $this->getValue(static::PFM_StatusC));}
		}


		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_WT))>0){$savedItems[]=static::PFM_WT;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_WT, $this->getValue(static::PFM_WT));}
		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_RF))>0){$savedItems[]=static::PFM_RF;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RF, $this->getValue(static::PFM_RF));}
		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_RD))>0){$savedItems[]=static::PFM_RD;Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RD, $this->getValue(static::PFM_RD));}


		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue("firewall"))>0){
		
			$savedItems[]="firewall";

			if($this->getValue("firewall")=="1"){
				$this->app->FirewallEnable;
			}else{
				$this->app->FirewallDisable;
			}

		}

	
		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue("rdp"))>0){

			$savedItems[]="rdp";
	
			if($this->getValue("rdp")=="1"){
				$appjson = json_decode($this->app->BlockRDP(true));
	
				if(!$appjson->result){
					$output[]=array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')) . " (" . $appjson->desc . ")");
					echo json_encode($output);
					exit;
				}

				Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RDP, "1");

			}else{
				$appjson = json_decode($this->app->BlockRDP(false));

				if(!$appjson->result){
					$output[]=array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')). " (" . $appjson->desc . ")");
					echo json_encode($output);
					exit;
				}

				Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_RDP, "0");
			}
	
	
		}

		if(Modules_FlexFirewallManager_Settings::GetLength($this->getValue(static::PFM_Status))>0){
	
			$savedItems[]=static::PFM_Status;

			$appjson = json_decode($this->app->Version);
	
			if($this->getValue(static::PFM_Status)=="1"){
				if($appjson->Service!="Paused" || $appjson->Service!="Stopped"){
					$this->app->ServiceStatus("Run");
				}
			}
	
			Modules_FlexFirewallManager_Settings::SaveSetting(static::PFM_Status, $this->getValue(static::PFM_Status));
		}


		if(count($savedItems)==0){
			$output[]=array('status' => 'danger','msg' => str_replace("%1","",pm_Locale::lmsg('statusERROR')));
		}else{
			$output[]=array('status' => 'success','msg' => pm_Locale::lmsg('pageSaveOK'),'items' => $savedItems);
		}
	
		echo json_encode($output);
		exit;

	    } // end Init
     } 

   /**
     * @return string
     */
    public function initSetup(){

	$result = pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/install"));
	if ($result['code'] !== 0) {
		return $result['stderr']. " - " . $result['stdout'];
	}

	Modules_FlexFirewallManager_Settings::SaveSetting("setup_date",Date('Y-m-d'));
	Modules_FlexFirewallManager_Settings::SaveSetting("Job","installed");

        return "OK";

    }



 }



