<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_Form_SmarterMail
 */
class Modules_FlexFirewallManager_Form_SmarterMail extends pm_Form_Simple
{


    const SMTP_recipients = 'EnableSMTPrecipients';
    const SMTP_delay = 'EnableSMTPdelay';
    const SMTP_plus = 'EnableSMTPplus';
    const SMTP_nullsender = 'EnableSMTPnullsender';

    const POP_concurrentenable = 'EnablePOPconcurrentenable';
    const POP_concurrent = 'EnablePOPconcurrent';

    const IMAP_threadsenable = 'EnableIMAPthreadsenable';
    const IMAP_threads = 'EnableIMAPthreads';

    const WEBMAIL_directory = 'EnableWebMaildirectory';
    const WEBMAIL_folders = 'EnableWebMailfolders';


    const WEBMAIL_recovery = 'EnableWebMailrecovery';
    const WEBMAIL_images = 'EnableWebMailimages';

    const WEBMAIL_login = 'EnableWebMaillogin';



    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_Form_SmarterMail constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init(){
        parent::init();

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());
	$appjson = json_decode($this->app->SmarterMail());

	if($appjson->result){

		$this->addElement('hidden', "smversion", [
			        'value'      => $appjson->SmarterMail,
        			'required'   => false,
			        'validators' => [],
        	]);

		$this->addElement('hidden', 'mta', [ 'value'      => '0',]);

		$this->addElement('hidden', "defender", [
			'title'      => pm_Locale::lmsg('SmarterMail.PluginDefenderEnable'),
			'value'      => $appjson->Defender->enable ? 1 : 0,
			'required'   => false,
			'class'   => 'switch',
			'data-action'   => 'saveswitchmta',
			'validators' => [],
		]);

		$this->addDisplayGroup(array("defender"), 'vs', array('legend' =>pm_Locale::lmsg('SmarterMail.PluginVS')));

		$this->addElement('hidden', 'smtp', [ 'value'      => '0',]);


		$appjson = json_decode($this->app->SmarterMail("SETTINGS"));

		if($appjson->result){
			$this->addElement('Text', static::SMTP_recipients, [
        			'label'      => pm_Locale::lmsg('SmarterMail.Recipients'),
			        'value'      => $appjson->recipients,
				'description' => pm_Locale::lmsg('SmarterMail.RecipientsDesc'),
			        'required'   => false,
       				'onchange'   => 'saveswitchsmtp()',
			    	'validators' => [],
	        	]);


       			$this->addElement('hidden', static::SMTP_delay, [
		        	 'title'      => pm_Locale::lmsg('SmarterMail.Delay'),
        			 'value'      => $appjson->delay ? 1 : 0,
	        		'required'   => false,
       				'class'   => 'switch',
		        	'data-action'   => 'saveswitchsmtp',
		        	'validators' => [],
			]);

	        	$this->addElement('hidden', static::SMTP_plus, [
	        	    'title'      => pm_Locale::lmsg('SmarterMail.Plus'),
		            'value'      => $appjson->plus ? 1 : 0,
        		    'required'   => false,
	        	    'class'   => 'switch',
        		    'data-action'   => 'saveswitchsmtp',
        		    'data-description'   => pm_Locale::lmsg('SmarterMail.PlusDesc'),
		            'validators' => [],
	        	]);

		        $this->addElement('hidden', static::SMTP_nullsender, [
        		    'title'      => pm_Locale::lmsg('SmarterMail.NullSender'),
	        	    'value'      => $appjson->nullsender ? 1 : 0,
	        	    'required'   => false,
        		    'class'   => 'switch',
        		    'data-action'   => 'saveswitchsmtp',
	        	    'data-description'   => pm_Locale::lmsg('SmarterMail.NullSenderDesc'),
		            'validators' => [],
        		]);

			$this->addDisplayGroup(array(static::SMTP_recipients,static::SMTP_delay,static::SMTP_plus,static::SMTP_nullsender), 'SMTP', array('legend' =>' SMTP '));


			$this->addElement('hidden', 'pop', [ 'value'      => '0',]);

	        	$this->addElement('hidden', static::POP_concurrentenable, [
	        	    'title'      => pm_Locale::lmsg('SmarterMail.ConcurrentEnable'),
		            'value'      => $appjson->concurrent == 0 ? 1 : 0,
        		    'required'   => false,
	        	    'class'   => 'switch',
        		    'data-action'   => 'saveswitchpop',
        		    'onchange'   => 'TrogleSwitchSub(\''.static::POP_concurrentenable.'\',\''.static::POP_concurrent.'\',\'1\')',
		            'validators' => [],
        		]);

	        	$this->addElement('Text', static::POP_concurrent, [
		            'label'      => pm_Locale::lmsg('SmarterMail.Concurrent'),
		            'value'      => $appjson->concurrent == 0 ? 500 : $appjson->concurrent,
		            'required'   => false,
        		    'onchange'   => 'saveswitchpop()',
	        	    'validators' => [],
	        	]);


			$this->addDisplayGroup(array(static::POP_concurrentenable,static::POP_concurrent), 'POP', array('legend' =>' POP '));


			$this->addElement('hidden', 'imap', [ 'value'      => '0',]);

	        	$this->addElement('hidden', static::IMAP_threadsenable, [
	        	    'title'      => pm_Locale::lmsg('SmarterMail.ThreadsEnable'),
		            'value'      => $appjson->threads == 0 ? 1 : 0,
        		    'required'   => false,
	        	    'class'   => 'switch',
        		    'data-action'   => 'saveswitchimap',
        		    'onchange'   => 'TrogleSwitchSub(\''.static::IMAP_threadsenable.'\',\''.static::IMAP_threads.'\',\'1\')',
		            'validators' => [],
        		]);


	       		$this->addElement('Text', static::IMAP_threads, [
		            'label'      => pm_Locale::lmsg('SmarterMail.Threads'),
		            'value'      => $appjson->threads == 0 ? 1000 : $appjson->threads,
		            'required'   => false,
        		    'onchange'   => 'saveswitchimap()',
	        	    'validators' => [],
		        ]);

			$this->addDisplayGroup(array(static::IMAP_threadsenable,static::IMAP_threads), 'IMAP', array('legend' =>' IMAP '));

		}

		$appjson = json_decode($this->app->SmarterMail("WEBMAIL"));

		$this->addElement('hidden', 'webmail', [ 'value'      => '0',]);

		if($appjson->result){

		 	$this->addElement('hidden', static::WEBMAIL_recovery, [
        		    'title'      => pm_Locale::lmsg('SmarterMail.Recovery'),
       			    'data-tooltip'      => $appjson->SmarterMail=="Standard Edition" ? pm_Locale::lmsg('SmarterMail.PluginDefenderVersion') : pm_Locale::lmsg('SmarterMail.Recovery'),
			    'disabled'      => $appjson->SmarterMail=="Standard Edition" ? 'disabled' : null,
		            'value'      => $appjson->recovery ? 1 : 0,
        		    'required'   => false,
        		    'class'   => 'switch',
        		    'onchange'   => 'saveswitchwebmail()',
		            'validators' => [],
	        	]);

			$this->addElement('hidden', static::WEBMAIL_directory, [
        		    'title'      => pm_Locale::lmsg('SmarterMail.Directory'),
       			    'data-tooltip'      => $appjson->SmarterMail=="Standard Edition" ? pm_Locale::lmsg('SmarterMail.PluginDefenderVersion') : pm_Locale::lmsg('SmarterMail.Directory'),
			    'disabled'      => $appjson->SmarterMail=="Standard Edition" ? 'disabled' : null,
	        	    'value'      => $appjson->directory ? 1 : 0,
	        	    'required'   => false,
        		    'class'   => 'switch',
        		    'onchange'   => 'saveswitchwebmail()',
	        	    'validators' => [],
	        	]);

			$this->addElement('hidden', static::WEBMAIL_folders, [
        		    'title'      => pm_Locale::lmsg('SmarterMail.Folders'),
       			    'data-tooltip'      => $appjson->SmarterMail=="Standard Edition" ? pm_Locale::lmsg('SmarterMail.PluginDefenderVersion') : pm_Locale::lmsg('SmarterMail.Folders'),
			    'disabled'      => $appjson->SmarterMail=="Standard Edition" ? 'disabled' : null,
	        	    'value'      => $appjson->folders ? 1 : 0,
	        	    'required'   => false,
        		    'class'   => 'switch',
        		    'onchange'   => 'saveswitchwebmail()',
	        	    'validators' => [],
	        	]);


	        	$this->addElement('hidden', static::WEBMAIL_images, [
	        	    'title'      => pm_Locale::lmsg('SmarterMail.Images'),
		            'value'      => $appjson->images ? 1 : 0,
        		    'required'   => false,
	        	    'class'   => 'switch',
        		    'onchange'   => 'saveswitchwebmail()',
		            'validators' => [],
        		]);


	        	$this->addElement('hidden', static::WEBMAIL_login, [
        		    'title'      => pm_Locale::lmsg('SmarterMail.Login'),
	        	    'value'      => $appjson->login ? 1 : 0,
	        	    'required'   => false,
        		    'class'   => 'switch',
        		    'onchange'   => 'saveswitchwebmail()',
	        	    'validators' => [],
        		]);


			$this->addDisplayGroup(array(static::WEBMAIL_directory,static::WEBMAIL_folders,static::WEBMAIL_recovery,static::WEBMAIL_images,static::WEBMAIL_login), 'WEBMAIL', array('legend' =>' WEBMAIL '));
		}

		$this->addControlButtons([
			'sendTitle' => pm_Locale::lmsg('Save'),
			'cancelHidden' => true,
		]);

	}

	
	        
    }
	        
    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

	
	if(! is_numeric($data[static::SMTP_recipients])){
		$this->markAsError();
		$this->getElement(static::SMTP_recipients)->addError(pm_Locale::lmsg("Error.Format"));
		return false;
	}

	if(! is_numeric($data[static::IMAP_threads])){
		$this->markAsError();
		$this->getElement(static::IMAP_threads)->addError(pm_Locale::lmsg("Error.Format"));
		return false;
	}

	if(! is_numeric($data[static::POP_concurrent])){
		$this->markAsError();
		$this->getElement(static::POP_concurrent)->addError(pm_Locale::lmsg("Error.Format"));
		return false;
	}


        return true;
    }

    /**
     * @return boolean
     */
    public function process(){         

	if (!Modules_FlexFirewallManager_Settings::isLicenced()){
		return false;
	}

	if($this->getValue("smtp")=="1"){
		$this->app->SmarterMail("delay",$this->getValue(static::SMTP_delay));
		$this->app->SmarterMail("recipients",$this->getValue(static::SMTP_recipients));
		$this->app->SmarterMail("plus",$this->getValue(static::SMTP_plus));
		$this->app->SmarterMail("nullsender",$this->getValue(static::SMTP_nullsender));
	}

	if($this->getValue("pop")=="1"){	
		if($this->getValue(static::POP_concurrentenable)==1){
			$this->app->SmarterMail("concurrent",0);
		}else{
			$this->app->SmarterMail("concurrent",$this->getValue(static::POP_concurrent));
		}
	}

	if($this->getValue("imap")=="1"){
		if($this->getValue(static::IMAP_threadsenable)==1){
			$this->app->SmarterMail("threads",0);
		}else{
			$this->app->SmarterMail("threads",$this->getValue(static::IMAP_threads));
		}
	}

	if($this->getValue("webmail")=="1"){
		$this->app->SmarterMail("directory",$this->getValue(static::WEBMAIL_directory));
		$this->app->SmarterMail("folders",$this->getValue(static::WEBMAIL_folders));

		$this->app->SmarterMail("recovery",$this->getValue(static::WEBMAIL_recovery));
		$this->app->SmarterMail("images",$this->getValue(static::WEBMAIL_images));

		$this->app->SmarterMail("login",$this->getValue(static::WEBMAIL_login));
	}

	if($this->getValue("mta")=="1"){
		$this->app->SmarterMail("defender",$this->getValue("defender"));
		if($this->getValue("defender")=="1"){pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/enabledefender"));}
	}


        return true;
    }


 }

