<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_Form_Web
 */
class Modules_FlexFirewallManager_Form_Web extends pm_Form_Simple
{

    const PFM_WEB_Lock_Normal = 'LockWEB_Normal';
    const PFM_WEB_Lock_High = 'LockWEB_High';
    const PFM_WEB_Domain = 'LockWEB_Domain';

    const PFM_WEBE = 'EnableWEB';
    const PFM_MODE = 'EnableModule';
    const PFM_ENV = 'env';
    const PFM_CONF = 'config';
    const PFM_WLOGIN = 'wplogin';
    const PFM_XML = 'xmlrpc';
    const PFM_APIK = 'apikey';
    const PFM_PGIN = 'pluginsphp';
    const PFM_VEND = 'vendorphp';
    const PFM_LIBPHP = 'librariesphp';
    const PFM_INCPHP = 'includephp';
    const PFM_CRONPHP = 'wpcron';
    const PFM_ADMIN = 'admin';
    const PFM_HACK = 'hack';
    const PFM_AGENT = 'agent';
    const PFM_QRY = 'query';

    const PFM_MP = 'Page';
    const PFM_MS = 'Secret';
    const PFM_MX = 'XSS';
    const PFM_MN = 'NoSniff';
    const PFM_MH3 = 'HTTP3';

    const PFM_WEB_SSL = 'SSL';
    const PFM_SSL_OLD = 'OLD';
    const PFM_SSL_V2 = 'V2';
    const PFM_SSL_V3 = 'V3';
    const PFM_SSL_TLS1 = 'TLS1';
    const PFM_SSL_TLS11 = 'TLS11';
    const PFM_SSL_TLS12 = 'TLS12';
    const PFM_SSL_TLS13 = 'TLS13';


    private $isConsole = false;
    private $app;
    private $WEBDOM;

    

    /**
     * Modules_FlexFirewallManager_Form_Web constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init(){
        parent::init();

	$langmins=pm_Locale::lmsg('mins');
	$langhours=pm_Locale::lmsg('hours');
	$langdays=pm_Locale::lmsg('days');

	$this->WEBDOM = array(0 => pm_Locale::lmsg('WEB.DomainFirewall'),1 => pm_Locale::lmsg('WEB.DomainWeb'));
	$tiempo_lockNormal = array(10 => "10 $langmins",20 => "20 $langmins",40 => "40 $langmins");
	$tiempo_lockHigh = $tiempo_lockNormal;

	if (Modules_FlexFirewallManager_Settings::isLicenced()){
		$tiempo_lockNormal += [ (60 * 5) => "5 $langhours"];
		$tiempo_lockNormal += [ (60 * 10) => "10 $langhours"];
		$tiempo_lockNormal += [ (60 * 20) => "20 $langhours"];
		$tiempo_lockNormal += [ (60 * 24 * 2) => "2 $langdays"];
		$tiempo_lockNormal += [ (60 * 24 * 3) => "3 $langdays"];
		$tiempo_lockNormal += [ (60 * 24 * 4) => "4 $langdays"];
		$tiempo_lockNormal += [ (60 * 24 * 5) => "5 $langdays"];
		$tiempo_lockNormal += [ 0 => pm_Locale::lmsg('LockPermanent')];

		$tiempo_lockHigh = [];

		$tiempo_lockHigh += [ (60 * 12) => "12 $langhours"];
		$tiempo_lockHigh += [ (60 * 24 * 1) => "1 $langdays"];
		$tiempo_lockHigh += [ (60 * 24 * 2) => "2 $langdays"];
		$tiempo_lockHigh += [ (60 * 24 * 3) => "3 $langdays"];
		$tiempo_lockHigh += [ (60 * 24 * 4) => "4 $langdays"];
		$tiempo_lockHigh += [ (60 * 24 * 5) => "5 $langdays"];
		$tiempo_lockHigh += [ 0 => pm_Locale::lmsg('LockPermanent')];
	}else{
		$tiempo_lockHigh += [ 80 => "80 $langmins"];
	}


	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

	$appjson = json_decode($this->app->version);

	if(!Modules_FlexFirewallManager_Settings::AdminAuth()){
	
	
	        $this->addElement('SimpleText', static::PFM_ENV, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_ENV),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_ENV,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_CONF, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_CONF),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_CONF,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_WLOGIN, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_WLOGIN),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_WLOGIN,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_XML, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_XML),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_XML,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_APIK, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_APIK),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_APIK,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_PGIN, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_PGIN),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_PGIN,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_VEND, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_VEND),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_VEND,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_LIBPHP, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_LIBPHP),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_LIBPHP,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_INCPHP, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_INCPHP),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_INCPHP,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_CRONPHP, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_CRONPHP),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_CRONPHP,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_ADMIN, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_ADMIN),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_ADMIN,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_AGENT, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_AGENT),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_AGENT,0)),
	        ]);

	        $this->addElement('SimpleText', static::PFM_QRY, [
        	    'label'      => pm_Locale::lmsg('WEB.'.static::PFM_QRY),
		    'escape' => false,
	            'value'      => Modules_FlexFirewallManager_Settings::StatusStringService(Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_QRY,0)),
	        ]);

		$this->addDisplayGroup(array(static::PFM_ENV,static::PFM_CONF,static::PFM_WLOGIN,static::PFM_XML,static::PFM_APIK,static::PFM_PGIN,static::PFM_VEND,static::PFM_LIBPHP,static::PFM_INCPHP,static::PFM_CRONPHP,static::PFM_ADMIN,static::PFM_HACK,static::PFM_AGENT,static::PFM_QRY), 'WebSettingsStatus');

	}else{

		$webDomStatus = Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_WEB_Domain,0);

	        $this->addElement('SimpleText', "Item".static::PFM_WEB_SSL, [
        	    'label'      => pm_Locale::lmsg('SSL.Title'),
	            'value'      => pm_Locale::lmsg('SSL.Desc'),
		    'class'   => 'hint',
		    'escape' => false,
	       	]);

		$appjson = json_decode($this->app->SSL);

		$TLS13 = $appjson->TLS13;

		$formSSL = new pm_Form_Simple();

		$this->addElement('hidden', static::PFM_SSL_OLD, [
	        	    'value'      => $appjson->old ? 1 : 0,
	        	    'required'   => false,
        	]);
		$formSSL->addElement('hidden', "draw".static::PFM_SSL_OLD, [
        	    'title'      => 'PCT',
        	    'data-title'      => pm_Locale::lmsg('SSL.SuggestDisabled'),
        	    'data-description'      => pm_Locale::lmsg('SSL.'.static::PFM_SSL_OLD) . "<br><i>" . pm_Locale::lmsg('SSL.SuggestDisabled') . "</i>",
	            'value'      => $appjson->old ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_SSL_V2, [
	        	    'value'      => $appjson->V2 ? 1 : 0,
	        	    'required'   => false,
        	]);
		$formSSL->addElement('hidden', "draw".static::PFM_SSL_V2, [
        	    'title'      => 'SSL 2.0',
        	    'data-title'      => pm_Locale::lmsg('SSL.SuggestDisabled'),
        	    'data-description'      => pm_Locale::lmsg('SSL.'.static::PFM_SSL_V2). "<br><i>" . pm_Locale::lmsg('SSL.SuggestDisabled') . "</i>",
	            'value'      => $appjson->V2 ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_SSL_V3, [
	        	    'value'      => $appjson->V3 ? 1 : 0,
	        	    'required'   => false,
        	]);
		$formSSL->addElement('hidden', "draw".static::PFM_SSL_V3, [
        	    'title'      => 'SSL 3.0',
        	    'data-title'      => pm_Locale::lmsg('SSL.SuggestDisabled'),
        	    'data-description'      => pm_Locale::lmsg('SSL.'.static::PFM_SSL_V3). "<br><i>" . pm_Locale::lmsg('SSL.SuggestDisabled') . "</i>",
	            'value'      => $appjson->V3 ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_SSL_TLS1, [
	        	    'value'      => $appjson->TLS1 ? 1 : 0,
	        	    'required'   => false,
        	]);
		$formSSL->addElement('hidden', "draw".static::PFM_SSL_TLS1, [
        	    'title'      => 'TLS 1.0',
        	    'data-title'      => pm_Locale::lmsg('SSL.SuggestDisabled'),
        	    'data-description'      => pm_Locale::lmsg('SSL.'.static::PFM_SSL_TLS1). "<br><i>" . pm_Locale::lmsg('SSL.SuggestDisabled') . "</i>",
	            'value'      => $appjson->TLS1 ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_SSL_TLS11, [
	        	    'value'      => $appjson->TLS11 ? 1 : 0,
	        	    'required'   => false,
        	]);
		$formSSL->addElement('hidden', "draw".static::PFM_SSL_TLS11, [
        	    'title'      => 'TLS 1.1',
        	    'data-description'      => pm_Locale::lmsg('SSL.'.static::PFM_SSL_TLS11),
	            'value'      => $appjson->TLS11 ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_SSL_TLS12, [
	        	    'value'      => $appjson->TLS12 ? 1 : 0,
	        	    'required'   => false,
        	]);
		$formSSL->addElement('hidden', "draw".static::PFM_SSL_TLS12, [
        	    'title'      => 'TLS 1.2',
        	    'data-description'      => pm_Locale::lmsg('SSL.'.static::PFM_SSL_TLS12),
	            'value'      => $appjson->TLS12 ? 1 : 0,
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_SSL_TLS13, [
	        	    'value'      => ($appjson->TLS13 === null ? 0 : ($appjson->TLS13 ? 1 : 0)),
	        	    'required'   => false,
        	]);
		$formSSL->addElement('hidden', "draw".static::PFM_SSL_TLS13, [
        	    'title'      => 'TLS 1.3',
        	    'data-title'      => ($appjson->TLS13 === null ? pm_Locale::lmsg('SSL.TLS13Valid') : 'TLS 1.3'),
        	    'data-description'      => pm_Locale::lmsg('SSL.'.static::PFM_SSL_TLS13),
	            'value'      => ($appjson->TLS13 === null ? 0 : ($appjson->TLS13 ? 1 : 0)),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		    'disabled' => ($appjson->TLS13 === null ? 'disabled' : null)
		]);

		$this->addSubForm($formSSL,"SubFormSSL");

	        $this->addElement('SimpleText', "Item".static::PFM_WEB_Domain, [
        	    'label'      => pm_Locale::lmsg('WEB.Domain'),
	            'value'      => "<b>" . $this->WEBDOM[$webDomStatus] . "</b>",
		    'escape' => false,
	       	]);

		$this->addElement('hidden', static::PFM_WEB_Domain, [
	        	    'value'      => $webDomStatus,
	        	    'required'   => false,
        	]);


		$formDom = new pm_Form_Simple();

	        $formDom->addElement('select', "draw".static::PFM_WEB_Domain, [
        	    'label'      => pm_Locale::lmsg('WEB.Domain'),
	            'value'      => $webDomStatus,
		    'multiOptions' => $this->WEBDOM,
        	    'required'   => false,
	            'validators' => [],
	        ]);

		$this->addSubForm($formDom,"SubFormDom");

		$status=Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_WEBE);
		$Normal=Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_WEB_Lock_Normal);
		$High=Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_WEB_Lock_High);

		if(!Modules_FlexFirewallManager_Settings::isLicenced()){
			if($Normal>40 || $status==0){$Normal=10;}
			if($High>80 || $status==0){$High=80;}
		}

		$this->addElement('hidden', static::PFM_WEBE, [
			'value'      => $status,
			'class'   => 'card',
			'data-info' => pm_Locale::lmsg('WEB.Status'),
		]);


		$formWEB = new pm_Form_Simple();

		$this->addElement('hidden', static::PFM_WEB_Lock_Normal, [
        		    'value'      => $Normal,
		]);

	        $formWEB->addElement('select', "draw".static::PFM_WEB_Lock_Normal, [
        	    'label'      => pm_Locale::lmsg('WEB.NormalLevel'),
	            'value'      => $Normal,
		    'description' => pm_Locale::lmsg('LockDesc'),
		    'multiOptions' => $tiempo_lockNormal,
        	    'required'   => false,
	            'validators' => [],
	        ]);


		$this->addElement('hidden', static::PFM_WEB_Lock_High, [
        		    'value'      => $High,
		]);
		$formWEB->addElement('select', "draw".static::PFM_WEB_Lock_High, [
	            'label'      => pm_Locale::lmsg('WEB.HighLevel'),
        	    'value'      => $High,
		    'description' => pm_Locale::lmsg('LockDesc'),
		    'multiOptions' => $tiempo_lockHigh,
        	    'required'   => false,
	            'validators' => [],
	        ]);


		$formRULE = new pm_Form_Simple();

		$this->addElement('hidden', static::PFM_ENV, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_ENV,0),
		]);

		$formRULE->addElement('hidden', "draw".static::PFM_ENV, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_ENV),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_ENV,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_CONF, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_CONF,0),
		]);

		$formRULE->addElement('hidden', "draw".static::PFM_CONF, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_CONF),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_CONF,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_WLOGIN, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_WLOGIN,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_WLOGIN, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_WLOGIN),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_WLOGIN,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_XML, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_XML,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_XML, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_XML),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_XML,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_APIK, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_APIK,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_APIK, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_APIK),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_APIK,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_PGIN, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_PGIN,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_PGIN, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_PGIN),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_PGIN,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_VEND, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_VEND,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_VEND, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_VEND),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_VEND,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_LIBPHP, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_LIBPHP,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_LIBPHP, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_LIBPHP),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_LIBPHP,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_INCPHP, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_INCPHP,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_INCPHP, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_INCPHP),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_INCPHP,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);
		$this->addElement('hidden', static::PFM_CRONPHP, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_CRONPHP,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_CRONPHP, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_CRONPHP),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_CRONPHP,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);
		$this->addElement('hidden', static::PFM_ADMIN, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_ADMIN,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_ADMIN, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_ADMIN),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_ADMIN,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);
		$this->addElement('hidden', static::PFM_HACK, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_HACK,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_HACK, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_HACK),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_HACK,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);
		$this->addElement('hidden', static::PFM_AGENT, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_AGENT,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_AGENT, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_AGENT),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_AGENT,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);
		$this->addElement('hidden', static::PFM_QRY, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_QRY,0),
		]);
		$formRULE->addElement('hidden', "draw".static::PFM_QRY, [
        	    'title'      => pm_Locale::lmsg('WEB.'.static::PFM_QRY),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableWEBSetting.".static::PFM_QRY,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);


		$this->addSubForm($formWEB,"SubFormWEB");
		$this->addSubForm($formRULE,"SubFormRULE");


		$statusMOD=Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_MODE,0);

		$this->addElement('hidden', static::PFM_MODE, [
			'value'      => $statusMOD,
			'class'   => 'card',
		]);


		$formMOD = new pm_Form_Simple();


		$this->addElement('hidden', static::PFM_MP, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MP,"1"),
		]);
	        $formMOD->addElement('select', "draw".static::PFM_MP, [
        	    'label'      => pm_Locale::lmsg('MODULE.Page'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MP,"1"),
		    'multiOptions' => array("0" => pm_Locale::lmsg('MODULE.PageDiscconect'),"1" => pm_Locale::lmsg('MODULE.PageError')),
        	    'required'   => false,
	            'validators' => [],
	        ]);

		$this->addElement('hidden', static::PFM_MS, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MS,0),
		]);
		$formMOD->addElement('hidden', "draw".static::PFM_MS, [
        	    'title'      => pm_Locale::lmsg('MODULE.'.static::PFM_MS),
		    'data-description' => pm_Locale::lmsg('MODULE.Secret_Desc'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MS,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_MX, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MX,0),
		]);
		$formMOD->addElement('hidden', "draw".static::PFM_MX, [
        	    'title'      => pm_Locale::lmsg('MODULE.'.static::PFM_MX),
		    'data-description' => pm_Locale::lmsg('MODULE.XSS_Desc'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MX,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);

		$this->addElement('hidden', static::PFM_MN, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MN,0),
		]);
		$formMOD->addElement('hidden', "draw".static::PFM_MN, [
        	    'title'      => pm_Locale::lmsg('MODULE.NS'),
		    'data-description' => pm_Locale::lmsg('MODULE.NS_Desc'),
	            'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MN,0),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
		]);


		$this->addElement('hidden', static::PFM_MH3, [
        		    'value'      => Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MH3,($TLS13 === null ? 0 : 1)),
		]);

		$formMOD->addElement('hidden', "draw".static::PFM_MH3, [
        	    'title'      => pm_Locale::lmsg('MODULE.H3'),
		    'data-title' => $TLS13 === null ? pm_Locale::lmsg('MODULE.H3Error') : pm_Locale::lmsg('MODULE.H3Info'),
		    'data-description' => pm_Locale::lmsg('MODULE.H3_Desc'),
	            'value'      => $TLS13 === null ? 0 : Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MH3,($TLS13 === null ? 0 : 1)),
        	    'required'   => false,
        	    'class'   => 'subswitch',
	            'validators' => [],
	            'disabled'      => $TLS13 === null ? 'disabled' : null,
		]);

		$this->addSubForm($formMOD,"SubFormMOD");
	        
	    }
	        
    }


    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }


        return true;
    }

    /**
     * @return boolean
     */
    public function process()
    {


	$changedType=false;
	if(Modules_FlexFirewallManager_Settings::GetSetting(static::PFM_WEB_Domain,2) != $this->getValue(static::PFM_WEB_Domain)){$changedType=true;}

	$changedSecret=false;
	if(Modules_FlexFirewallManager_Settings::GetSetting("EnableModuleSetting.".static::PFM_MS,2) != $this->getValue(static::PFM_MS)){$changedSecret=true;}

        Modules_FlexFirewallManager_Settings::SaveSettingMemory(static::PFM_WEBE, $this->getValue(static::PFM_WEBE));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory(static::PFM_MODE, $this->getValue(static::PFM_MODE));

	Modules_FlexFirewallManager_Settings::SaveSettingMemory(static::PFM_WEB_Lock_Normal, $this->getValue(static::PFM_WEB_Lock_Normal));
	Modules_FlexFirewallManager_Settings::SaveSettingMemory(static::PFM_WEB_Lock_High, $this->getValue(static::PFM_WEB_Lock_High));
	Modules_FlexFirewallManager_Settings::SaveSettingMemory(static::PFM_WEB_Domain, $this->getValue(static::PFM_WEB_Domain));

        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_ENV, $this->getValue(static::PFM_ENV));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_CONF, $this->getValue(static::PFM_CONF));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_WLOGIN, $this->getValue(static::PFM_WLOGIN));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_XML, $this->getValue(static::PFM_XML));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_APIK, $this->getValue(static::PFM_APIK));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_PGIN, $this->getValue(static::PFM_PGIN));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_VEND, $this->getValue(static::PFM_VEND));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_LIBPHP, $this->getValue(static::PFM_LIBPHP));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_INCPHP, $this->getValue(static::PFM_INCPHP));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_CRONPHP, $this->getValue(static::PFM_CRONPHP));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_ADMIN, $this->getValue(static::PFM_ADMIN));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_HACK, $this->getValue(static::PFM_HACK));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_AGENT, $this->getValue(static::PFM_AGENT));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableWEBSetting.".static::PFM_QRY, $this->getValue(static::PFM_QRY));


        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableModuleSetting.".static::PFM_MP, $this->getValue(static::PFM_MP));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableModuleSetting.".static::PFM_MS, $this->getValue(static::PFM_MS));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableModuleSetting.".static::PFM_MX, $this->getValue(static::PFM_MX));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableModuleSetting.".static::PFM_MN, $this->getValue(static::PFM_MN));
        Modules_FlexFirewallManager_Settings::SaveSettingMemory("EnableModuleSetting.".static::PFM_MH3, $this->getValue(static::PFM_MH3));


	Modules_FlexFirewallManager_Settings::SaveSettingMemory(null,null);	// save to file

	if($changedSecret){
		if($this->getValue(static::PFM_MS)=="1"){
			$this->app->SecretServer(true);
		}else{
			$this->app->SecretServer(false);
		}
	}

	if($this->getValue(static::PFM_SSL_OLD)!==""){
		if($this->getValue(static::PFM_SSL_OLD)==="0"){$this->app->SSL("OLD",false);}else{$this->app->SSL("OLD",true);}
	}
	if($this->getValue(static::PFM_SSL_V2)!==""){
		if($this->getValue(static::PFM_SSL_V2)==="0"){$this->app->SSL("V2",false);}else{$this->app->SSL("V2",true);}
	}
	if($this->getValue(static::PFM_SSL_V3)!==""){
		if($this->getValue(static::PFM_SSL_V3)==="0"){$this->app->SSL("V3",false);}else{$this->app->SSL("V3",true);}
	}
	if($this->getValue(static::PFM_SSL_TLS1)!==""){
		if($this->getValue(static::PFM_SSL_TLS1)==="0"){$this->app->SSL("TLS1",false);}else{$this->app->SSL("TLS1",true);}
	}
	if($this->getValue(static::PFM_SSL_TLS11)!==""){
		if($this->getValue(static::PFM_SSL_TLS11)==="0"){$this->app->SSL("TLS11",false);}else{$this->app->SSL("TLS11",true);}
	}
	if($this->getValue(static::PFM_SSL_TLS12)!==""){
		if($this->getValue(static::PFM_SSL_TLS12)==="0"){$this->app->SSL("TLS12",false);}else{$this->app->SSL("TLS12",true);}
	}
	if($this->getValue(static::PFM_SSL_TLS13)!==""){
		if($this->getValue(static::PFM_SSL_TLS13)==="0"){$this->app->SSL("TLS13",false);}else{$this->app->SSL("TLS13",true);}
	}


	if($changedType){
		if($this->getValue(static::PFM_WEB_Domain)=="1"){
			pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/switchIIS"));
		}else{
			pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/switchFirewall"));
		}
	}


        return true;
    }


 }

