<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


/**
 * Class Modules_FlexFirewallManager_ME_Add
 */
class Modules_FlexFirewallManager_ME_Add extends pm_Form_Simple
{

    const PFM_IP = 'iptoblock';
    const PFM_IPRule = 'iprule';

    private $isConsole = false;
    private $app;
    

    /**
     * Modules_FlexFirewallManager_ME_Add constructor.
     *
     * @param array $options
     */
    public function __construct($options = [])
    {
        if (!empty($options['isConsole'])) {
            $this->isConsole = $options['isConsole'];
        }

	
        parent::__construct($options);
    }

    /**
     * Init
     */
    public function init()
    {
        parent::init();

	$this->app=Modules_FlexFirewallManager_Settings::CreateCom(Modules_FlexFirewallManager_Settings::LangCode());

	$rulesname = [];

    	$appjson = json_decode($this->app->GetRulesNames("MAILENABLE"));


	if($appjson->result){

		foreach($appjson->rules as $rules){
			$rulesname[$rules->rulename]=$rules->rulename;
            	}    
	}



        $this->addElement('Text', static::PFM_IP, [
            'label'      => pm_Locale::lmsg('ToBlock_IP'),
	    'description' => pm_Locale::lmsg('ToBlock_IPDesc'),
            'required'   => true,
	    'validators' => array(
                array('NotEmpty', true),
            ),
        ]);

	if(isset($_GET["rule"])){
		$this->addElement('hidden', static::PFM_IPRule, [
			'value' => $_GET["rule"],
	        ]);
		$this->addElement('SimpleText', "showrule", [
			'label'      => pm_Locale::lmsg('PathRulesM'),
			'value' => str_replace(Modules_FlexFirewallManager_Settings::Ext . " - ","",$_GET["rule"]),
        	]);
	}else{
	        $this->addElement('select', static::PFM_IPRule, [
        	    'label'      => pm_Locale::lmsg('PathRulesM'),
		    'multiOptions' => $rulesname,
        	    'required'   => false,
	            'validators' => [],
        	]);
	}


        $this->addControlButtons([
		'sendTitle' => pm_Locale::lmsg('Save'),
		'cancelHidden' => true,
        ]);
    }

    /**
     * @param array $data
     *
     * @return bool
     */
    public function isValid($data)
    {
        if (!parent::isValid($data)) {
            $this->markAsError();
            return false;
        }

	if (!filter_var($data[static::PFM_IP], FILTER_VALIDATE_IP)) {
			$this->markAsError();
			$this->getElement(static::PFM_IP)->addError(pm_Locale::lmsg('Error.Format'));
			return false;
	}

        return true;
    }

    /**
     * @return integer
     */
    public function process()
    {


	if(!Modules_FlexFirewallManager_Settings::isLicenced()){

		$appjson = json_decode($this->app->GetRuleName($this->getValue(static::PFM_IPRule)));

		if($appjson->result){
			if($appjson->numbersips>10){
 				$this->_status->addMessage('warning',pm_Locale::lmsg('statusPRO'));
        		        $this->_redirect('index', [ 'exit' => true ]);
				return "IP;2;PRO";
			}
		}

	}

	$appjson = json_decode($this->app->BlockIp($this->getValue(static::PFM_IP),"MAILENABLE",$this->getValue(static::PFM_IPRule)));

	if($appjson->result){
		return "IP;1;OK";
	}else{
		if(strpos($appjson->desc, "Pro Version")==false){
			return "IP;0;".$appjson->desc;
		}else{
			return "IP;2;PRO";
		}
	}

    }


 }

