<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


class Modules_FlexFirewallManager_Public{


    public function LinkFF()
    {
	try{
        	return new COM("FlexFirewallManager.Admin",null,CP_UTF8);
	}
	catch(com_exception $e){
		pm_Log::err("[" . self::Ext . "] Error CreateCom " . $e->getCode() . " : " . $e->getMessage());
		if(strpos($e->getMessage(),"Password")>0){
			pm_Log::err("[" . self::Ext . "] Fix Error CreateCom > PleskUser Update");
			Modules_FlexFirewallManager_Settings::SaveSetting("Job","PleskUser");
		}

		return null;
	}

    }


    /**
     * Update DB IP
     *
     * @return Boolean
     */
    public function update()
    {
       self::LinkFF()->UpdateDB();
       return true;
    }


    /**
     * Import Rule
     *
     * @return Boolean
     */
    public function importRule()
    {

	$import=file_get_contents($_FILES['import']['tmp_name']);
	return self::LinkFF()->ImportFirewallRule($import);

    }

    /**
     * Get Info for Home Block
     *
     * @return String Json
     */
    public function homeblock()
    {
	$data = [];
    	$fileManager = new pm_ServerFileManager();
	$filePath = pm_Context::getVarDir() . "\Stats.cfg";
	$contentStats = $fileManager->fileGetContents($filePath);

	$items = preg_split('/[\n\r]+/', $contentStats);
	foreach($items as $item) {
		if(strpos($item,"\t")===False){break;}
		$info = explode("\t", $item);
		$data[] = [Modules_FlexFirewallManager_Settings::FormatDateOutput($info[0],pm_Locale::lmsg('formatDate'))  => ($info[1] + $info[2])];

		if(count($data)>2){break;}

	}

	return json_encode($data);

    }

    /**
     * Get Task to Complete
     *
     * @return Numeric
     */
    public function migrationstatus(){

    	$fileManager = new pm_ServerFileManager();
	$filePath = pm_Context::getVarDir() . "\\";

	if (!$fileManager->fileExists($filePath . "migrate.task")) {
		return "0";
	}else{
		$contentStats = trim($fileManager->fileGetContents($filePath. "migrate.task"));
		$result = $fileManager->scanDir($filePath . $contentStats,true,false);
		return count($result);
	}

    }
    /**
     * Export Rule
     *
     * @return String Path
     */
    public function exportRule()
    {

    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\export-rule.bin";

		return $fileManager->fileGetContents($filePath);

    }


    /**
     * Check IP Reputation from some Providers
     *
     * @param $ip		 String Ip Address
     *
     * @return String of Provider Bad Reputation
     */

    public function reputationCheck($ip){

	/* Range IP not Check */

	if($ip=='' || $ip=='-'){return "NORMAL";}

	/* If IP was checked return Cache result */
	if(isset($_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip])){
		return $_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip];
	}

	/* Wildcard IP not Check */
	if( strpos($ip,"-")>0 || strpos($ip,"*")>0 ){
		$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]="UKN";
		return "UKN";
	}

	/* Start Checking */

	$reverseIp=$this->reverseIP($ip);

	try {
		$result = dns_get_record($reverseIp .".zen.spamhaus.org",DNS_A,$authns);
		if(!empty($result) && $this->isDetected($result[0]['ip'])){
			$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]="Spamhaus";
			return "Spamhaus";
		}
	} catch (Exception $e) {
	}


	try {
		$result = dns_get_record($reverseIp .".bl.spamcop.net",DNS_A,$authns);
		if(!empty($result) && $this->isDetected($result[0]['ip'])){
			$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]="Spamcop";
			return "Spamcop";
		}
	} catch (Exception $e) {
	}

	try {
		$result = dns_get_record($reverseIp .".cbl.abuseat.org",DNS_A,$authns);
		if(!empty($result) && $this->isDetected($result[0]['ip'])){
			$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]="Abuseat";
			return "Abuseat";
		}
	} catch (Exception $e) {
	}

	try {
		$result = dns_get_record($reverseIp .".b.barracudacentral.org",DNS_A,$authns);
		if(!empty($result) && $this->isDetected($result[0]['ip'])){
			$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]="Barracudacentral";
			return "Barracudacentral";
		}
	} catch (Exception $e) {
	}

	try {
		$result = dns_get_record($reverseIp .".rbl.blockedservers.com",DNS_A,$authns);
		if(!empty($result) && $this->isDetected($result[0]['ip'])){
			$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]="Blockedservers";
			return "Blockedservers";
		}
	} catch (Exception $e) {
	}

	try {
		$result = dns_get_record($reverseIp .".bl.octopusdns.com",DNS_A,$authns);
		if(!empty($result) && $this->isDetected($result[0]['ip'])){
			$_SESSION[pm_Context::getModuleInfo()->name]['reputation-'.$ip]="Octopusdns";
			return "Octopusdns";
		}
	} catch (Exception $e) {
	}

	$_SESSION["reputation"][$ip]="NORMAL";
	return "NORMAL";

    }


    Function reverseIP($ip){

	if(strpos($ip,".")>0){
		return implode(".", array_reverse(explode(".", $ip, 4), false));
	}else{
		return implode(".", str_split(str_replace(":","",$ip)));
	}

    }


    /**
     * if dns_get_record of reputationCheck have valid response
     *
     * @param $value	 String Value Response (IPAdress)
     *
     * @return Boolean
     */
    Function isDetected($value){

	/* Check result */
	if(Modules_FlexFirewallManager_Settings::GetLength($value)==0){
		return false;
	}else{

		/* Check value as good reputation */
		if ( ($value=="127.0.0.0") || ($value=="127.0.0.1") || ($value=="127.0.0.9") || ($value=="127.0.0.10") || ($value=="127.0.0.11") ){
			return false;
		}else{
			return true;
		}

	}
    }


}