<?php
/**
 * Copyright 2022-2024 Flex Firewall Manager for Plesk
 *
 * Permission is hereby not granted to manipulate, modify or adapt the code;
 * as well as obtain a copy of this software or the associated documentation.
 * It is not allowed to publish, distribute, sublicense and/or sell copies of the Software,
 * without the consent of the author or creator of the software.
 *
 * The above copyright notice and this permission notice will be included
 * on all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", AND IN NO EVENT
 * AUTHORS OR COPYRIGHT HOLDERS WILL BE RESPONSIBLE
 * FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION,
 * TORT OR OTHERWISE, ARISING OUT OF OR IN CONNECTION WITH THE SOFTWARE OR USE.
 *
 * @copyright 2022-2024 Flex Firewall Manager for Plesk
 * @author Flex Firewall <info@firewall.flexservices.app>
 * @license Copyright
 */


class Modules_FlexFirewallManager_Settings{

/*Create Const by default*/

    const DomExt="https://firewall.flexservices.app";
    const Ext="Flex Firewall Manager";


    /**
     * Get Languaje
     *
     * @return String {2}
     */
    public static function LangCode(){
	return substr(pm_Locale::getCode(), 0, 2);
    }


    /**
     * Get Current User
     *
     * @return String
     */
    public static function UserCom(){
	if(self::ClientAuth()){
		$user=pm_Domain::getByDomainId($_SESSION[pm_Context::getModuleInfo()->name]['site_id'])->getSysUserLogin();
	}else{
		$user=pm_Session::getClient()->getProperty("login");
	}
	return $user;
    }

    /**
     * Check Permission Extension
     *
     * @return Boolean
     */
    public static function isEnablePermission(){

	if(self::ClientAuth()){
		
		if(!isset($_SESSION[pm_Context::getModuleInfo()->name]['site_id'])){
			return false;
		}

	        if (pm_Domain::getByDomainId($_SESSION[pm_Context::getModuleInfo()->name]['site_id'])->hasPermission('firewall_ext_enable')) {
        	    return true;
	        }else{
        	    return false;
		}
	}

	if(self::ResellerAuth()){

	        if (pm_Session::getClient()->hasPermission('firewall_ext_enable')) {
        	    return true;
	        }else{
        	    return false;
		}
	}

   }



    /**
     * Create Link to FirewallBrain
     *
     * @param $lang	 String => LangCode
     * @return COM+ Link
     * @return Null if cannot load 
     */

	public static function CreateCom($lang,$user = null){
		$appcom = null;

		try{
			if(Modules_FlexFirewallManager_Settings::GetSetting("PU")==''){Modules_FlexFirewallManager_Settings::SaveSetting("PU","Plesk Administrator");}
			if(Modules_FlexFirewallManager_Settings::GetSetting("PU")==Modules_FlexFirewallManager_Settings::GetSetting("PA")){
				if(Modules_FlexFirewallManager_Settings::GetSetting("Job")==''){Modules_FlexFirewallManager_Settings::SaveSetting("Job","PleskUser");}
				return Modules_FlexFirewallManager_Settings::GetSetting("Job");
			}
			if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="PleskUser"){
				$appcom = null;
				return Modules_FlexFirewallManager_Settings::GetSetting("Job");
			}
			//echo "Run COM+<br>";
	        	$appcom = new COM("FlexFirewallManager.Admin",null,CP_UTF8);
			$appcom->LangOutput=$lang;
			if(Modules_FlexFirewallManager_Settings::GetSetting("EnableLOGPlesk")==1){
				if($user==null){
					$appcom->Username=Modules_FlexFirewallManager_Settings::GetSetting("PU").":" . pm_Session::getClient()->getProperty("login");
				}else{
					$appcom->Username=Modules_FlexFirewallManager_Settings::GetSetting("PU").":Plesk";
				}
			}else{
				$appcom->Username=Modules_FlexFirewallManager_Settings::GetSetting("PU");
			}
			$appcom->Password=Modules_FlexFirewallManager_Settings::GetSetting("PA");

			$_SESSION[pm_Context::getModuleInfo()->name]['version'] = json_encode($appcom->version);

		}catch(com_exception $e){
			/*Create Error Log*/
			pm_Log::err("[" . self::Ext . "] Error CreateCom " . $e->getCode() . " : " . $e->getMessage());

			if($e->getCode()==2147614729){
				pm_Log::err("[" . self::Ext . "] Wrong Login. Try to get new credencial. PleskUser Update");
				Modules_FlexFirewallManager_Settings::SaveSetting("Job","PleskUser");
				$appcom = null;
				return "PleskUser";
			}else{
				$appcom = null;
				Modules_FlexFirewallManager_Settings::SaveSetting("Job","PleskUser");
				if(strpos($e->getMessage(),"Failed to create")>0){pm_Log::err("[" . self::Ext . "] CreateCom is crash. Must Reinstall Ext. Executing /reinstall command to try fix");$result = pm_ApiCli::callSbin("FlexFirewallSetup.exe",array("/reinstall"));}
			}			
		}
		return $appcom;
	}


    /**
     * Format String Value GetVersionCom
     *
     * @param $app		Object => COM+
     *
     * @return String
     */
	public static function GetVersionCom($app){
		$appjson = null;
		if(isset($_SESSION[pm_Context::getModuleInfo()->name]['version']) && strlen($_SESSION[pm_Context::getModuleInfo()->name]['version'])>2){
			$appjson = json_decode($_SESSION[pm_Context::getModuleInfo()->name]['version']);
		}else{
			$appjson = json_decode($app->version);
		}
		return $appjson;

	}



    /**
     * Check Extension Update
     *
     * @return Boolean (True if runing any update)
     */
	public static function isJob(){

		if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=='Init'){
			return false;
		}

		if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=='PleskUser'){
			return true;
		}

		if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=='FixCom'){
			return true;
		}

		if(Modules_FlexFirewallManager_Settings::GetSetting("status")=="1"){
			if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=='reinstall'){
				return true;
			}else{
				return false;
			}
		}else{
			return false;
		}


	}


    /**
     * Check if PROMO setting is active
     *
     * @return Boolean (True if have promo license to get all features)
     */
	public static function isPromo(){
		$status=false;
		$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo']="";


		$context = stream_context_create( [
		'ssl' => [
			'verify_peer' => false,
			'verify_peer_name' => false,
		],
		'http'=>array(
			'timeout' => 5,
			'max_redirects' => 3,
			'ignore_errors' => 0,
			'method' => "GET",
			'header' => "Accept-language: es\r\n" .
			"cookie: \r\n" .  
			"User-Agent: PLESK EXT " . Date('Y-m-d')."\r\n" .
			"X-Pleskv: " . pm_ProductInfo::getVersion() . "\r\n" .
			"X-Extv: " . pm_Context::getModuleInfo()->version . "\r\n" .
			"X-Hostmn: " . gethostname() . "\r\n"
			)
		]);

		$CodePromo=Modules_FlexFirewallManager_Settings::GetSetting('PROMO');

		switch (strtoupper($CodePromo)) {

		case strtoupper("Release"):

			$db = pm_Bootstrap::getDbAdapter();
			$localRecord = $db->fetchRow($db->select()->from('ip_addresses'));

			$ServerIp=$localRecord["ip_address"];
			$extension = pm_Extension::getById(strtolower(str_replace(" ","-",self::Ext)));

			if(strpos(get_headers(self::DomExt . "/trial/".$ServerIp.".release",1,$context)[0],"200 OK")){
				// exist
				$ContentResponse = self::DecryptPromo(file_get_contents(self::DomExt ."/trial/".$ServerIp.".release",false,$context));

				if($ContentResponse!=''){
					$DatePromo = explode("-",$ContentResponse);

					if( Date('Y-m-d') <= Date("Y-m-d", mktime(0, 0, 0, $DatePromo[1], $DatePromo[2], $DatePromo[0])) ){
						$status=true;$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo']=". " . str_replace("%1",self::FormatDateOutput(Date("d/m/Y", strtotime(Date("Y-m-d", mktime(0, 0, 0, $DatePromo[1], $DatePromo[2], $DatePromo[0])))),pm_Locale::lmsg('formatDate')),pm_Locale::lmsg('AppProFullDate'));
					}else{
						Modules_FlexFirewallManager_Settings::SaveSetting('PROMO','');
					}
				}

			}
			break;
		case strtoupper("Trial"):

			$db = pm_Bootstrap::getDbAdapter();
			$localRecord = $db->fetchRow($db->select()->from('ip_addresses'));

			$ServerIp=$localRecord["ip_address"];
			$extension = pm_Extension::getById(strtolower(str_replace(" ","-",self::Ext)));

			if(strpos(get_headers(self::DomExt . "/trial/".$ServerIp.".trial",1,$context)[0],"200 OK")){
				// exist
				$ContentResponse = self::DecryptPromo(file_get_contents(self::DomExt ."/trial/".$ServerIp.".trial",false,$context));
				if($ContentResponse!=''){
					$DatePromo = explode("-",$ContentResponse);

					if( Date('Y-m-d') <= Date("Y-m-d", mktime(0, 0, 0, $DatePromo[1], $DatePromo[2], $DatePromo[0])) ){
						$status=true;$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo']=". " . str_replace("%1",self::FormatDateOutput(Date("d/m/Y", strtotime(Date("Y-m-d", mktime(0, 0, 0, $DatePromo[1], $DatePromo[2], $DatePromo[0])) . " +1 days")),pm_Locale::lmsg('formatDate')),pm_Locale::lmsg('AppProFullDate'));
					}else{
						Modules_FlexFirewallManager_Settings::SaveSetting('PROMO','');
					}
				}
			}else{

	 			$status=true;$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo']=". " . str_replace("%1",self::FormatDateOutput(Date("d/m/Y", strtotime('+60 days')),pm_Locale::lmsg('formatDate')),pm_Locale::lmsg('AppProFullDate'));
			}

			break;
		case strtoupper($_SERVER['COMPUTERNAME']):
			$List=explode('\n',exec('getmac /nh /fo list'));
			foreach ($List as $Item) {
			    $UID=str_replace('-','',strtok($Item,' '));
			    if(strpos(get_headers(self::DomExt ."/promo/".$UID.".promo",1,$context)[0],"200 OK")!=false){
				$status=true;
				$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo']="";
			    }
			}
			break;
		}

		return $status;
	}


    /**
     * Decrypt Promo String
     *
     * @param $string	 String
     * @return String Date for all features
     * @return Empty on exception 
     */
	public static function DecryptPromo($string){
		try{

		    $string = substr($string,1,strlen($string)-2)."=" ;
		    $ivCiphertext  = base64_decode($string);
		    $iv = substr($ivCiphertext, 0, 16);
		    $ciphertext = substr($ivCiphertext, 16);
		    $key=pm_ProductInfo::getVersion()."-".pm_Context::getModuleInfo()->version;
		    for($i=strlen($key);$i<32;$i++)
		    $key[$i]="#";
		    $result=openssl_decrypt($ciphertext, "aes-256-cbc", $key, OPENSSL_RAW_DATA, $iv);

		    if($result==false){
			return "";
		    }else{return $result;}
		}
		catch(Exception $e){
			return "";
		}
	}


    /**
     * Check License is ON
     *
     * @return Boolean
     */
	public static function isLicenced(){

		if (isset($_SESSION[pm_Context::getModuleInfo()->name]['License']) && $_SESSION[pm_Context::getModuleInfo()->name]['License']=="1"){
			return true;
		}

		//error_reporting(0);
		try{
			// $license = new pm_License("EXT.00000000.0000");
			$_SESSION[pm_Context::getModuleInfo()->name]['License']="0";
			$_SESSION[pm_Context::getModuleInfo()->name]['LicensePromo']="";

			//$status=$license->getProperty("active");
			$status=false;		
	
			if(!$status){$status=self::isPromo();}

			//return $license->getProperty("active");
			// $license->getProperty("lim_date");

			if($status){$_SESSION[pm_Context::getModuleInfo()->name]['License']="1";}

			return $status;
		}
		catch(Exception $e){
			$_SESSION[pm_Context::getModuleInfo()->name]['License']="0";
			$status=false;	

			if(!$status){$status=self::isPromo();}

			if($status){$_SESSION[pm_Context::getModuleInfo()->name]['License']="1";}

			return $status;
		}
		
	}


    /**
     * Get Country by Code
     *
     * @param $Code	 String {2}
     *
     * @return String Country Fullname
     */
	public static function Country($Code){

		if($Code=='' || $Code=='--'){
			return "";
		}

		return pm_Locale::lmsg('country.' . strtoupper($Code));
	}


    /**
     * Permission Account
      *
     * @return Boolean
     */
    public static function AdminAuth(){
	return pm_Session::getClient()->isAdmin();
    }
    public static function ResellerAuth(){
	return pm_Session::getClient()->isReseller();
    }
    public static function ClientAuth(){
	return pm_Session::getClient()->isClient();
    }


/*
Default Tabs
*/
    public static function _getTabs($app,$tab){
        $tabs = [];

	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
		// no tab
	}else{

		if($app!=null){


			if(self::ClientAuth()){
				$tabs[] = [
        			    'title' => pm_Locale::lmsg('TabSettingTitle'),
		        	    'controller' => 'index',
	        		    'action' => 'firewall',
		        	    'containerCls' => ($tab=='index-firewall' ? 'active' : ''),
			        ];
			}else{
			        $tabs[] = [
        			    'title' => pm_Locale::lmsg('TabSettingTitle'),
		        	    'controller' => 'index',
		        	    'action' => 'index',
		        	    'containerCls' => ($tab=='-' || $tab=='index-index' || $tab=='index-firewall' || $tab=='index-web' || $tab=='index-mailenable' || $tab=='index-smartermail' || $tab=='index-logs' ? 'active' : ''),
		        	    'cls' => 'tour-index',
		        	];
			}
			if(self::AdminAuth()){

		           $tabs[] = [
        		        'title' => pm_Locale::lmsg('TabRulesTitle'),
		        	'controller' => 'firewall',
                		'action' => 'index',
	        	        'containerCls' => ($tab=='smartermail-index' || $tab=='mailenable-blacklistcountry' || $tab=='firewall-blacklistcountry' || $tab=='firewall-index' || $tab=='mailenable-index' || $tab=='cloudflare-index'? 'active' : ''),
                		'cls' => 'tour-rules',
		            ];

		           $tabs[] = [
        		        'title' => pm_Locale::lmsg('TabWhiteListTitle'),
		        	'controller' => 'index',
                		'action' => 'whitelist',
		        	'containerCls' => ($tab=='index-whitelist' ? 'active' : ''),
                		'cls' => 'tour-whitelist',
		            ];

			}else{

		           $tabs[] = [
        		        'title' => pm_Locale::lmsg('PathRulesF'),
		        	'controller' => 'firewall',
		        	'containerCls' => ($tab=='firewall-index' ? 'active' : ''),
                		'action' => 'index',
		            ];

	        	   $tabs[] = [
        	        	'title' => pm_Locale::lmsg('PathRulesC'),
		        	'controller' => 'cloudflare',
		        	'containerCls' => ($tab=='cloudflare-index' ? 'active' : ''),
	                	'action' => 'index',
		            ];
	
			}
	

	        	   $tabs[] = [
        	        	'title' => pm_Locale::lmsg('TabSearchTitle'),
		        	'controller' => 'index',
	                	'action' => 'search',
		        	'containerCls' => ($tab=='index-search' ? 'active' : ''),
				'cls' => 'tour-search',
		            ];
		}else{
		           $tabs[] = [
        		        'title' => pm_Locale::lmsg('TabTitle'),
		        	'controller' => 'index',
                		'action' => 'setup',
		            ];
		}
	}

        return $tabs;
    }

    public static function _getSettingTabs($app,$tab){
        $tabs = [];


	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
		// no tab
	}else{

		if($app!=null){
	
			if(self::AdminAuth()){


				$appjson = json_decode(self::GetVersionCom($app));

			        $tabs[] = [
        			    'title' => pm_Locale::lmsg('TabSettingExtTitle'),
		        	    'controller' => 'index',
		        	    'action' => 'index',
			            'containerCls' => ($tab=='-' || $tab=='index-index' ? 'active' : ''),
		        	];

				$tabs[] = [
        			    'title' => pm_Locale::lmsg('TabFirewallTitle'),
		        	    'controller' => 'index',
	        		    'action' => 'firewall',
			            'containerCls' => ($tab=='index-firewall' ? 'active' : ''),
		        	];

				$tabs[] = [
        			    'title' => pm_Locale::lmsg('TabWebTitle'),
		        	    'controller' => 'index',
	        		    'action' => 'web',
			            'containerCls' => ($tab=='index-web' ? 'active' : ''),
		        	];

				if($appjson->MailServer=="MailEnable"){
					$tabs[] = [
	        			    'title' => pm_Locale::lmsg('TabMailEnableTitle'),
			        	    'controller' => 'index',
	        			    'action' => 'mailenable',
					    'cls' => 'mailenable',
			            	    'containerCls' => ($tab=='index-mailenable' ? 'active' : ''),
		        		];
				}

				if($appjson->MailServer=="SmarterMail"){
					$tabs[] = [
	        			    'title' => pm_Locale::lmsg('TabSmarterMailTitle'),
			        	    'controller' => 'index',
	        			    'action' => 'smartermail',
					    'cls' => 'smartermail',
			            	    'containerCls' => ($tab=='index-smartermail' ? 'active' : ''),
		        		];
				}

				$tabs[] = [
        			    'title' => pm_Locale::lmsg('TabLogTitle'),
		        	    'controller' => 'index',
	        		    'action' => 'logs',
			            'containerCls' => ($tab=='index-logs' ? 'active' : ''),
		        	];

			}

			
		}
	}

        return $tabs;
    }



    /**
     * RuleTabs
     *
     * @param $app	 FirewallBrain Link and check is load
     *
     * @return Array $tabs
     */
    public static function _getRuleTabs($app,$tab){
        $tabs = [];

	if(Modules_FlexFirewallManager_Settings::GetSetting("Job")=="Init"){
		// no tab
	}else{

		if($app!=null){
	

			$appjson = json_decode(self::GetVersionCom($app));

		           $tabs[] = [
        		        'title' => pm_Locale::lmsg('PathRulesF'),
		        	'controller' => 'firewall',
	                	'action' => 'index',
				'cls' => 'firewall',
			        'containerCls' => ($tab=='firewall-index' ? 'active' : ''),
		            ];
	
			if(self::AdminAuth()){
				if($appjson->MailServer=="MailEnable"){
		        	   $tabs[] = [
        		        	'title' => pm_Locale::lmsg('PathRulesM'),
			        	'controller' => 'mailenable',
	                		'action' => 'index',
					'cls' => 'mailenable',
			        	'containerCls' => ($tab=='mailenable-index' ? 'active' : ''),
			            ];
				}
				if($appjson->MailServer=="SmarterMail"){
		        	   $tabs[] = [
        		        	'title' => pm_Locale::lmsg('PathRulesS'),
			        	'controller' => 'smartermail',
	                		'action' => 'index',
					'cls' => 'smartermail',
			        	'containerCls' => ($tab=='smartermail-index' ? 'active' : ''),
			            ];
				}
			}

	        	   $tabs[] = [
        	        	'title' => pm_Locale::lmsg('PathRulesC'),
		        	'controller' => 'cloudflare',
	                	'action' => 'index',
				'cls' => 'cloudflare',
		        	'containerCls' => ($tab=='cloudflare-index' ? 'active' : ''),
		            ];

			
		}
	}

        return $tabs;
    }



    /**
     * Check if Rule can be manage by user login in plesk
     *
     * @param $rulename		String => Name of Rule
     *
     * @return Boolean
     */
	public static function AllowRule($rulename){

		if(strpos($rulename, " AS")){return false;}

		if(self::AdminAuth()){		
			return true;
		}else{

			if(!self::ClientAuth()){
				if(strpos($rulename, " SMTP")){return true;}
				if(strpos($rulename, " POP")){return true;}
				if(strpos($rulename, " IMAP")){return true;}
				if(strpos($rulename, " FTP")){return true;}

				if(Modules_FlexFirewallManager_Settings::GetSetting('EnableBOT')=="1" && Modules_FlexFirewallManager_Settings::GetSetting('status_RuleBot')=="1"){
					if(strpos($rulename, " BOT")){return true;}
				}

			}

        		foreach (pm_Domain::getAllDomains(true) as $domain) {
            			if (!pm_Session::getClient()->isAdmin() && !pm_Session::getClient()->hasAccessToDomain($domain->getId())) {
                			continue;
            			}

				if(strpos($rulename, $domain->getName())){return true;}
        		}

		}

		return false;
	}



    /**
     * Return String with Format Date
     *
     * @param $date		String  Date and Languaje Format
     * @param $format		String  Languaje Format
     *
     * @return String		Format output
     * @return String		Empty String if wrong @param
     */
	public static function FormatDateOutput($date,$format){

		if(self::GetLength($date)==0){
			return "";
		}

		$output=$format;
		$strdate=$date;
		$strtime="";


		if (str_contains($strdate, ' ')){
			$strdate=explode(" ", $date)[0];
			$strtime=explode(" ", $date)[1];
		}

		if (str_contains($date, '-')) {
			$ardate=explode("-", $strdate);
			$output=str_replace("yyyy",$ardate[0],$output);
			$output=str_replace("mm",$ardate[1],$output);
			$output=str_replace("dd",$ardate[2],$output);

		} elseif (str_contains($date, '/')) {
			$ardate=explode("/", $strdate);

			$output=str_replace("yyyy",$ardate[2],$output);
			$output=str_replace("mm",$ardate[1],$output);
			$output=str_replace("dd",$ardate[0],$output);

		} else {

			$output=str_replace("yyyy",date('Y',$strdate),$output);
			$output=str_replace("mm",date('m',$strdate),$output);
			$output=str_replace("dd",date('d',$strdate),$output);
		}

		if (str_contains($format, ':') && $strtime!=''){
			$artime=explode("-", $strtime);

			$output=str_replace("hh",$artime[0],$output);
			$output=str_replace("mm",$artime[1],$output);
		}

		return $output;
	}


    /**
     * Return is  param domain is an AliasDomain
     *
     * @param $domainname	String => DomainName
     *
     * @return Boolean
     */
	public static function isAliasDomain($domainname){
		try{
			pm_Domain::getByName($domainname)->getId();
			return false;
		}catch(exception $e){
			return true;
		}
	}


    /**
     * DomainDnsRecords
     *
     * @param $domainname	String => DomainName
     *
     * @return Array with DNS record
     * @return Null on exception
     */
	public static function GetPleskDomainDnsRecords($domainname){
		try{
			return pm_Domain::getByName($domainname)->getDnsZone()->getRecords();
		}catch(exception $e){

			try{
				$found=false;
				foreach(pm_Domain::getAllDomains(true) as $domain){
					foreach(pm_DomainAlias::getByDomain($domain) as $alias){
						if($alias->getDisplayName()==$domainname){
							$found=true;
							return $alias->getDnsZone()->getRecords();
						}
					}
				}

				return null;
			}catch(exception $e){
				return null;
			}
		}

	}


    /**
     * DomainNS Records
     *
     * @param $domainname	String => DomainName
     *
     * @return Array with NS record
     * @return Null on exception
     */
	public static function GetPleskDomainNS($domainname){
		$listdns=[];
		try{

			$regdns=pm_Domain::getByName($domainname)->getDnsZone()->getRecordsByType("NS");
			foreach($regdns as $dns){
				$listdns[]=substr($dns->getValue(), 0, -1);
			}
			return $listdns;

		}catch(exception $e){
			try{

				foreach(self::GetPleskDomainDnsRecords($domainname) as $records){
					if($records->getType()=="NS"){$listdns[]=substr($records->getValue(), 0, -1);}
				}

				return $listdns;
				
			}catch(exception $e){
				return null;
			}
		}

	}



    /**
     * Get/Set Domain Parameter Account 
     *
     * @param $domainname	String => DomainName
     * @param $value		String => Value to set
     *
     * @return Boolean if SET action
     * @return String if GET action
     */

	public static function PleskDomainAccountCF($domainname,$value = ''){
		if($value==''){
			try{
				return pm_Domain::getByName($domainname)->getSetting("Account");
			}catch(exception $e){
				return "";
			}
		}else{
			try{
				pm_Domain::getByName($domainname)->setSetting("Account",$value);
				return true;
			}catch(exception $e){
				return false;
			}
		}
	}


    /**
     * Get/Set Domain SYNC Parameter SYNC
     *
     * @param $domainname	String => DomainName
     * @param $value		String => Value to set
     *
     * @return String Boolean (0,1)
     */
	public static function PleskDomainAutoSyncCF($domainname,$value = ''){
		if($value==''){
			try{
				$value=pm_Domain::getByName($domainname)->getSetting("SYNC");
				if($value==''){$value="0";}
				return $value;
			}catch(exception $e){
				return "0";

			}
		}else{
			try{
				pm_Domain::getByName($domainname)->setSetting("SYNC",$value);
				return "1";
			}catch(exception $e){
				return "0";

			}
		}
	}

    /**
     * Find elemen in dns record aray
     *
     * @param $Records		Array Records
     * @param $Record		Single Record
     *
     * @return Record		if found, return Record
     * @return Null		if not found
     */
	public static function CheckDnsExist($Records,$Record){

                $found = false;
		$recordDns = [];
                foreach ($Records as $dns) {

                    if ($Record['name'] === $dns['name'] && $Record['type'] === $dns['type']) {
			if($dns['type']=="TXT" || $dns['type']=="NS"){
				if(trim($Record['value']) === trim($dns['value'])){
					$recordDns = $dns;
		                        $found = true;
			                break;
				}
			}else if($dns['type']=="MX"){
				if( (trim($Record['value']) === trim($dns['value'])) && ( (int) $Record['opciones'] === (int) $dns['opciones']) ){
					$recordDns = $dns;
		                        $found = true;
			                break;
				}
			}else{
				$recordDns = $dns;
	                        $found = true;
		                break;
			}
                    }
                }

		if($found){
			return $recordDns;
		}else{
			return null;
		}

	}



    /**
     * Get all Domains
     *
     * @param $showalias		Optional List Append Alias to Lits
     *
     * @return Record		Array Domains
     */
	public static function GetAllDomains($showalias = false){

		$Domains = [];
		$ListDomains=[];
		$IncludedDomains=[];

		foreach(pm_Domain::getAllDomains(false) as $domain){
            		if (!pm_Session::getClient()->isAdmin() && !pm_Session::getClient()->hasAccessToDomain($domain->getId())) {
                		continue;
            		}

			$domainame=self::GetDomainName($domain->getDisplayName());

			if (!array_key_exists($domainame, $ListDomains)) {$ListDomains[$domainame] = [$domain->getDisplayName()];}else{array_push($ListDomains[$domainame], $domain->getDisplayName());}

			$AutoDNS=self::PleskDomainAutoSyncCF($domain->getDisplayName());

		 	$Domains[$domain->getDisplayName()] = [
                		'name' => $domain->getDisplayName(),
                		'autodns' => $AutoDNS,
                		'type' => "main",
                		'obj' => $domain,
				'maindom' => $domainame
  	            	];

			if($showalias){
				foreach(pm_DomainAlias::getByDomain($domain) as $alias){

					$domainame=self::GetDomainName($alias->getDisplayName());

					if (!array_key_exists($domainame, $ListDomains)) {$ListDomains[$domainame] = [$alias->getDisplayName()];}else{array_push($ListDomains[$domainame], $alias->getDisplayName());}

				 	$Domains[$alias->getDisplayName()] = [
                				'name' => $alias->getDisplayName(),
		                		'autodns' => $AutoDNS,
                				'type' => "alias",
        	        			'obj' => $alias,
						'maindom' => $domainame
		  	            	];
				}
			}
		}


		foreach(array_keys($ListDomains) as $key){

			if(count($ListDomains[$key])==1){
				$IncludedDomains[] = $Domains[$ListDomains[$key][0]];
			}else{

				$index = array_search($key, $ListDomains[$key]);
				if($index === false){
					foreach($ListDomains[$key] as $dom){
						$Domains[$dom]['type']="notvalid";
						$IncludedDomains[] = $Domains[$dom];
					}
				}else{
					$IncludedDomains[] = $Domains[$ListDomains[$key][$index]];
				}


			}
		}

		asort($IncludedDomains);
		return $IncludedDomains;

	}



    /**
     * Find Domain in aray
     *
     * @param $ListDomains	Array Domains
     * @param $name		String => Domain to find
     *
     * @return Record		Domain if found
     * @return Null		Null if not found
     */
	public static function CheckDomExist($ListDomains,$name){

                $found = false;
		$zone = [];
                foreach ($ListDomains as $dom) {
			if(strtolower($dom["name"])==$name){
				$zone=$dom["obj"];
				$found = true;
				break;
			}

			
                }

		if($found){
			return $zone;
		}else{
			return null;
		}

	}



    /**
     * Find Country in aray
     *
     * @param $ListCountry	Array Countrys
     * @param $CountryCheck	String{2} => Country Code
     *
     * @return Record		Boolean
     */
	public static function CheckCountryExist($ListCountry,$CountryCheck){

                $found = false;
                foreach ($ListCountry as $Country) {
			if($Country->code==$CountryCheck["code"]){
				$found = true;
				if($Country->status=="A"){$found = false;}
				break;
			}
                }

		return $found;


	}



    /**
     * Read Setting File
     *
     * @param $Item		String => Item to find
     * @param $DefaultValue	Optional DefaultValue if not find Item
     *
     * @return Record		Value of Item if Found
     * @return Null		Null if Item not exists
     */
	public static function GetSetting($Item , $DefaultValue = null,$file = 'Settings'){

		/* Check if there is any cache setting live */

		if(isset($_SESSION[pm_Context::getModuleInfo()->name][$file])){

			/* cache found, now check if cache is from last 1 min or more */


			if( isset($_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity']) && ((time() - $_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity']) > 60) ){
				/* old cache : destroy and not load */
				unset($_SESSION[pm_Context::getModuleInfo()->name][$file]);
				unset($_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity']);
			}else{

				/* catch cache found */
				$appjson = $_SESSION[pm_Context::getModuleInfo()->name][$file];

				if($appjson["Job"]==''){

					if( str_contains($Item, '.') ){
						if(isset($appjson[explode(".",$Item)[0]]) && is_array($appjson[explode(".",$Item)[0]])){
							if( !isset($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]) || is_null($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]) || !array_key_exists(explode(".",$Item)[1], $appjson[explode(".",$Item)[0]]) ){
								return $DefaultValue;
							}else{
								if($Item=="Job"){
									if($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]==''){return '';}
								}else{
									return $appjson[explode(".",$Item)[0]][explode(".",$Item)[1]];
								}
							}
						}else{
							return $DefaultValue;
						}
					}else{
						if( !isset($appjson[$Item]) || is_null($appjson[$Item]) || !array_key_exists($Item, $appjson)  ){
							return $DefaultValue;
						}else{
							if($Item=="Job"){
								if($appjson[$Item]==''){return '';}
							}else{
								return $appjson[$Item];
							}
						}
					}
				}
			}
		}

		/* no catch found and get information from file */

    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\".$file.".cfg";

		if (!$fileManager->fileExists($filePath)) {
			return $DefaultValue;
		}else{
			$appjson = json_decode($fileManager->fileGetContents($filePath), true);
			$_SESSION[pm_Context::getModuleInfo()->name][$file]=$appjson;
			$_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity'] = time();
			if( str_contains($Item, '.') ){
				if( !isset($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]) || is_null($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]) || !array_key_exists(explode(".",$Item)[1], $appjson[explode(".",$Item)[0]]) ){
					return $DefaultValue;
				}else{
					return $appjson[explode(".",$Item)[0]][explode(".",$Item)[1]];
				}
			}else{
				if( !isset($appjson[$Item]) || is_null($appjson[$Item]) || !array_key_exists($Item, $appjson) ){
					return $DefaultValue;
				}else{
					return $appjson[$Item];
				}
			}

		}

	}


    /**
     * Save Setting File
     *
     * @param $Item		String => Item to find
     * @param $Value		Value to save
     *
     */
	public static function SaveSetting($Item,$Value,$file = 'Settings'){

    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\".$file.".cfg";

		if (!$fileManager->fileExists($filePath)) {
			if( str_contains($Item, '.') ){
				$appjson[explode(".",$Item)[0]][] = [explode(".",$Item)[1] => $Value];
			}else{
				$appjson[$Item] = $Value;
			}
			$fileManager->filePutContents($filePath, json_encode($appjson, JSON_PRETTY_PRINT));

			/* Destroy cache if exists*/
			unset($_SESSION[pm_Context::getModuleInfo()->name][$file]);
		}else{
			$appjsonSession = (isset($_SESSION[pm_Context::getModuleInfo()->name][$file]) ? $_SESSION[pm_Context::getModuleInfo()->name][$file] : [] );
			$appjson = json_decode($fileManager->fileGetContents($filePath), true);
			if( str_contains($Item, '.') ){
				$appjson[explode(".",$Item)[0]][explode(".",$Item)[1]] = $Value;
			}else{
				$appjson[$Item] = $Value;
			}

			if($appjsonSession!==$appjson){
				$fileManager->filePutContents($filePath, json_encode($appjson, JSON_PRETTY_PRINT));
			}

			/* Refresh cache */
			$_SESSION[pm_Context::getModuleInfo()->name][$file]=$appjson;
			$_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity'] = time();
		}



	}
    /**
     * Save Setting Memory
     *
     * @param $Item		String => Item to find
     * @param $Value		Value to save
     *
     */
	public static function SaveSettingMemory($Item,$Value,$file = 'Settings'){

		$appjsonSession = [];
		$code = pm_Context::getModuleInfo()->name;

    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\".$file.".cfg";

		if (!$fileManager->fileExists($filePath)) {
			if( str_contains($Item, '.') ){
				$appjsonSession[explode(".",$Item)[0]][] = [explode(".",$Item)[1] => $Value];
			}else{
				$appjsonSession[$Item] = $Value;
			}
			$fileManager->filePutContents($filePath, json_encode($appjsonSession, JSON_PRETTY_PRINT));

			/* Destroy cache if exists*/
			$_SESSION[$code]["mem".$file]=$appjsonSession;
		}else{
			if(!isset($_SESSION[$code]["mem".$file])){
				$appjsonSession = json_decode($fileManager->fileGetContents($filePath), true);
			}else{
				$appjsonSession = $_SESSION[$code]["mem".$file];
			}

			if($Item==null && $Value==null){
				$fileManager->filePutContents($filePath, json_encode($appjsonSession, JSON_PRETTY_PRINT));
				unset($_SESSION[$code][$file]);
				unset($_SESSION[$code]["mem".$file]);
			}else{

				if( str_contains($Item, '.') ){
					$appjsonSession[explode(".",$Item)[0]][explode(".",$Item)[1]] = $Value;
				}else{
					$appjsonSession[$Item] = $Value;
				}

				/* Refresh cache */
				$_SESSION[$code]["mem".$file]=$appjsonSession;
			}

		}



	}
    /**
     * Delete Setting File
     *
     * @param $Item		String => Item to find
     *
     */
	public static function DeleteSetting($Item,$file = 'Settings'){

    		$fileManager = new pm_ServerFileManager();
		$filePath = pm_Context::getVarDir() . "\\".$file.".cfg";
		$found=false;

		if ($fileManager->fileExists($filePath)) {
			$appjson = json_decode($fileManager->fileGetContents($filePath), true);
			if( str_contains($Item, '.') ){
				if( isset( $appjson[explode(".",$Item)[0]][explode(".",$Item)[1]] ) ){unset($appjson[explode(".",$Item)[0]][explode(".",$Item)[1]]); $found=true;}
			}else{
				if( isset( $appjson[$Item] ) ){unset($appjson[$Item]);$found=true;}
			}

			if($found){
				$fileManager->filePutContents($filePath, json_encode($appjson, JSON_PRETTY_PRINT));

				/* Refresh cache */
				$_SESSION[pm_Context::getModuleInfo()->name][$file]=$appjson;
				$_SESSION[pm_Context::getModuleInfo()->name][$file.'_Activity'] = time();
			}
		}



	}




    /**
     * Get Length String and detect null as 0
     *
     * @param $Value		String => Value
     *
     * @return Numeric
     */
	public static function GetLength($Value){

		if ($Value === null || $Value === ''){
		  	return 0;
		}else{
			return strlen($Value);
		}
	}



    /**
     * Format Boolean Value to HTML (True | False)
     *
     * @param $value		Numeric => Value
     *
     * @return String HTML
     */
	public static function StatusStringService($value){
		if($value==1){
			return "<img src=\"".pm_Context::getBaseUrl() . "img/icon/on.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"enabled\" title=\"".pm_Locale::lmsg('on')."\"> " . pm_Locale::lmsg('on');
		}else{
			return "<img src=\"".pm_Context::getBaseUrl() . "img/icon/off.png\" style=\"width: 16px;margin-top: -2px;\" alt=\"disabled\" title=\"".pm_Locale::lmsg('off')."\"> " . pm_Locale::lmsg('off');
		}

	}

    /**
     * Format String Value FullDomainName to String DomainName
     *
     * @param $FullDomainName		String => Value
     *
     * @return String
     */
	public static function GetDomainName($FullDomainName){

		$result = "";
	        $lastcount = 0;
		$index = 0;
        	$partDom = explode(".",$FullDomainName);

		for ($i = count($partDom) - 1; $i >= 0; $i--) {
			If ($lastcount > 4 && $index>1){break;}
			If (self::GetLength($result)>0){ $result = "." . $result;}
			$result = $partDom[$i] . $result;
			$lastcount = self::GetLength($partDom[$i]);
			$index++;
		}
	
        	return $result;
	}



} // end
